; A model of food security in rural Southern Malawi
; Samantha Dobbie & Stefano Balbi 2016


extensions [
  nw gis
  nlfuzzy
  array
  ]


;;;;;;;;;;;;;;;;;;;;;;;
; Variable definition ;
;;;;;;;;;;;;;;;;;;;;;;;

breed [households household]
breed [individuals individual]

globals [
  rand-list                 ; random numbers to sort households upon

  ; INDIVIDUALS
  num-individuals          ; number of individuals to be created
  add-hh                   ; the number of new households to be added under population growth scenarios

  ; SOCIAL NETWORK
  clustering-coefficient  ; measure of the degree to which households tend to cluster together.
  average-path-length     ; the average number of steps along the shortest paths for all possible pairs of networked households
  average-degree          ; the average number of connections or edges each household has to other households
  clust-coeff-sum         ; total clustering coefficient
  num-qualifying-nodes    ; number of qualifying households
  tot-links               ; total number of links between households
  current-node            ; current household
  num-households          ; number of households to be created
  num-families            ; number of families in village
  num-neighbors           ; number of neighbours a household has
  rewiring-probability    ; the probability of a link being rewired
  num-close-hh            ; number of close households

  ; POPULATION GROWTH
  growth-rate             ; the number of households in the population (based on UN projections)

  ;TIME OF YEAR
  year                     ; number of years (starting from 1)
  month                    ; the month of the year
  season-start             ; the start of the growing season (TRUE/FALSE)
  season-end               ; the end of the growing season (TRUE/FALSE)
  agri-type                ; whether we are in the rainy or dry season


  ; EXOGENOUS FACTORS
  market-stability         ; stability of grain price
  political-stability      ; stability of household access to saftey nets
  past-input-pol           ; past access to input subsidies
  past-pw-pol              ; past access to payment for work schemes
  max-tree-age             ; maximum age of fruit stands before they need to be replanted
  annual-rain-list         ; list of annual rainfall projections (2010 - 2050)
  annual-rain              ; annual rainfall for the current model year

  ; PRODUCTIVE STABILITY
  hh-prod-stability         ; stability of crop production
  food-stability            ; stability of food availabilty, access and utilisation

  ; FORESTS
  min-fr                    ; minimum amount of biomass that has to remain
  past-growth               ; past forest growth
  area-ha                   ; total forest area (hectares)
  biomass                   ; mean biomass available per hectare (m3 per hectare)
  ; C(x) consumption
  req-energy                ; per capita energy requirement for firewood per month
  f-fire                    ; rate of utility decline once hh-fire-conslevel met
  e-cont                    ; energy content of wood
  density                   ; density of wood
  ; L(x) leisure
  fi                        ; the initial forest amount in metres cubed
  fr                        ; the current forest amount  in meters cubed
  ; U(x) Utility
  alpha-c                   ; preference weight for firewood consumption
  alpha-l                   ; preference weight for firewood leisure
  alpha-a                   ; preference weight for firewood adherance

  ; WATER
  n-bore                    ; number of working boreholes in the village
  min-water                 ; minimum amount of water that has to remain
  capacity                  ; amount of water available per individual
  ; C(x) consumption
  w-req-water               ; per capita water requirement for water per month (L)
  f-water                   ; rate of utility decline once hh-water-conslevel met
  ; L(x) leisure
  wi                        ; the initial water amount available in litres per capita
  wr                        ; the current water amount available in litres per capita
  ; U(x) Utility
  w-alpha-c                 ; preference weight for water consumption
  w-alpha-l                 ; preference weight for water leisure
  w-alpha-a                 ; preference weight for water adherence

  ; LIVESTOCK
  hh1-meat                 ; amount of output per unit of livestock and labour
  hh1-egg                  ; amount of output per unit of livestock and labour
  hh1-milk                 ; amount of output per unit of livestock and labour
  hh1-manure               ; amount of output per unit of livestock and labour
  hh2-meat                 ; amount of output per unit of livestock and labour
  hh2-egg                  ; amount of output per unit of livestock and labour
  hh2-milk                 ; amount of output per unit of livestock and labour
  hh2-manure               ; amount of output per unit of livestock and labour
  hh3-meat                 ; amount of output per unit of livestock and labour
  hh3-egg                  ; amount of output per unit of livestock and labour
  hh3-milk                 ; amount of output per unit of livestock and labour
  hh3-manure               ; amount of output per unit of livestock and labour
  tlu-prob-1               ; probability that a type 1 hh with 0 tlu gets tlu
  tlu-prob-2               ; probability that a type 1 hh with 0 tlu gets tlu
  tlu-prob-3               ; probability that a type 1 hh with 0 tlu gets tlu

  ; CALORIE CONVERSION FACTORS
  cf-anroots               ; conversion factor for annual roots
  cf-grains                ; conversion factor for grains
  cf-pulses                ; conversion factor for pulses
  cf-peroots               ; conversion factor for permanent roots
  cf-veg                   ; conversion factor for vegetables
  cf-fruit                 ; conversion factor for fruit
  cf-cash                  ; conversion factor for edible cash crops
  cf-forage                ; conversion factor for food foraged
  cf-meat                  ; conversion factor for meat
  cf-egg                   ; conversion factor for eggs
  cf-milk                  ; conversion factor for milk

  ; SUBSISTENCE REQUIREMENTS
  sub-req                 ; subsistence requrements (land allocated to food crops)

  ;LABOUR REQUIREMENTS
  grain-labour            ; labour requirements (HH hrs/ hectare) for grains
  nuts-pulses-labour      ; labour requirements (HH hrs/ hectare) for nuts & pulses
  annual-roots-labour     ; labour requirements (HH hrs/ hectare) for annual roots
  permroots-labour        ; labour requirements (HH hrs/ hectare) for perm roots
  vegetables-labour       ; labour requirements (HH hrs/ hectare) for vegetables
  fruits-labour           ; labour requirements (HH hrs/ hectare) for fruits
  cash-labour             ; labour requirements (HH hrs/ hectare) for cash crops
  food-labour             ; labour requirements for food crops
  deforest-labour         ; labour requirements to deforest a patch (HH hrs/hectare)

  ;LAND REQUIREMENTS
  cash-land               ; land requirements for cash crops
  tree-land               ; land requirements for planting fruit trees

  ; COPING STRATEGIES
  ;n-f-interact            ; max number of times households can ask to borrow food from network (times per month)
  ;n-l-interact            ; max number of times households can ask to borrow  labour from network (times per month)

  ; MARKETS
  grain-stability         ; list of past and present annual grain prices
  annual-roots-list       ; list of future prices as modeled by COSIMO and GCAM
  grains-list             ; list of future prices as modeled by COSIMO and GCAM
  pulses-list             ; list of future prices as modeled by COSIMO and GCAM
  per-roots-list          ; list of future prices as modeled by COSIMO and GCAM
  veg-list                ; list of future prices as modeled by COSIMO and GCAM
  fruits-list             ; list of future prices as modeled by COSIMO and GCAM
  cash-list               ; list of future prices as modeled by COSIMO and GCAM
  meat-list               ; list of future prices as modeled by COSIMO and GCAM
  egg-list                ; list of future prices as modeled by COSIMO and GCAM
  milk-list               ; list of future prices as modeled by COSIMO and GCAM
  tlu-list                ; list of future prices as modeled by COSIMO and GCAM
  ag-wage                 ; current wage per hour hh agricultural work (dollars)
  nag-wage                ; current wag per hour hh non-agricultural work (dollars)
  value-anroots           ;current value of annual roots (dollars/kg)
  value-grains            ;current value of grains (dollars/kg)
  value-pulses            ;current value of pulses (dollars/kg)
  value-peroots           ;current value of permanent roots (dollars/kg)
  value-veg               ;current value of vegetables (dollars/kg)
  value-fruit             ;current value of fruits (dollars/kg)
  value-cash              ;current value of cash crops (dollars/kg)
  value-meat              ; current value of meat (dollars/kg)
  value-egg               ; current value of eggs (dollars/kg)
  value-milk              ; current value of milk (dollars/litre)
  value-tlu               ; current value of livestock units (dollars/kg)
  value-s-inorg-fert      ; value of subsidised inorganic fertiliser (dollars/kg)
  value-s-pesticide       ; value of subsidised pesticide (dollars/kg)

  ; POLICY
  ; input subsidies
  coupon-month         ; month coupons become available
  p1-access            ; probability of type 1 hh being selected for farm input subsidy programme (FISP)
  p2-access            ; probability of type 2 hh being selected for FISP
  p3-access            ; probability of type 3 hh being selected for FISP
  p1-coupon-use        ; probability of type 1 hh using coupon
  p2-coupon-use        ; probability of type 2 hh using coupon
  p3-coupon-use        ; probability of type 3 hh using coupon
  ; public work programs
  pw1-access           ; probability of type 1 hh being targetted
  pw2-access           ; probability of type 2 hh being targetted
  pw3-access           ; probability of type 3 hh being targetted

  ;MODEL RUN
  duration             ; length of the model run in ticks (each tick = 1 month)

  ; MODEL OUTCOMES
  ;AVAILABILITY
  h1-avail             ; mean calories available to farmers from own production and the market
  h2-avail             ; mean calories available to agricultural labourers from own production and the market
  h3-avail             ; mean calories available to non-agricultiral workers from own production and the market
  av-yield             ; average yield of farming plots
  av-yield-dimba       ; average yield of dimba plots
  ;ACCESS
  h1-access            ; mean calories accessible to farmers
  h2-access            ; mean calories accessible to agricultural laboures
  h3-access            ; mean calories accessible to non-aricultural workers
  prop-h1-defic        ; proportion of farmer households that are food energy deficient
  prop-h2-defic        ; proportion of agricultural labourer households that are food energy deficient
  prop-h3-defic        ; proportion of non-agricultural worker households that are food energy deficient
  h1-fecc              ; average daily food energy consumption per capita of farmers
  h2-fecc              ; average daily food energy consumption per capita of agricultural labourers
  h3-fecc              ; average daily food energy consumption per capita of non-agricultural workers
  ; UTILISATION
  h1-diversity         ; mean diversity score of farmers
  h2-diversity         ; mean diversity score of agricultural labourers
  h3-diversity         ; mean diversity score of non-agricultural workers
  h1-propstaples       ; mean proportion of farmers diet made up of staples
  h2-propstaples       ; mean proportion of agricultural labourers diet made up ofstaples
  h3-propstaples       ; mean proportion of non-agricultural workers
  h1-pa                ; mean process-ability of farmers
  h2-pa                ; mean process-ability of agricultural labourers
  h3-pa                ; mean process-ability of non-agricultiral workers
  ; STABILITY
  h1-stability         ; mean production stability of farming households
  h2-stability         ; mean production stability of agricultural workers
  h3-stability         ; mean production stability of non-agricultural workers
  ; TYPE
  prop-hanging-in      ; proportion of households hanging in
  prop-stepping-up     ; proportion of households stepping up
  prop-stepping-out    ; proportion of households stepping out
  prop-falling-down    ; proportion of households falling down

   prop-hanging-in-1      ; proportion of households hanging in
  prop-stepping-up-1     ; proportion of households stepping up
  prop-stepping-out-1    ; proportion of households stepping out
  prop-falling-down-1    ; proportion of households falling down

  prop-hanging-in-2      ; proportion of households hanging in
  prop-stepping-up-2     ; proportion of households stepping up
  prop-stepping-out-2    ; proportion of households stepping out
  prop-falling-down-2    ; proportion of households falling down

  prop-hanging-in-3      ; proportion of households hanging in
  prop-stepping-up-3     ; proportion of households stepping up
  prop-stepping-out-3    ; proportion of households stepping out
  prop-falling-down-3    ; proportion of households falling down


  ; LANDUSE
  h-land               ; proportion of households with land
  h1-land              ; proportion of farmer households with land
  h2-land              ; proportion of agricultural labourer households with land
  h3-land              ; proportion of non-agricultural worker households with land
  vil-anro             ; mean proportion of land given to annual roots
  vil-grain            ; mean proportion of land given to grains
  vil-nut              ; mean proportion of land given to nuts
  vil-perm             ; mean proportion of land given to perm roots
  vil-cash             ; mean proportion of land given to cash crops
  vil-veg              ; mean proportion of land given to vegetables
  vil-fruit            ; mean proportion of land given to fruit
  vil-fal              ; mean proportion of land given to fallow
  vil-anro-1           ; mean proportion of land given to annual roots by farmers
  vil-anro-2           ; mean proportion of land given to annual roots by agricultural labourers
  vil-anro-3           ; mean proportion of land given to annual roots by non-agricultural workers
  vil-grain-1          ; mean proportion of land given to grains by farmers
  vil-grain-2          ; mean proportion of land given to grains by agricultural labourers
  vil-grain-3          ; mean proportion of land given to grains by non-agricultural workers
  vil-nut-1            ; mean proportion of land given to nuts and pulses by farmers
  vil-nut-2            ; mean proportion of land given to nuts and pulses by agricultural labourers
  vil-nut-3            ; mean proportion of land given to nuts and pulses by non-agricultural workers
  vil-perm-1           ; mean proportion of land given to permanent crops by farmers
  vil-perm-2           ; mean proportion of land given to permanent crops by agricultural labourers
  vil-perm-3           ; mean proportion of land given to permanent crops by non-agricultural workers
  vil-cash-1           ; mean proportion of land given to cash crops by farmers
  vil-cash-2           ; mean proportion of land given to cash crops by agricultural labourers
  vil-cash-3           ; mean proprotion of land given to cash crops by non-agricultural workers
  vil-veg-1            ; mean proportion of land given to vegetables by farmers
  vil-veg-2            ; mean proportion of land given to vegetables by agricultural labourers
  vil-veg-3            ; mean proportion of land given to vegetables by non-agricultural workers
  vil-fruit-1          ; mean proportion of land given to fruits by farmers
  vil-fruit-2          ; mean proportion of land given to fruits by agricultural labourers
  vil-fruit-3          ; mean proportion of land given to fruits by non-agricultural workers
  vil-fal-1            ; mean proportion of land given to fallow by farmers
  vil-fal-2            ; mean proportion of land given to fallow by agricultural labourers
  vil-fal-3            ; mean proportion of land given to fallow by non-agricultural workers

  v-tot-anro           ; mean amount of annual root output in kg
  v-tot-grains         ; mean amount of grains output in kg
  v-tot-pulses         ; mean amount of pulses root output in kg
  v-tot-peroots        ; mean amount of peroots root output in kg
  v-tot-cash           ; mean amount of cash output in kg
  v-tot-veg            ; mean amount of veg output in kg
  v-tot-fruit          ; mean amount of fruit output in kg
  tot-anro-1           ; mean amount of annual root output in kg for farmers
  tot-anro-2           ; mean amount of annual root output in kg for agricultural labourers
  tot-anro-3           ; mean amount of annual root output in kg for non-agricultural workers
  tot-grain-1          ; mean amount of grain output in kg for farmers
  tot-grain-2          ; mean amount of grain output in kg for agricultural labourers
  tot-grain-3          ; mean amount of grain output in kg for non-agricultural workers
  tot-pulses-1         ; mean amount of nuts & pulses output in kg for farmers
  tot-pulses-2         ; mean amount of nuts & pulses output in kg for agricultural labourers
  tot-pulses-3         ; mean amount of nuts & pulse output in kg for non-agricultural workers
  tot-peroots-1        ; mean amount of permanent roots output in kg for farmers
  tot-peroots-2        ; mean amount of permanent roots output in kg for agricultural labourers
  tot-peroots-3        ; mean amount of permanent roots output in kg for non-agricultural workers
  tot-cash-1           ; mean amount of cash crop output in kg for farmers
  tot-cash-2           ; mean amount of cash crop output in kg for agricultural laboures
  tot-cash-3           ; mean amount of cash crop output in kg for non-agricultural workers
  tot-veg-1            ; mean amount of veg output in kg for farmers
  tot-veg-2            ; mean amount of veg output in kg for agricultural labourers
  tot-veg-3            ; mean amount of veg output in kg for non-agricultural labourers
  tot-fruit-1          ; mean amount of fruit output in kg for farmers
  tot-fruit-2          ; mean amount of fruit output in kg for agricultural labourers
  tot-fruit-3          ; mean amount of fruit output in kg for non-agricultural workers

 ;FOOD SECURITY STATUS
  h1-av                 ; mean availability status of farmers [0-100]
  h2-av                 ; mean availability status of agricultural labourers [0-100]
  h3-av                 ; mean availability status of non-agricultural workers [0-100]

  h1-ac                 ; mean access status of farmers [0-100]
  h2-ac                 ; mean access status of agricultural labourers [0-100]
  h3-ac                 ; mean access status of non-agricultral workers [0-100]

  h1-u                  ; mean utilisation status of farmers [0-100]
  h2-u                  ; mean utilisation status of agricultural labourers[0-100]
  h3-u                  ; mean utilisation status of non-agricultural workers [0-100]

  h1-s                  ; mean statbility status of farmers [0-100]
  h2-s                  ; mean stability status of agricultural labourers [0-100]
  h3-s                  ; mean stability status of non-agricultural workers [0-100]

  count-h1              ; number of farming households
  count-h2              ; number of households that are agricultural labourers
  count-h3              ; number of households that are non-agricultural workers
  ]

households-own [
  ;ATTRIBUTES
  hh-id                     ; unique id number of the household
  hh-type                   ; 1=farmer 2=agricultural labourer 3=non-agricultural worker
  past-type
  hh-head                   ; individual corresponding to head of household
  hh-gender                 ; gender of the household head M/F
  rand-sort                 ; random number to sort upon
  sim-age                   ; to identify new agents
  new-ind                   ; number of new individuals to be created

  ; HUMAN CAPITAL
  hh-size                   ; number of individuals making up household
  hh-member                 ; list of household members
  hh-edu-level              ; education level between 1 and 7

  ; SOCIAL CAPITAL
  social-net                ; agentset of linked households
  family                    ; related households

  ; NATURAL CAPITAL
  my-farm                   ; list of patches owned by the HH
  hh-land-area              ; total area of land owned (hectares)

  ; PHYSICAL CAPITAL
  t-labour                  ; hours of labour a HH has to dedicate (monthly)
  labour-pool               ; surplus labour a HH can donate
  chickens-owned            ; number of chickens owned by the hh
  goats-owned               ; number of goats owned by the hh
  cattle-owned              ; number of cattle owned by the hh
  tlu                       ; number of livestock units owned by the hh
  hh-inputs                 ; total quantity of inputs (fertiliser, seeds etc) (kg)
  hh-inorg-fert             ; quantity of inorganic fertiliser (kg)
  hh-pesticide              ; quantity of pesticide (kg)
  firewood-stock            ; stock of firewood (kg)
  water-stock               ; stock of water (Litres)

  ; FINANCIAL CAPITAL
  hh-capital                ; capital assets (dollars)
  past-capital              ; hh capital at the end of the agricultural season
  past-output               ; total crop output for the past agricultural season (kg)
  m-remitt                  ; income from remittances
  other-inc                 ; income from 'other sources' as described in the ihs3 this includes pensions, gambling and credit etc.


  ; BASIC NEEDS
  met-food-needs            ; 0 = TRUE, 1 = FALSE
  hh-fire-cons              ; household firewood consumption requirements (monthly)
  hh-water-cons             ; household water consumption requirements (monthly)
  hh-food-needs             ; household food needs (monthly)

  ; CAPABILITY TO BE FOOD SECURE
  food-availability         ; amount of calories available from self-production and the market
  food-access               ; amount of calories available from access to market and coping strategies
  food-utilisation          ; amount of calories consumed by the household
  food-security             ; status - good, moderate or poor
  diet-diversity            ; number of unique food types eaten (0 - 8)

  ; LABOUR ALLOCATION
  agri-priority              ; list of agricultural activities in order of labour priority
  fw-labour                  ; labour given to firewood collection
  w-labour                   ; labour given to water collectio
  fh-labour                  ; labour given to on-farm work
  fo-labour                  ; labour given to off-farm agricutural work
  na-labour                  ; labour given to non-agricultural work
  farming-lab                ; labour given to farming
  livs-lab                   ; labour given to tending to livestock
  foraging-lab               ; labour given to foraging

  p1-lab                     ; labour given to annual roots (patch cover type 1)
  p2-lab                     ; labour given to basic grains (patch cover type 2)
  p3-lab                     ; labour given to basic grains and nuts and pulses (patch cover type 3)
  p4-lab                     ; labour given to nuts and pulses (patch cover type 4)
  p5-lab                     ; labour given to perm roots (patch cover type 5)
  p6-lab                     ; labour given to cash crops (patch cover type 6)
  p7-lab                     ; labour given to vegetables (patch cover type 7)
  p8-lab                     ; labour given to fruit trees (patch cover type 8)
  p9-lab                     ; labour given to fruit trees and basic grains (patch cover type 9)
  p10-lab                    ; labour given to fruit trees and basic grains and nuts and pulses (patch cover type 10)
  p11-lab                    ; labour given to fruit trees basic grains, nuts and pulses and permanent roots (patch cover type 11)


  ; COLLECT FIREWOOD
  resource-array    ; array of extraction levels
  res-list          ; list of extraction levels
  max-res           ; maximum extraction level
  min-res           ; minimum extraction level
  norm-list         ; list of normalised extraction levels
  norm-array        ; array of normalised extraction levels
  prop-needs        ; proportion of firewood needs met
  act-extract       ; actual proportion of resource extracted
  ; C(x) consumption
  resource-extract    ; resource extraction level (x)
  opt-extract         ; optimum resource exctraction level
  hh-needs            ; household fire wood requirements
  sd-type-cons
  norm-hh-fire-cons   ; normalised firewood consumption requirement
  norm-ex-level       ; normalised extraction level
  consumption         ; value of consumption component
  ; L(x) leisure
  t-min             ; minimum amount of time for a single gathering trip
  leisure           ; value of leisure component
  col-time          ; time taken to collect firewood
  gat-t
  m-gat-t
  ; A(x) adherence
  r                 ; determines degree hh adheres to institutional rules/ network norms (0 <= r <= 1)
  rules             ; determines how much hh adheres to rules
  norms             ; determines how much hh adheres to norms
  past-resource-ex  ; past resource extraction level
  ex-level          ; extraction level prescribed by institution
  adherence         ; value of adherence component
  norm-neighbours   ; value of average extraction of neighbours
  av-ex             ; value of average extraction of neighbours (not normalised)
  ; U(X) utility
  past-utility      ; current highest utility
  utility           ; newly calculated utility value
  utility-list      ; list of previous utility values

  ; COLLECT WATER
  w-prop-needs      ; proportion of water needs met
  w-resource-array  ; array of extraction levels
  w-res-list        ; list of extraction levels
  w-max-res         ; maximum extraction level
  w-min-res         ; minimum extraction level
  w-norm-list       ; list of normalised extraction levels
  w-norm-array      ; array of normalised extraction levels
  w-act-extract     ; actual proportion of resource extracted
  ; C(x) consumption
  w-resource-extract ; resource extraction level (x)
  w-opt-extract      ; optimum resource exctraction level
  norm-hh-water-cons ; normalised water consumption requirement
  w-norm-ex-level    ; normalised extraction level
  w-consumption      ; value of consumption component
  ; L(x) leisure
  w-t-min             ; minimum amount of time for a single gathering trip
  w-leisure           ; value of leisure component
  w-col-time          ; time taken to collect water
  ; A(x) adherence
  w-r                 ; determines degree hh adheres to institutional rules/ network norms (0 <= r <= 1)
  w-rules             ; determines how much hh adheres to rules
  w-norms             ; determines how much hh adheres to norms
  w-past-resource-ex  ; past resource extraction level
  w-ex-level          ; extraction level prescribed by institution
  w-adherence         ; value of adherence component
  w-norm-neighbours   ; value of average extraction of neighbours
  ; U(X) utility
  w-past-utility      ; current highest utility
  w-utility           ; newly calculated utility value
  w-utility-list

  ; ACQUIRE INPUTS
  coupon-n                   ; number of coupons
  coupon-type                ; 1 = fertiliser, 2 = pesticide

  ;FARMING
  hh-sub-req                 ; whether HH subsistance requirements are met (True/False)
  hh-cash-labour             ; whether HH cash crop labour requirements are met (True/False
  hh-cash-land               ; whether HH cash crop land requirements are met (True/False)
  hh-cash-know               ; whether HH cash crop knowledge requirements are met (True/False)
  hh-tree-land               ; whether HH tree planting land requirements are met (True/False)
  hh-tree-labour             ; whether HH tree planting labour requirements are met (True/False)
  hh-tree-know               ; whether HH tree planting knowledge requirements are met (True/False)
  hh-food-labour             ; whether HH food crop labour requirements are met (True/False)
  get-labour                 ; whether HH can get labour from the labour pool or not (True/False)
  n-labour-request           ; the number of neighbous hh has requested labour from
  hh-veg-labour              ; whether HH veg crop labour requirements are met
  crop-priority              ; list of crops in order of labour priority
  month-lab                  ; monthly labour requirements
  labour-inc                 ; income from labour on neighbours farms

  allo-grains               ; area of land allocated to basic grains (hectares)
  allo-nuts-pulses          ; area of land allocated to nuts and pulses (hectares)
  allo-annual-roots         ; area of land allocated to annual roots tubers and plantains
  allo-perm-roots           ; area of land allocated to permanent roots tubers and plantains
  allo-vegetables           ; area of land allocated to vegetables
  allo-fruits               ; area of land allocated to fruits
  allo-cash-crops           ; area of land allocated to cash crops
  allo-fallow               ; area of land left to fallow
  allo-food-crops           ; area of land allocated to food crops

  past-grains                ; has the HH grown grains in the past?
  past-nuts-pulses           ; has the HH grown nuts and pulses in the past?
  past-annual-roots          ; has the HH grown annual roots in the past?
  past-perm-roots            ; has the HH grown perm roots in the past?
  past-vegetables            ; has the HH grown vegetables in the past?
  past-fruits                ; has the HH grown fruits in the past?
  past-cash-crops            ; has the HH grown cash crops in the past?

  labour-grains              ; labour accumulated for grains (hours)
  labour-nuts-pulses         ; labour accumulated for nuts and pulses (hours)
  labour-annual-roots        ; labour accumulated for annual roots (hours)
  labour-perm-roots          ; labour accumulated for perm roots (hours)
  labour-vegetables          ; labour accumulated for vegetables (hours)
  labour-fruits              ; labour accumulated for fruits (hours)
  labour-cash-crops          ; labour accumulated for cashcrops (hours)

  lg                         ; non-zero labour-grains
  lnp                        ; non-zero labour-nuts-pulses
  lf                         ; non-zero labour-fruits
  lpr                        ; non-zero labour-perm-crops

  output-p1                  ; expected output from patches with cover type = 1 (kg)
  output-p2                  ; expected output from patches with cover type = 2 (kg)
  output-p3                  ; expected output from patches with cover type = 3 (kg)
  output-p4                  ; expected output from patches with cover type = 4 (kg)
  output-p5                  ; expected output from patches with cover type = 5 (kg)
  output-p6                  ; expected output from patches with cover type = 6 (kg)
  output-p7                  ; expected output from patches with cover type = 7 (kg)
  output-p8                  ; expected output from patches with cover type = 8 (kg)
  output-p9                  ; expected output from patches with cover type = 9 (kg)
  output-p10                 ; expected output from patches with cover type = 10 (kg)
  output-p11                 ; expected output from patches with cover type = 11 (kg)

  jan-out                    ; list of total output for January
  feb-out                    ; list of total output for February
  mar-out                    ; list of total output for March
  apr-out                    ; list of total output for April
  may-out                    ; list of total output for May
  jun-out                    ; list of total output for June
  jul-out                    ; list of total output for July
  aug-out                    ; list of total output for August
  sep-out                    ; list of total output for September
  oct-out                    ; list of total output for October
  nov-out                    ; list of total output for November
  dec-out                    ; list of total output for December

  out-anroots                ; output of annual roots in kg
  out-grains                 ; output of grains in kg
  out-pulses                 ; output of pulses in kg
  out-peroots                ; output of permanent roots in kg
  out-veg                    ; output of vegetables in kg
  out-fruit                  ; output of fruit in kg
  out-cash                   ; output of cash in kg

  eat-anroots                ; eaten annual roots (calories)
  sell-anroots               ; sold annual roots (dollars)
  lost-anroots               ; lost annual roots (kg)

  eat-grains                 ; eaten grains (calories)
  sell-grains                ; sold annual roots (dollars)
  lost-grains                ; lost annual roots (kg)

  eat-pulses                 ; eaten nuts and pulses (calories)
  sell-pulses                ; sold nuts and pulses (dollars)
  lost-pulses                ; lost nuts and pulses (kg)

  eat-peroots                ; eaten permanent roots (calories)
  sell-peroots               ; sold permanent roots (dollars)
  lost-peroots               ; lost permanent roots (kg)

  eat-veg                    ; eaten vegetables (calories)
  sell-veg                   ; sold vegetables (dollars)
  lost-veg                   ; lost vegetables (kg)

  eat-fruit                  ; eaten fruit (calories)
  sell-fruit                 ; sold fruit (dollars)
  lost-fruit                 ; lost fruit (kg)

  eat-cash-crops             ; eaten cash crops (calories)
  sell-cash-crops            ; sold cash crops (dollars)
  lost-cash-crops            ; lost cash crops (kg)

  ; LIVESTOCK
  tlu-growth                 ; growth of livestock population
  meat-output                ; meat output from livestock
  egg-output                 ; egg output from livestock
  milk-output                ; milk output from livestock
  manure-output              ; manure output from livestock

  eat-meat                   ; meat eaten (calories)
  sell-meat                  ; meat sold (dollars)
  lost-meat                  ; meat lost (kg)

  eat-egg                    ; eggs eaten (calories)
  sell-egg                   ; eggs sold (dollars)
  lost-egg                   ; eggs lost (kg)

  eat-milk                   ; milk consumed (calories)
  sell-milk                  ; milk sold (dollars)
  lost-milk                  ; milk lost (kg)

  ; FORAGING
  eat-forage-veg             ; calories from foraged veg
  eat-forage-fruit           ; calories from foraged fruit

  ; OFF-FARM NON-AGRICULTURAL WORK
  off-nonag-output            ; off-farm non-agricultural output (Dollars)

  ; SPENDING CAPACITY
  m-nonf-expense               ; non food expenses
  spending-cap                 ; spending capacity
  spending-cal                 ; potential maize calories that can be bought using income

  ; FOOD AVAILABILITY
  calorie-pool              ; surplus calories from farming, foraging and animal production (above basic needs)
  surplus                   ; surplus of calories
  calorie-deficit           ; deficit of calories
  spend-cal-pool            ; amount of surplus calories that come from spending capacity
  actual-cal-pool           ; amount of surplus calories that come from self production
  bought-calories           ; actual calories bought


  ; COPING STRATEGIES
  pwp-calories           ; calories from public work programes (food for work etc)
  n-food-request         ; number of times hh has asked for food from network
  borrow-food            ; number of grains calories borrowed from the social network
  sale-livestock         ; number of grains calories corresponding to income from sale of livestock

  ; PROCESS ABILITY
  hh-process-ability     ; ability of household to process food [0-100]

  ; DIET
  cereals                ; cereal count
  fruits                 ; fruit count
  meats                  ; meat count
  milks                  ; milk count
  nuts                   ; nut count
  roots                  ; annual and permenant roots count
  vegs                   ; vegetable count
  forages                ; forage count

  ; FOOD SECURITY STATUS
  availability-status     ; availability of food [0-100]
  access-status           ; access to food [0-100]
  utilisation-status      ; utilisation of food [0-100]
  daily-fecpc             ; daily food energy consumption per capita
  hh-prop-staples         ; percentage of hh food energy from staples
  crop-sales              ; income from sale of crops (dollars)

  farm-work        ; count of hours working on-farm
  agri-work        ; count of hours working off-farm
  n-agri-work      ; count of hours doing non-agricultural work

  hanging-in       ; whether or not the hh-type stays the same (1 = true, 0 = false)
  stepping-up      ; whether or not the hh-type stays the same, but outputs are higher (1 = true, 0 = false)
  stepping-out     ; whether the hh-type changes to one with higher yield and/ or income (1 = true, 0 = false)
  falling-down     ; whether the hh-type changes to one with lower yield and / or income (1 = true, 0 = false)

  ; MODEL RESULTS
  lu-anro          ; proportion of land allocated to annual roots
  lu-grain         ; proportion of land allocated to grain
  lu-nut           ; proportion of land allocated to nuts and pulses
  lu-perm          ; proportion of land allocated to permanent crops
  lu-cash          ; proportion of land allocated to cash crops
  lu-veg           ; proportion of land allocated to vegetables
  lu-fruit         ; proportion of land allocated to fruit
  lu-fal           ; proportion of land allocated to fallow

  tot-anroots      ; total output of annual roots (kg)
  tot-grains       ; total output of grains (kg)
  tot-pulses       ; total output of pulses (kg)
  tot-peroots      ; total output of permanent roots (kg)
  tot-fruit        ; total output of fruit (kg)
  tot-cash         ; total output of cash crops (kg)
  tot-veg          ; total output of vegetables (kg)
  tot-output       ; total output of crops (kg)
  ]

individuals-own [
  family-id        ; the household the individual belongs to
  status           ; 1 for household head 0 otherwise
  gender           ; gender of individual ( 1 = male, 0 = female)
  age              ; age of individual
  edu-level        ; level of education
  illness          ; TRUE or FALSE
  ideal-calories   ; recommended daily caloric intake (based on age and gender)
  ind-labour       ; individual labour
  sim-age          ; To identify new agents
  ]

patches-own [
  ; ATTRIBUTES
  l-a                      ; labour accumulation for yield calculations
  patch-id                 ; unique id of the patch
  owner-id                 ; id of household owning patch
  patch-type               ; patch type 1 = forest, 2 = farm plot, 3 = dimba,  4 = river
  patch-area               ; area in HA
  land-fallow              ; land left to fallow? True/false
  patch-cover-type         ; patch cover type (0 - 11)
  labour-accum             ; accumulated labour
  labour-ha                ; labour per hectare
  inorg-fert-ha            ; inorganic fertiliser per hectare
  org-fert-ha              ; organic fertiliser per hectare
  lab                      ; labour for yield calculation
  org                      ; organic fertiliser for yield calcuation
  inorg                    ; inorganic fertiliser for yield calculation
  patch-inorg-fert         ; application of inorganic fertilisers (kg)
  patch-org-fert           ; application of organic fertiliesers (kg)
  patch-pesticide          ; application of pesticides and insecticides (kg)
  fruit-stand              ; fruit trees present? T/F
  fruit-stand-age          ; Age of fruit stand (months)
  cash-stand               ; whether patch has previously been planted with cash crops or not (0 = FALSE, 1 = TRUE)
  patch-fallow             ; area of land left to fallow (this might be less than the total area of the patch)
  prop-patch               ; for splitting patches based on labour

  ; EXPECTED YIELD
  harvest-time             ; is it harvest month? TRUE/FALSE
  i-labour                 ; labour
  p-yield                  ; expected patch yield (kg/hectare)
  patch-output             ; expected patch output (kg)
  ]


;;;;;;;;;;;;;;;;;;;;;;;;
; MODEL INITIALISATION ;
;;;;;;;;;;;;;;;;;;;;;;;;

to setup
  clear-all
  file-close-all                  ; close any open files
  nlfuzzy:init                    ; initialise fuzzy logic extension
  random-seed random-seed-no      ; set up seed number
  define-globals                  ; initialise global variables
  define-patches                  ; set up patches
  define-individuals              ; set up individuals
  define-households               ; set up households
  define-small-world              ; set up small world network
  define-social-net               ; identifies social network of each household
  reset-ticks
end

;;;;;;;;;;;;;
; MODEL RUN ;
;;;;;;;;;;;;;

to go

  tick
  ;SEASONALITY
  set-random-sort                         ; allocates a number at random to each household to allow 'random sorting'
  define-month                            ; defines the month of the year based on time steps
  define-year                             ; define the year based on month
  define-season-start                     ; determines whether it is the start of the growing season (true/false)
  define-season-end                       ; determines whether it is the end of the growing season (true/false)
  define-agri-season                      ; determines whether we are in the wet or dry season
  set-coupon-month                        ; determines the month coupons become available

  ; MARKETS
  set-market-value                        ; defines market value of commodities for each year.

  ;HOUSEHOLD ACTIVITIES
  ; BASIC NEEDS
  calc-food-needs                         ; determine food needs of the household
  calc-water-needs                        ; determine water needs of the household
  calc-fuel-needs                         ; determine fuel needs of the household

  ;LABOUR
  allocate-labour                         ; allocate labour between hh, on-farm ag, off-farm ag and off-farm non-ag work

  ; COLLECT FIREWOOD
  collect-firewood

  ; COLLECT WATER
  collect-water

  ; ACQUIRE INPUTS
  subsidised-inputs                       ; determine quantity of subsidised inputs

  ;FARMING
  setcrop-priority                        ; order crops based on labour priority for each month
  allocate-land                           ; at the start of the season allocate land to different crop types
  reallocate-land                         ; make adjustments to land allocations based on labour availability
  apply-inputs                            ; apply inputs to patches

  ; TENDING TO ANIMALS
  tend-livestock                          ; tend to livestock
  process-livestock                       ; process livestock outputs
  manure                                  ; apply manure to patches
  update-livestock                        ; update livestock numbers

  ; COMPUTE FARM YIELD
  compute-exp-yield                       ; calculate expected yield for each patch
  process-yield                           ; determine the proportion of crop which will be lost, eaten, sold and nafd

  ; FORAGING
  go-foraging                             ; forage for indigenous and wild foods

  ; OFF-FARM NON-AG WORK
  off-farm-nonagwork

  ; SPENDING CAPACITY
  non-food-expense
  calc-income
  calc-spending-cap

  ; FOOD AVAILABITLIY                     ; potential food availability from farming, foraging and animal production
  calc-food-availability

  ; COPING STRATEGIES
  pot-cash-for-work                       ; potential cash-for-work
  pot-borrow-food                         ; potential to borrow food from SN
  sell-livestock                          ; potential income from sale of live animals

  ; FOOD-ACCESS                           ; amount of calories available from access to market and adaptive strategies
  calc-food-access

  ; ABIITY TO PROCESS
  process-ability

  ; FOOD UTILISATION
  calc-food-utilisation  ; amount of calories consumed by the household
  summarise-hh-diet      ; calculate hh diet indicators

  ; PRODUCTION STABILITY
  calc-prod-stability

  ; FOOD STABILITY  ; long-term stability of food availability, access and utilisation
   calc-food-stability

  ; FOOD SECURITY
  calc-food-security

  ; HEALTH STATUS
  set-health-status

  ; OUTCOMES
  model-outcomes

  ;UPDATE HOUSEHOLD TYPE
  update-hh-type                       ; update household type
  set-trajectory

  ; GROW POPULATION
  update-population

  ; UPDATE ATTRIBUTES
  update-hh                            ; update household attributes

  ;PATCH ACTIVITIES
  ;UPDATE PATCH
  update-patch                         ; update patch attributes


  if ticks = duration                  ; end the simulation after a given number of ticks (or months)
  [
    stop
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; SET-UP                              ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to define-globals                            ; initialise global variables
  set duration 481                           ; length of simulation run (in ticks or months)
  set rand-list []

  ;INDIVIDUALS
  set num-individuals 546

  ;SEASONALITY
  set year 1

  ;SOCIAL NETWORK
  set num-households 116
  set num-families 5
  set rewiring-probability 0.1
  set num-close-hh 10

  ;POPULATION GROWTH

  ifelse population-scenario = "Fixed"
  [
    file-open "fixed-growth-rate.txt"
    set growth-rate []
    while [file-at-end? = FALSE] [set growth-rate lput file-read growth-rate]
    file-close
  ]
  [
    file-open "growth-rate.txt"
    set growth-rate []
    while [file-at-end? = FALSE] [set growth-rate lput file-read growth-rate]
    file-close
  ]

  ; FOREST
  set min-fr 0
  set area-ha 169.3
  set biomass 50
  set past-growth biomass * 0.0025 * area-ha
  ; Consumption C(x)
  set req-energy 1080
  set e-cont 15
  set density 450
  ; Leisure L(x)
  set f-fire 0.2
  set fi area-ha * biomass
  set fr area-ha * biomass
  ; Utility U(X)
  set alpha-c 1 / 3
  set alpha-l 1 / 3
  set alpha-a 1 / 3

  ; WATER
  set n-bore 2
  ; Consumption C(x)
  set w-req-water 1080
  ; Leisure L(x)
  set f-water 0.2
  set wi 270000 * n-bore
  set wr 270000 * n-bore
  ; Utility U(X)
  set w-alpha-c 1 / 3
  set w-alpha-l 1 / 3
  set w-alpha-a 1 / 3
  set min-water 0

  ; TREE GROWTH
  set max-tree-age 30

  ; ANNUAL RAINFALL
  ifelse climate-scenario = "Fixed"
  [
    file-open "fixed-climate-data.txt"
    set annual-rain-list []
    while [file-at-end? = FALSE] [set annual-rain-list lput file-read annual-rain-list]
    file-close
  ]
  [
    file-open "climateData.txt"
    set annual-rain-list []
    while [file-at-end? = FALSE] [set annual-rain-list lput file-read annual-rain-list]
    file-close
  ]

  set annual-rain 1396.9

  ; POLITICAL STABILITY
  set past-input-pol []
  set past-pw-pol []

  ; LIVESTOCK
  set hh1-meat 0.006
  set hh1-egg  0.06
  set hh1-milk  0.04
  set hh1-manure 0.92

  set hh2-meat  0.006
  set hh2-egg  0.24
  set hh2-milk  0.0
  set hh2-manure 0.06

  set hh3-meat 0.006
  set hh3-egg 0.06
  set hh3-milk 0.02
  set hh3-manure 0.61

  set tlu-prob-1 90
  set tlu-prob-2 85
  set tlu-prob-3 96

  ; CALORIE CONVERSION FACTORS
  set cf-anroots 790
  set cf-grains 3538
  set cf-pulses 3364
  set cf-peroots 1540
  set cf-veg 325
  set cf-meat 2042.5
  set cf-egg 1470
  set cf-milk 620

  ; LABOUR REQUIREMENTS
  set grain-labour 79.5
  set nuts-pulses-labour 118.3
  set annual-roots-labour 68.4
  set permroots-labour 86.4
  set vegetables-labour 94.6
  set fruits-labour 77.1
  set cash-labour 108.7
  set food-labour 88.66
  set deforest-labour 1200

  ; LAND REQUIREMENTS
  set cash-land 0.28
  set tree-land 0.31

  ; ADAPTIVE STRATEGIES
  ;set n-f-interact 3


  ; MARKETS
  set grain-stability []
  file-open "annual-roots.txt"
  set annual-roots-list []
  while [file-at-end? = FALSE] [set annual-roots-list lput file-read annual-roots-list]
  file-close

  file-open "grains.txt"
  set grains-list []
  while [file-at-end? = FALSE] [set grains-list lput file-read grains-list]
  file-close

  file-open "pulses.txt"
  set pulses-list []
  while [file-at-end? = FALSE] [set pulses-list lput file-read pulses-list]
  file-close

  file-open "per-roots.txt"
  set per-roots-list []
  while [file-at-end? = FALSE] [set per-roots-list lput file-read per-roots-list]
  file-close

  file-open "veg.txt"
  set veg-list []
  while [file-at-end? = FALSE] [set veg-list lput file-read veg-list]
  file-close

  file-open "fruits.txt"
  set fruits-list []
  while [file-at-end? = FALSE] [set fruits-list lput file-read fruits-list]
  file-close

  file-open "cash.txt"
  set cash-list []
  while [file-at-end? = FALSE] [set cash-list lput file-read cash-list]
  file-close

  file-open "meat.txt"
  set meat-list []
  while [file-at-end? = FALSE] [set meat-list lput file-read meat-list]
  file-close

  file-open "egg.txt"
  set egg-list []
  while [file-at-end? = FALSE] [set egg-list lput file-read egg-list]
  file-close

  file-open "milk.txt"
  set milk-list []
  while [file-at-end? = FALSE] [set milk-list lput file-read milk-list]
  file-close

  file-open "tlu.txt"
  set tlu-list []
  while [file-at-end? = FALSE] [set tlu-list lput file-read tlu-list]
  file-close

  set ag-wage 1.23
  set nag-wage 0.2
  set value-anroots 0.33623
  set value-grains 0.22532355
  set value-pulses 1.0913
  set value-peroots 0.35451
  set value-veg 1.540909
  set value-fruit 0.6876376
  set value-cash 0.9254538
  set value-meat 3.630116
  set value-egg 1.624998
  set value-milk 0.5675426
  set value-tlu 1.1264896
  set value-s-inorg-fert 0.07
  set value-s-pesticide 0.07

  ; POLICY
  set p1-access 58.9
  set p2-access 41.8
  set p3-access 58.1
  set p1-coupon-use 0.93
  set p2-coupon-use 0.96
  set p3-coupon-use 0.96
  set pw1-access 0.022
  set pw2-access 0.025
  set pw3-access 0.03

  set prop-h1-defic 0
  set prop-h2-defic 0
  set prop-h3-defic 0
end

to define-patches
  ; characterise patches
  ; patch-type
  ; 1 = forest, 2 = farm plot, 3 = dimba,  4 = water, 5 = other (no data patch)
  file-open "p-patchtype-116.txt"
  foreach sort patches [ask ? [set patch-type file-read]]
  file-close

  let sort-patches-one sort patches with [patch-type = 1]
  let sort-patches-two sort patches with [patch-type = 2]
  let sort-patches-three sort patches with [patch-type = 3]
  let sort-patches-four sort patches with [patch-type = 4]
  let sort-patches-five sort patches with [patch-type = 5]

  ; patch-id
  file-open "p-patchid-116.txt"
  foreach sort patches [ask ? [set patch-id file-read]]
  file-close

  ; owner-id  : read external file to define owner
  file-open "p-owner-id2-116.txt"
  foreach sort-patches-two [ask ? [set owner-id  file-read]]
  file-close

  file-open "p-owner-id3-116.txt"
  foreach sort-patches-three [ask ? [set owner-id  file-read]]
  file-close

  foreach sort-patches-one [ask ? [set owner-id 0]]
  foreach sort-patches-four [ask ? [set owner-id 0]]
  foreach sort-patches-five [ask ? [set owner-id 0]]

  ; patch-area : read external file to define patch area
  file-open "p-patch-area1-116.txt"
  foreach sort-patches-one [ask ? [set patch-area file-read]]
  file-close

  file-open "p-patch-area2-116.txt"
  foreach sort-patches-two [ask ? [set patch-area file-read]]
  file-close

  file-open "p-patch-area3-116.txt"
  foreach sort-patches-three [ask ? [set patch-area file-read]]
  file-close

  file-open "p-patch-area4-116.txt"
  foreach sort-patches-four [ask ? [set patch-area file-read]]
  file-close

  foreach sort-patches-five [ask ? [set patch-area 0]]

  ; fruit stand

  file-open "p-fruit-stand2-116.txt"
  foreach sort-patches-two [ask ? [set fruit-stand file-read]]
  file-close

  file-open "p-fruit-stand3-116.txt"
  foreach sort-patches-three [ask ? [set fruit-stand file-read]]
  file-close

  foreach sort-patches-one [ask ? [set fruit-stand "FALSE"]]
  foreach sort-patches-four [ask ? [set fruit-stand "FALSE"]]
  foreach sort-patches-five [ask ? [set fruit-stand "FALSE"]]

  ; cash crops
  file-open "p-past-cash-crops2-116.txt"
  foreach sort-patches-two [ask ? [set cash-stand file-read]]
  file-close

  file-open "p-past-cash-crops3-116.txt"
  foreach sort-patches-three [ask ? [set cash-stand file-read]]
  file-close

  foreach sort-patches-one [ask ? [set cash-stand 0]]
  foreach sort-patches-four [ask ? [set cash-stand 0]]
  foreach sort-patches-five [ask ? [set cash-stand 0]]

   ask patches
  [
    if patch-cover-type = 0 [set land-fallow TRUE]
    set labour-accum 0
    set patch-inorg-fert 0
    set patch-org-fert 0
    set patch-pesticide 0
    set fruit-stand-age 0          ; need to add in fruit-stand-age

    ; EXPECTED YIELD
    set harvest-time FALSE
    set i-labour 0
    set p-yield 0
    set patch-output 0
  ]
end

to define-individuals
  ;create and characterise individuals
  create-individuals num-individuals
  ask individuals [hide-turtle]

  ;family-id: read external file to define family-id
  file-open "i-hv-family-id-116.txt"
  foreach sort individuals [ask ? [set family-id file-read] ]
  file-close

  ; status: read external file to define status
  file-open "i-status-116.txt"
  foreach sort individuals [ask ? [set status file-read] ]
  file-close

  ; gender: read external file to define status
  file-open "i-gender-116.txt"
  foreach sort individuals [ask ? [set gender file-read] ]
  file-close

  ;age: read file to define age of each individual
  file-open "i-age-116.txt"
  foreach sort individuals [ask ? [set age file-read] ]
  file-close

  ;edu-level: read file to define education level of each individual
  file-open "i-edu-116.txt"
  foreach sort individuals [ask ? [set edu-level file-read] ]
  file-close

  ;illness: read file to define whether the individual is ill or not
  file-open "i-ill-116.txt"
  foreach sort individuals [ask ? [set illness file-read] ]
  file-close

  ask individuals [
    set ideal-calories 0
    set sim-age 1
    ]
  end

to define-households
  ; create and characterise households
  set-default-shape households "circle"
  create-households num-households

  ;ATTRIBUTES
  ;Id: read external file to define the ID of each household
  file-open "hh-id-116.txt"
  foreach sort households [ask ? [set hh-id file-read] ]
  file-close

  ;Household type: read external file to define household type (1, 2 or 3)
  file-open "hh-type-116.txt"
  foreach sort households [ask ? [set hh-type  file-read] ]
  file-close

  ;Capital: read external file to set household capital
  file-open "hh-capital-116.txt"
  foreach sort households [ask ? [set hh-capital file-read] ]
  file-close

  ;Chickens owned: read external file to set number of chickens owned
  file-open "hh-chickens-116.txt"
  foreach sort households [ask ? [set chickens-owned file-read] ]
  file-close

  ;Goats owned: read external file to set number of goats owned
  file-open "hh-goats-116.txt"
  foreach sort households [ask ? [set goats-owned file-read] ]
  file-close

 ; cattle owned: read external file to set number of cattle owned
  file-open "hh-cattle-116.txt"
  foreach sort households [ask ? [set cattle-owned file-read] ]
  file-close

  ask households
  [
    ; ATTRIBUTES
    set past-capital hh-capital
    set new-ind 0
    set sim-age 1
    set hh-member individuals with [family-id = [hh-id] of myself]
    set hh-head individuals with [family-id = [hh-id] of myself and status = 1]
    set hh-size count hh-member
    let edu [edu-level] of hh-head
    set hh-edu-level item 0 edu
    let gend [gender] of hh-head
    set hh-gender item 0 gend
    set my-farm patches with [ owner-id  = [hh-id] of myself]
    set social-net link-neighbors
    set hh-land-area sum [patch-area] of my-farm
    set t-labour 0
    set labour-pool 0
    set hh-inputs 0
    set hh-inorg-fert 0
    set hh-pesticide 0
    set firewood-stock 0
    set water-stock 0

    ; BASIC NEEDS
    set met-food-needs 1
    set hh-fire-cons 0
    set hh-water-cons 0
    set hh-food-needs 0

    ; CAPABILITY TO BE FOOD SECURE
    set food-availability 0
    set food-access 0
    set food-utilisation 0
    set food-stability 0
    set food-security 0
    set diet-diversity 0

    ; LABOUR ALLOCATION
    set agri-priority [ ]
    set fw-labour 0
    set w-labour 0
    set fh-labour 0
    set fo-labour 0
    set na-labour 0
    set farming-lab 0
    set livs-lab 0

    ; COLLECT FIREWOOD
    set ex-level (past-growth / count individuals) * hh-size
    set resource-array array:from-list n-values 10 [0]
    set res-list []
    set norm-list []
    set max-res 0
    set min-res 0
    set act-extract 0
    ; C(x) consumption
    set resource-extract 0
    set opt-extract  0
    set consumption 0
    ; L(x) leisure
    set leisure 0
    set col-time 0
    if hh-type = 1 [set t-min 0.7]
    if hh-type = 2 [set t-min 1.3]
    if hh-type = 3 [set t-min 0.8]
    ; A(x) adherence
    set r  0.5
    set rules 0
    set norms 0
    set past-resource-ex normal (0.16 * hh-size) 0.02
    set adherence 0
    set av-ex 0
    ; U(X) utility
    set past-utility  0
    set utility 0
    set utility-list []

    ; COLLECT WATER
     set w-resource-array array:from-list n-values 10 [0]
    set w-res-list []
    set w-norm-list []
    set w-max-res 0
    set w-min-res 0
    set w-act-extract 0
    ; C(x) consumption
    set w-resource-extract 0
    set w-opt-extract  0
    set hh-water-cons 0
    set w-consumption 0
    ; L(x) leisure
    set w-leisure 0
    set w-col-time 0
    if hh-type = 1 [set w-t-min 0.57]
    if hh-type = 2 [set w-t-min 0.61]
    if hh-type = 3 [set w-t-min 0.68]
    ; A(x) adherence
    set w-r  0.2
    set w-rules 0
    set w-norms 0
    set w-past-resource-ex normal (w-req-water * hh-size) 0.02
    set w-adherence 0
    ; U(X) utility
    set w-past-utility  0
    set w-utility 0
    set w-utility-list []

    ; ACQUIRE INPUTS
    set coupon-n 0
    set coupon-type 0

    ; FARMING
    set month-lab 0
    set fh-labour 0
    set fo-labour 0
    set na-labour 0

    set hh-sub-req FALSE
    set hh-cash-labour FALSE
    set hh-cash-land FALSE
    set hh-cash-know FALSE
    set hh-tree-land FALSE
    set hh-tree-labour FALSE
    set hh-tree-know FALSE
    set hh-food-labour FALSE
    set get-labour FALSE

    set allo-grains 0
    set allo-nuts-pulses 0
    set allo-annual-roots 0
    set allo-perm-roots 0
    set allo-vegetables 0
    set allo-fruits 0
    set allo-cash-crops 0
    set allo-fallow 0

    set past-grains 0
    set past-nuts-pulses 0
    set past-annual-roots 0
    set past-perm-roots 0
    set past-vegetables 0
    let past-cash 0
    foreach sort my-farm [ask ? [ if cash-stand = 1 [set past-cash past-cash + 1]]]
    set past-cash-crops past-cash
    let past-fruities 0
    foreach sort my-farm [ask ? [ if fruit-stand = "TRUE" [set past-fruities past-fruities + 1]]]
    set past-fruits past-fruities

    set labour-grains 0
    set labour-nuts-pulses 0
    set labour-annual-roots 0
    set labour-perm-roots 0
    set labour-vegetables 0
    set labour-fruits 0
    set labour-cash-crops 0

    set lg 0
    set lnp 0
    set lf 0
    set lpr 0

    set out-anroots 0
    set out-grains 0
    set out-pulses 0
    set out-peroots 0
    set out-veg 0
    set out-fruit 0
    set out-cash 0

    set eat-anroots 0
    set sell-anroots 0
    set lost-anroots 0

    set eat-grains 0
    set sell-grains 0
    set lost-grains 0

    set eat-pulses 0
    set sell-pulses 0
    set lost-pulses 0

    set eat-peroots 0
    set sell-peroots 0
    set lost-peroots 0

    set eat-veg 0
    set sell-veg 0
    set lost-veg 0

    set eat-fruit 0
    set sell-fruit 0
    set lost-fruit 0

    set eat-cash-crops 0
    set sell-cash-crops 0
    set lost-cash-crops 0

    set jan-out []
    set feb-out []
    set mar-out []
    set apr-out []
    set may-out []
    set jun-out []
    set jul-out []
    set aug-out []
    set sep-out []
    set oct-out []
    set nov-out []
    set dec-out []

    ; LIVESTOCK
    set tlu 0
    set tlu-growth 0
    set meat-output 0
    set egg-output  0
    set milk-output 0
    set manure-output 0

    set eat-meat 0
    set sell-meat 0
    set lost-meat 0

    set eat-egg 0
    set sell-egg 0
    set lost-egg 0

    set eat-milk 0
    set sell-milk 0
    set lost-milk 0

    ; FORAGING
    set eat-forage-veg 0
    set eat-forage-fruit 0

    ; OFF-FARM NON-AGRICULTURAL WORK
    set off-nonag-output 0

    ; SPENDING CAPACITY
    set m-nonf-expense 0
    set spending-cap 0
    set spending-cal 0

    ; FOOD AVAILABILITY
    set calorie-pool 0
    set calorie-deficit 0


    ; COPING STRATEGIES
    set pwp-calories 0
    set n-food-request 0
    set borrow-food 0

    set sale-livestock 0

    ; DIET
    set cereals 0
    set fruits 0
    set meats 0
    set milks 0
    set nuts 0
    set roots 0
    set vegs 0
    set forages 0

    ; PRODUCTIVE STABILITY
    set hh-prod-stability 0

   ; FOOD SECURITY STATUS
   set availability-status 0
   set access-status 0
   set daily-fecpc 0
   set hh-prop-staples 0

   set crop-sales 0

   set farm-work 0
   set agri-work 0
   set n-agri-work 0
  ]
end

to define-small-world
  ask households [assign-family]
  layout-circle (sort-by [[family] of ?1 < [family] of ?2] households) max-pxcor - 1
  ask households
  [
    set hidden? true
    facexy 0 0
    set size 0.5
    if who mod 2 = 0 [fd 4]
  ]
  create-links
  rewire-links
end

to compute-metrics
  compute-cluster-coefficient
  compute-avpath
  compute-degree
end

to assign-family
   set family random (num-families)
   set color  family
end

to create-links
  let n (num-individuals + 1)
  while [n < (num-individuals + num-households)]
  [
    ;; make link with one of the same family
    ;; this makes a lattice with average degree of ??
    ;repeat num-close-hh
    repeat num-households / num-families
    [let b one-of households with [family = [family] of household n]
      if b != household n
      [make-link-between household n b ]
      ]
    ;;this adds one link to a a friend hh that is not of the big family (similar to rewiring)
    ;let c one-of households with [family != [family] of turtle n]
    ;make-link-between turtle n
    ;           c
    ;; separate the clusters
    layout-spring households links 0.2 4 0.9
    display
    set n n + 1
    ]
  compute-metrics
  end

;; connects the two nodes
to make-link-between [node1 node2]
  ask node1 [
    create-link-with node2
      [
        set hidden? true
        set color gray + 1.5]
  ]
end

to rewire-links
  ;; WARNING: the simplified rewiring algorithm does not certain checks (ie disconnected graph)
  ;; for large networksthis shouldn't be too much of an issue.
  ask links
  [
    ;; whether to rewire it or not?
    if (random-float 1) < rewiring-probability
    [
      ask end1
      [
        create-link-with one-of other households with [not link-neighbor? myself ]
           [
             set hidden? true
             set color 17
             ]
           ]
      die
      ]
    ]
  compute-metrics
end

to compute-cluster-coefficient
  set num-qualifying-nodes 0
  set clust-coeff-sum 0

ask households [
  set tot-links 0
  set num-neighbors count link-neighbors
  set current-node self
  ask link-neighbors
  [
     set tot-links (tot-links + count link-neighbors with [link-neighbor? current-node])
  ]
  if (num-neighbors > 1)
  [
    set clust-coeff-sum (clust-coeff-sum + (tot-links / (num-neighbors * (num-neighbors - 1))))
    set num-qualifying-nodes num-qualifying-nodes + 1
    ]
  ]
set clustering-coefficient (clust-coeff-sum / num-qualifying-nodes)
end

to compute-avpath
  nw:set-context households links
  set average-path-length nw:mean-path-length
end

to compute-degree
   nw:set-context households links
   set average-degree count links / count households
end

to define-social-net
  ask households
  [
  set social-net households with [not link-neighbor? myself]
  ]
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; SEASONALITY                          ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to set-random-sort
  ask households
  [
    set rand-sort pick-random
  ]
end

to define-month
  ; divide seasons into 12 months according to ticks
  if (ticks  = 1) or (ticks = 13) or (ticks = 25) or (ticks = 37) or (ticks = 49) or (ticks = 61) or (ticks = 73) or (ticks = 85) or (ticks = 97) or (ticks = 109)
  or (ticks  = 121) or (ticks = 133) or (ticks = 145) or (ticks = 157) or (ticks = 169) or (ticks = 181) or (ticks = 193) or (ticks = 205) or (ticks = 217) or (ticks = 229)
  or (ticks  = 241) or (ticks = 253) or (ticks = 265) or (ticks = 277) or (ticks = 289) or (ticks = 301) or (ticks = 313) or (ticks = 325) or (ticks = 337) or (ticks = 349)
  or (ticks  = 361) or (ticks = 373) or (ticks = 385) or (ticks = 397) or (ticks = 409) or (ticks = 421) or (ticks = 433) or (ticks = 445) or (ticks = 457) or (ticks = 469)
  [
    set month "Jun"
  ]
  if (ticks = 2) or (ticks = 14) or (ticks = 26) or (ticks = 38) or (ticks = 50) or (ticks = 62) or (ticks = 74) or (ticks = 86) or (ticks = 98) or (ticks = 110)
  or (ticks  = 122) or (ticks = 134) or (ticks = 146) or (ticks = 158) or (ticks = 170) or (ticks = 182) or (ticks = 194) or (ticks = 206) or (ticks = 218) or (ticks = 230)
  or (ticks  = 242) or (ticks = 254) or (ticks = 266) or (ticks = 278) or (ticks = 290) or (ticks = 302) or (ticks = 314) or (ticks = 326) or (ticks = 338) or (ticks = 350)
  or (ticks  = 362) or (ticks = 374) or (ticks = 386) or (ticks = 398) or (ticks = 410) or (ticks = 422) or (ticks = 434) or (ticks = 446) or (ticks = 458) or (ticks = 470)
  [
    set month "Jul"
  ]
  if (ticks = 3) or (ticks = 15) or (ticks = 27) or (ticks = 39) or (ticks = 51) or (ticks = 63) or (ticks = 75) or (ticks = 87) or (ticks = 99) or (ticks = 111)
  or (ticks  = 123) or (ticks = 135) or (ticks = 147) or (ticks = 159) or (ticks = 171) or (ticks = 183) or (ticks = 195) or (ticks = 207) or (ticks = 219) or (ticks = 231)
  or (ticks  = 243) or (ticks = 255) or (ticks = 267) or (ticks = 279) or (ticks = 291) or (ticks = 303) or (ticks = 315) or (ticks = 327) or (ticks = 339) or (ticks = 351)
  or (ticks  = 363) or (ticks = 375) or (ticks = 387) or (ticks = 399) or (ticks = 411) or (ticks = 423) or (ticks = 435) or (ticks = 447) or (ticks = 459) or (ticks = 471)
  [
    set month "Aug"
  ]
  if (ticks = 4) or (ticks = 16) or (ticks = 28) or (ticks = 40) or (ticks = 52) or (ticks = 64) or (ticks = 76) or (ticks = 88) or (ticks = 100) or (ticks = 112)
  or (ticks  = 124) or (ticks = 136) or (ticks = 148) or (ticks = 160) or (ticks = 172) or (ticks = 184) or (ticks = 196) or (ticks = 208) or (ticks = 220) or (ticks = 232)
  or (ticks  = 244) or (ticks = 256) or (ticks = 268) or (ticks = 280) or (ticks = 292) or (ticks = 304) or (ticks = 316) or (ticks = 328) or (ticks = 340) or (ticks = 352)
  or (ticks  = 364) or (ticks = 376) or (ticks = 388) or (ticks = 400) or (ticks = 412) or (ticks = 424) or (ticks = 436) or (ticks = 448) or (ticks = 460) or (ticks = 472)
  [
    set month "Sep"
  ]
  if (ticks = 5) or (ticks = 17) or (ticks = 29) or (ticks = 41) or (ticks = 53) or (ticks = 65) or (ticks = 77) or (ticks = 89) or (ticks = 101) or (ticks = 113)
  or (ticks  = 125) or (ticks = 137) or (ticks = 149) or (ticks = 161) or (ticks = 173) or (ticks = 185) or (ticks = 197) or (ticks = 209) or (ticks = 221) or (ticks = 233)
  or (ticks  = 245) or (ticks = 257) or (ticks = 269) or (ticks = 281) or (ticks = 293) or (ticks = 305) or (ticks = 317) or (ticks = 329) or (ticks = 341) or (ticks = 353)
  or (ticks  = 365) or (ticks = 377) or (ticks = 389) or (ticks = 401) or (ticks = 413) or (ticks = 425) or (ticks = 437) or (ticks = 449) or (ticks = 461) or (ticks = 473)
  [
    set month "Oct"
  ]
  if (ticks = 6) or (ticks = 18) or (ticks = 30) or (ticks = 42) or (ticks = 54) or (ticks = 66) or (ticks = 78) or (ticks = 90) or (ticks = 102) or (ticks = 114)
  or (ticks  = 126) or (ticks = 138) or (ticks = 150) or (ticks = 162) or (ticks = 174) or (ticks = 186) or (ticks = 198) or (ticks = 210) or (ticks = 222) or (ticks = 234)
  or (ticks  = 246) or (ticks = 258) or (ticks = 270) or (ticks = 282) or (ticks = 294) or (ticks = 306) or (ticks = 318) or (ticks = 330) or (ticks = 342) or (ticks = 354)
  or (ticks  = 366) or (ticks = 378) or (ticks = 390) or (ticks = 402) or (ticks = 414) or (ticks = 426) or (ticks = 438) or (ticks = 450) or (ticks = 462) or (ticks = 474)
  [
    set month "Nov"
  ]
  if (ticks = 7) or (ticks = 19) or (ticks = 31) or (ticks = 43) or (ticks = 55) or (ticks = 67) or (ticks = 79) or (ticks = 91) or (ticks = 103) or (ticks = 115)
  or (ticks  = 127) or (ticks = 139) or (ticks = 151) or (ticks = 163) or (ticks = 175) or (ticks = 187) or (ticks = 199) or (ticks = 211) or (ticks = 223) or (ticks = 235)
  or (ticks  = 247) or (ticks = 259) or (ticks = 271) or (ticks = 283) or (ticks = 295) or (ticks = 307) or (ticks = 319) or (ticks = 331) or (ticks = 343) or (ticks = 355)
  or (ticks  = 367) or (ticks = 379) or (ticks = 391) or (ticks = 403) or (ticks = 415) or (ticks = 427) or (ticks = 439) or (ticks = 451) or (ticks = 463) or (ticks = 475)
  [
    set month "Dec"
  ]
  if (ticks = 8) or (ticks = 20) or (ticks = 32) or (ticks = 44) or (ticks = 56) or (ticks = 68) or (ticks = 80) or (ticks = 92) or (ticks = 104) or (ticks = 116)
  or (ticks  = 128) or (ticks = 140) or (ticks = 152) or (ticks = 164) or (ticks = 176) or (ticks = 188) or (ticks = 200) or (ticks = 212) or (ticks = 224) or (ticks = 236)
  or (ticks  = 248) or (ticks = 260) or (ticks = 272) or (ticks = 284) or (ticks = 296) or (ticks = 308) or (ticks = 320) or (ticks = 332) or (ticks = 344) or (ticks = 356)
  or (ticks  = 368) or (ticks = 380) or (ticks = 392) or (ticks = 404) or (ticks = 416) or (ticks = 428) or (ticks = 440) or (ticks = 452) or (ticks = 464) or (ticks = 476)
  [
    set month "Jan"
  ]
  if (ticks = 9) or (ticks = 21) or (ticks = 33) or (ticks = 45) or (ticks = 57) or (ticks = 69) or (ticks = 81) or (ticks = 93) or (ticks = 105) or (ticks = 117)
  or (ticks  = 129) or (ticks = 141) or (ticks = 153) or (ticks = 165) or (ticks = 177) or (ticks = 189) or (ticks = 201) or (ticks = 213) or (ticks = 225) or (ticks = 237)
  or (ticks  = 249) or (ticks = 261) or (ticks = 273) or (ticks = 285) or (ticks = 297) or (ticks = 309) or (ticks = 321) or (ticks = 333) or (ticks = 345) or (ticks = 357)
  or (ticks  = 369) or (ticks = 381) or (ticks = 393) or (ticks = 405) or (ticks = 417) or (ticks = 429) or (ticks = 441) or (ticks = 453) or (ticks = 465) or (ticks = 477)
  [
    set month "Feb"
  ]
  if (ticks = 10) or (ticks = 22) or (ticks = 34) or (ticks = 46) or (ticks = 58) or (ticks = 70) or (ticks = 82) or (ticks = 94) or (ticks = 106) or (ticks = 118)
  or (ticks  = 130) or (ticks = 142) or (ticks = 154) or (ticks = 166) or (ticks = 178) or (ticks = 190) or (ticks = 202) or (ticks = 214) or (ticks = 226) or (ticks = 238)
  or (ticks  = 250) or (ticks = 262) or (ticks = 274) or (ticks = 286) or (ticks = 298) or (ticks = 310) or (ticks = 322) or (ticks = 334) or (ticks = 346) or (ticks = 358)
  or (ticks  = 370) or (ticks = 382) or (ticks = 394) or (ticks = 406) or (ticks = 418) or (ticks = 430) or (ticks = 442) or (ticks = 454) or (ticks = 466) or (ticks = 478)
  [
    set month "Mar"
  ]
  if (ticks = 11) or (ticks = 23) or (ticks = 35) or (ticks = 47) or (ticks = 59) or (ticks = 71) or (ticks = 83) or (ticks = 95) or (ticks = 107) or (ticks = 119)
  or (ticks  = 131) or (ticks = 143) or (ticks = 155) or (ticks = 167) or (ticks = 179) or (ticks = 191) or (ticks = 203) or (ticks = 215) or (ticks = 227) or (ticks = 239)
  or (ticks  = 251) or (ticks = 263) or (ticks = 275) or (ticks = 287) or (ticks = 299) or (ticks = 311) or (ticks = 323) or (ticks = 335) or (ticks = 347) or (ticks = 359)
  or (ticks  = 371) or (ticks = 383) or (ticks = 395) or (ticks = 407) or (ticks = 419) or (ticks = 431) or (ticks = 443) or (ticks = 455) or (ticks = 467) or (ticks = 479)
  [
    set month "Apr"
  ]
  if (ticks = 12) or (ticks = 24) or (ticks = 36) or (ticks = 48) or (ticks = 60) or (ticks = 72) or (ticks = 84) or (ticks = 96) or (ticks = 108) or (ticks = 120)
  or (ticks  = 132) or (ticks = 144) or (ticks = 156) or (ticks = 168) or (ticks = 180) or (ticks = 192) or (ticks = 204) or (ticks = 216) or (ticks = 228) or (ticks = 240)
  or (ticks  = 252) or (ticks = 264) or (ticks = 276) or (ticks = 288) or (ticks = 300) or (ticks = 312) or (ticks = 324) or (ticks = 336) or (ticks = 348) or (ticks = 360)
  or (ticks  = 372) or (ticks = 384) or (ticks = 396) or (ticks = 408) or (ticks = 420) or (ticks = 432) or (ticks = 444) or (ticks = 456) or (ticks = 468) or (ticks = 480)
  [
    set month "May"
  ]
end

to define-year
  if month = "Jan" [
    set year year + 1
    set annual-rain (item (year - 1) annual-rain-list)
    ]
end

to define-season-start             ; the agricultural season starts in June
  ifelse month = "Jun"
  [set season-start TRUE]
  [set season-start FALSE]
end

to define-season-end
  ifelse month = "May"
  [set season-end TRUE]
  [set season-end FALSE]
end


to define-agri-season               ; the agricultural season is divided into wet and dry
  ifelse (month = "Apr") or (month = "May") or (month = "Jun") or (month = "Jul") or (month = "Aug") or (month = "Sep") or (month = "Oct")
  [set agri-type "Dry"]
  [set agri-type "Wet"]
end

to set-coupon-month
  if season-start = TRUE
  [
    let cm random-float 100
    if cm <= 0.7 [ set coupon-month "Aug"]
    if cm > 0.7 and cm <= 5.6 [set coupon-month "Sep"]
    if cm > 5.6 and cm <= 63.2 [set coupon-month "Oct"]
    if cm > 63.2 and cm <= 98.1 [set coupon-month "Nov"]
    if cm > 98.1 and cm <= 100 [set coupon-month "Dec"]
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;
; MARKETS               ;
;;;;;;;;;;;;;;;;;;;;;;;;;

to set-market-value
  if year > 1 [
    set value-anroots item (year - 2) annual-roots-list
    set value-grains item (year - 2) grains-list
    set value-pulses item (year - 2) pulses-list
    set value-peroots item (year - 2) per-roots-list
    set value-veg item (year - 2) veg-list
    set value-fruit item (year - 2) fruits-list
    set value-cash item (year - 2) cash-list
    set value-meat item (year - 2) meat-list
    set value-egg item (year - 2) egg-list
    set value-milk item (year - 2) milk-list
    set value-tlu item (year - 2) tlu-list
    set value-s-inorg-fert 10
    set value-s-pesticide 10
  ]
  set grain-stability lput value-grains grain-stability
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; HOUSEHOLD ACTIVITIES                 ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; BASIC NEEDS

to calc-food-needs        ; calcualte monthly household energy requirements - based on recommended values for light activity published in Smith & Subandoro (2007)
  ask individuals
  [
    if age <= 1 [set ideal-calories 820]
    if age > 1 and age <= 2 [set ideal-calories 1150]
    if age > 2 and age <= 3 [set ideal-calories 1350]
    if age > 3 and age <= 5 [set ideal-calories 1550]

    if age > 5 and age <= 7 and gender = 1 [set ideal-calories 1850]
    if age > 7 and age <= 10 and gender = 1 [set ideal-calories 2100]
    if age > 10 and age <= 12 and gender = 1 [set ideal-calories 2200]
    if age > 12 and age <= 14 and gender = 1 [set ideal-calories 2400]
    if age > 14 and age <= 16 and gender = 1 [set ideal-calories 2650]
    if age > 16 and age <= 18 and gender = 1 [set ideal-calories 2850]

    if age > 5 and age <= 7 and gender = 0 [set ideal-calories 1750]
    if age > 7 and age <= 10 and gender = 0 [set ideal-calories 1800]
    if age > 10 and age <= 12 and gender = 0 [set ideal-calories 1950]
    if age > 12 and age <= 14 and gender = 0 [set ideal-calories 2100]
    if age > 14 and age <= 16 and gender = 0 [set ideal-calories 2150]
    if age > 16 and age <= 18 and gender = 0 [set ideal-calories 2150]

    if age > 18 and age <= 30 and gender = 1 [set ideal-calories 2600]
    if age > 30 and age <= 60 and gender = 1 [set ideal-calories 2500]
    if age > 60 and gender = 1 [set ideal-calories 2100]

    if age > 18 and age <= 30 and gender = 0 [set ideal-calories 2000]
    if age > 30 and age <= 60 and gender = 0 [set ideal-calories 2050]
    if age > 60 and gender = 0 [set ideal-calories 1850]
  ]

  ask households
  [
   set hh-food-needs (sum [ideal-calories] of hh-member) * 30 ; calculate monthly food needs for the household
  ]
end


to calc-water-needs
  ask households
  [
    set hh-water-cons hh-size * w-req-water
  ]
end

to calc-fuel-needs
  ask households
  [
    set hh-needs ((hh-size * req-energy) / (e-cont * density))
    set hh-fire-cons  hh-needs - firewood-stock
  ]
end


;LABOUR
to allocate-labour
  ask individuals
  [
    ; first calculate total labour for month (in hrs)
    ; this is based upon individual age, gender and health
    let l-type [hh-type] of households with [hh-id  = [family-id] of myself]
    let i-type item 0 l-type
    if i-type = 1
    [
      if age > 15 and age < 65 and gender = 1 and illness = "FALSE"
      [set  ind-labour 80]
      if age > 15 and age < 65 and gender = 1 and illness = "TRUE"
      [set ind-labour 78]
      if age > 9 and age < 65 and gender = 0 and illness = "FALSE"
      [set ind-labour 100]
      if age > 9 and age < 65  and gender = 0 and illness = "TRUE"
      [set ind-labour  88]
    ]
    if i-type = 2
    [
      if age > 15 and age < 65 and gender = 1 and illness = "FALSE"
      [set ind-labour  81]
      if age > 15 and age < 65 and gender = 1 and illness = "TRUE"
      [set ind-labour  87]
      if age > 9 and age < 65 and gender = 0 and illness = "FALSE"
      [set ind-labour  91]
      if age > 9 and age < 65  and gender = 0 and illness = "TRUE"
      [set ind-labour  90]
    ]
    if i-type = 3
    [
      if age > 15 and age < 65 and gender = 1 and illness = "FALSE"
      [set ind-labour  115]
      if age > 15 and age < 65 and gender = 1 and illness = "TRUE"
      [set ind-labour  141]
      if age > 9 and age < 65 and gender = 0 and illness = "FALSE"
      [set ind-labour  89]
      if age > 9 and age < 65  and gender = 0 and illness = "TRUE"
      [set ind-labour 92]
    ]
  ]
  ask households
      [
      ; total labour of indivual household members
      set t-labour sum  [ind-labour] of individuals with [family-id = [hh-id] of myself]
      ; then calculate the proportion of time spent by the household on
      ; on-farm, off-farm-ag, off-farm non-ag and household
      ; proportions will come from IHS3 data
       if hh-type  = 1 and month = "Jan"
       [
         set fw-labour 0.06  * t-labour       ; labour for firewood collection
         set w-labour 0.15  * t-labour        ; labour for water collection
         set fh-labour 0.72  * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.05  * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.03  * t-labour       ; labour for off-farm non-agricultural work
         ]
       if hh-type  = 1 and month = "Feb"
       [
         set fw-labour 0.08  * t-labour       ; labour for firewood collection
         set w-labour 0.19  * t-labour        ; labour for water collection
         set fh-labour 0.69 * t-labour        ; labour for on-farm agricultural activities
         set fo-labour 0.03 * t-labour        ; labour for off-farm agricutural work
         set na-labour 0.01 * t-labour        ; labour for off-farm non-agricultural work
         ]
       if hh-type  = 1 and month = "Mar"
       [
         set fw-labour 0.07  * t-labour       ; labour for firewood collection
         set w-labour 0.22  * t-labour        ; labour for water collection
         set fh-labour 0.68 * t-labour        ; labour for on-farm agricultural activities
         set fo-labour 0.02 * t-labour        ; labour for off-farm agricutural work
         set na-labour 0.01 * t-labour        ; labour for off-farm non-agricultural work
         ]
       if hh-type  = 1 and month = "Apr"
       [
         set fw-labour 0.11  * t-labour       ; labour for firewood collection
         set w-labour 0.23  * t-labour        ; labour for water collection
         set fh-labour 0.62 * t-labour        ; labour for on-farm agricultural activities
         set fo-labour 0.03 * t-labour        ; labour for off-farm agricutural work
         set na-labour 0.01 * t-labour        ; labour for off-farm non-agricultural work
         ]
        if hh-type  = 1 and month = "May"
         [
           set fw-labour 0.12  * t-labour      ; labour for firewood collection ;0.12
           set w-labour 0.26  * t-labour       ; labour for water collection
           set fh-labour 0.58 * t-labour       ; labour for on-farm agricultural activities
           set fo-labour 0.02 * t-labour       ; labour for off-farm agricutural work
           set na-labour 0.03 * t-labour       ; labour for off-farm agricultural work
           ]
         if hh-type  = 1 and month = "Jun"
         [
           set fw-labour 0.09  * t-labour       ; labour for firewood collection
           set w-labour 0.23  * t-labour        ; labour for water collection
           set fh-labour 0.62 * t-labour        ; labour for on-farm agricultural activities
           set fo-labour 0.03 * t-labour        ; labour for off-farm agricutural work
           set na-labour 0.03 * t-labour        ; labour for off-farm agricultural work
           ]
         if hh-type  = 1 and month = "Jul"
         [
           set fw-labour 0.11  * t-labour       ; labour for firewood collectio
           set w-labour 0.24  * t-labour        ; labour for water collection
           set fh-labour 0.62 * t-labour       ; labour for on-farm agricultural activities
           set fo-labour 0.02 * t-labour       ; labour for off-farm agricutural work
           set na-labour 0.01 * t-labour       ; labour for off-farm agricultural work
           ]
       if hh-type  = 1 and month = "Aug"
         [
         set fw-labour 0.14  * t-labour       ; labour for firewood collection
         set w-labour 0.23  * t-labour        ; labour for water collection
         set fh-labour 0.59 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.01 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.02 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 1 and month = "Sep"
         [
         set fw-labour 0.10  * t-labour       ; labour for firewood collection
         set w-labour 0.21  * t-labour        ; labour for water collection
         set fh-labour 0.65 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.02 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.03 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 1 and month = "Oct"
         [
         set fw-labour 0.09  * t-labour       ; labour for firewood collection
         set w-labour 0.21  * t-labour        ; labour for water collection
         set fh-labour 0.65 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.02 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.03 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 1 and month = "Nov"
         [
         set fw-labour 0.09  * t-labour       ; labour for firewood collection
         set w-labour 0.19  * t-labour        ; labour for water collection
         set fh-labour 0.64 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.03 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.03 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 1 and month = "Dec"
         [
         set fw-labour 0.06  * t-labour       ; labour for firewood collection
         set w-labour 0.16  * t-labour        ; labour for water collection
         set fh-labour 0.72 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.04 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.02 * t-labour       ; labour for off-farm agricultural work
       ]


       if hh-type  = 2 and month = "Jan"
       [
         set fw-labour 0.07  * t-labour       ; labour for firewood collection
         set w-labour 0.15  * t-labour        ; labour for water collection
         set fh-labour 0.34 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.41 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.02 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 2 and month = "Feb"
         [
         set fw-labour 0.09  * t-labour       ; labour for firewood collection
         set w-labour 0.17  * t-labour        ; labour for water collection
         set fh-labour 0.29 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.44 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.01 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 2 and month = "Mar"
         [
         set fw-labour 0.13  * t-labour       ; labour for firewood collection
         set w-labour 0.26  * t-labour        ; labour for water collection
         set fh-labour 0.23 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.36 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.02 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 2 and month = "Apr"
         [
         set fw-labour 0.11  * t-labour       ; labour for firewood collection
         set w-labour 0.33  * t-labour        ; labour for water collection
         set fh-labour 0.19 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.36 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.01 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 2 and month = "May"
         [
         set fw-labour 0.13  * t-labour       ; labour for firewood collection.         set w-labour 0.23  * t-labour        ; labour for water collection
         set fh-labour 0.16 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.46 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.01 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 2 and month = "Jun"
         [
         set fw-labour 0.12  * t-labour       ; labour for firewood collection
         set w-labour 0.28  * t-labour        ; labour for water collection
         set fh-labour 0.15 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.43 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.01 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 2 and month = "Jul"
         [
         set fw-labour 0.11  * t-labour       ; labour for firewood collection
         set w-labour 0.25  * t-labour        ; labour for water collection
         set fh-labour 0.12 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.48 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.04 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 2 and month = "Aug"
         [
         set fw-labour 0.12  * t-labour       ; labour for firewood collection
         set w-labour 0.27  * t-labour        ; labour for water collection
         set fh-labour 0.21 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.39 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.02 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 1 and month = "Sep"
         [
         set fw-labour 0.14  * t-labour       ; labour for firewood collection
         set w-labour 0.19  * t-labour        ; labour for water collection
         set fh-labour 0.21 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.44 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.01 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 2 and month = "Oct"
         [
         set fw-labour 0.10  * t-labour       ; labour for firewood collection
         set w-labour 0.18  * t-labour        ; labour for water collection
         set fh-labour 0.25 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.42 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.05 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 2 and month = "Nov"
         [
         set fw-labour 0.07  * t-labour       ; labour for firewood collection
         set w-labour 0.15  * t-labour        ; labour for water collection
         set fh-labour 0.32 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.41 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.05 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 2 and month = "Dec"
         [
         set fw-labour 0.13  * t-labour       ; labour for firewood collection
         set w-labour 0.20  * t-labour        ; labour for water collection
         set fh-labour 0.34 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.32 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.00 * t-labour       ; labour for off-farm agricultural work
       ]
         if hh-type  = 3 and month = "Jan"
       [
         set fw-labour 0.04  * t-labour       ; labour for firewood collection
         set w-labour 0.07  * t-labour        ; labour for water collection
         set fh-labour 0.24 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.01 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.64 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 3 and month = "Feb"
         [
         set fw-labour 0.06  * t-labour       ; labour for firewood collection
         set w-labour 0.17  * t-labour        ; labour for water collection
         set fh-labour 0.14 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.01 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.62 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 3 and month = "Mar"
         [
         set fw-labour 0.07  * t-labour       ; labour for firewood collection
         set w-labour 0.19  * t-labour        ; labour for water collection
         set fh-labour 0.13 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.01 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.61 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 3 and month = "Apr"
         [
         set fw-labour 0.20  * t-labour       ; labour for firewood collection
         set w-labour 0.28  * t-labour        ; labour for water collection
         set fh-labour 0.07 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.01 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.45 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 3 and month = "May"
         [
         set fw-labour 0.09  * t-labour       ; labour for firewood collection
         set w-labour 0.18  * t-labour        ; labour for water collection
         set fh-labour 0.11 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.01 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.61 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 3 and month = "Jun"
         [
         set fw-labour 0.09  * t-labour       ; labour for firewood collection
         set w-labour 0.20  * t-labour        ; labour for water collection
         set fh-labour 0.10 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.01 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.60 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 3 and month = "Jul"
         [
         set fw-labour 0.08  * t-labour       ; labour for firewood collection
         set w-labour 0.17  * t-labour        ; labour for water collection
         set fh-labour 0.15 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.04 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.56 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 3 and month = "Aug"
         [
         set fw-labour 0.15  * t-labour       ; labour for firewood collection
         set w-labour 0.20  * t-labour        ; labour for water collection
         set fh-labour 0.10 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.03 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.52 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 3 and month = "Sep"
         [
         set fw-labour 0.11  * t-labour       ; labour for firewood collection
         set w-labour 0.17  * t-labour        ; labour for water collection
         set fh-labour 0.17 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.01 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.54 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 3 and month = "Oct"
         [
         set fw-labour 0.10  * t-labour       ; labour for firewood collection
         set w-labour 0.14  * t-labour        ; labour for water collection
         set fh-labour 0.18 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.01 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.58 * t-labour       ; labour for off-farm agricultural work
       ]
       if hh-type  = 3 and month = "Nov"
         [
         set fw-labour 0.08  * t-labour       ; labour for firewood collection
         set w-labour 0.15  * t-labour        ; labour for water collection
         set fh-labour 0.17 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.02 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.58 * t-labour       ; labour for off-farm non-agricultural work
       ]
       if hh-type  = 3 and month = "Dec"
         [
         set fw-labour 0.03  * t-labour       ; labour for firewood collection
         set w-labour 0.10  * t-labour        ; labour for water collection
         set fh-labour 0.30 * t-labour       ; labour for on-farm agricultural activities
         set fo-labour 0.00 * t-labour       ; labour for off-farm agricutural work
         set na-labour 0.57 * t-labour       ; labour for off-farm agricultural work
       ]
         set farming-lab fh-labour
         set labour-pool labour-pool + fo-labour
      ]
end

; COLLECTING FIREWOOD
to collect-firewood
  set rand-list []
  set area-ha (sum [patch-area] of patches with [patch-type = 1])
  set fr area-ha * biomass
  calc-ex-level
  ask households
  [
    if fw-labour > 0 and fr > 0 [
      ; update availability
      set rand-sort pick-random
      pick-extract ; select a level of resource extraction at random
      foreach norm-list  [
        set resource-extract ?
        ; calculate consumption
        set consumption norm-hh-fire-cons + f-fire * (resource-extract - norm-hh-fire-cons)

        ; calculate leisure
        set gat-t t-min + (fi / fr) ; calculate collection time for a single trip
        let cmax 3 * norm-hh-fire-cons; calculate maximum consumption level: 3 * hh-fire-cons
        let p 30 ; average headload per trip is 27 kg
        set m-gat-t (resource-extract * cmax * (density / p) * gat-t)
        ifelse (m-gat-t <= fw-labour) [set col-time m-gat-t] [ set col-time fw-labour]
        set leisure 1 - (col-time / fw-labour)

        ; calculate adherence
        ifelse (resource-extract > norm-ex-level)
        [set rules 0]
        [set rules 1 - (resource-extract - norm-ex-level)]
        set norms 1 - sqrt((resource-extract - norm-neighbours) ^ 2)
        set adherence (r * rules)  + ((1 - r) * norms)
        ;set adherence rules
        ; calculate utility
        set utility (consumption ^ alpha-c * leisure ^ alpha-l * adherence ^ alpha-a)

        ; check utility against that for previous resource-extract
        if (utility > past-utility)
        [
          set past-utility utility
          set opt-extract resource-extract
          ] ; update past utility with the new higher one and keep resource-extract the same
      ]
      if utility = 0 [set opt-extract min norm-list]
      set act-extract opt-extract * (max-res - min-res) + min-res ; convert normalised value back to actual value
    ]]
    update-firewood
    update-attri
end

to calc-ex-level
 if (ticks = 1) or (ticks = 13) or ( ticks = 25) or (ticks = 37) or (ticks = 49)
  or (ticks = 61) or (ticks = 73) or (ticks = 85) or (ticks = 97) or (ticks = 109)
  or (ticks = 121) or (ticks = 133) or (ticks = 145) or (ticks = 157) or (ticks = 169)
  or (ticks = 181) or (ticks = 193) or (ticks = 205) or (ticks = 217) or (ticks = 229)
  or (ticks = 241) or (ticks = 253) or (ticks = 265) or (ticks = 277) or (ticks = 289)
  or (ticks = 301) or (ticks = 313) or (ticks = 325) or (ticks = 337) or (ticks = 349)
  or (ticks = 361) or (ticks = 373) or (ticks = 385) or (ticks = 397) or (ticks = 409)
  or (ticks = 421) or (ticks = 433) or (ticks = 445) or (ticks = 457) or (ticks = 469)
  [
    let fire-capacity past-growth / count individuals
    ask households
    [
      set ex-level  (fire-capacity * hh-size)
    ]
  ]
end


to pick-extract
  ifelse hh-fire-cons < 0 [set hh-fire-cons 0] [ set hh-fire-cons hh-fire-cons]
  ;ifelse ticks <= 24
  foreach n-values 10 [?] [ array:set resource-array ? (normal past-resource-ex 0.02)]
  set res-list array:to-list resource-array
  set av-ex mean [past-resource-ex] of social-net
  let c-list res-list
  set c-list lput av-ex c-list
  set c-list lput ex-level c-list
  set c-list lput hh-fire-cons c-list
  set max-res max c-list
  set min-res min c-list
  foreach res-list [
    let norm ((? - min-res)/(max-res - min-res))
    set norm-list lput norm norm-list
    ]
  set norm-hh-fire-cons (hh-fire-cons - min-res)/(max-res - min-res)
  set norm-ex-level (ex-level - min-res)/(max-res - min-res)
  set norm-neighbours (av-ex - min-res)/(max-res - min-res)
end

to update-firewood
  let resource-use sum [act-extract] of households
  ; deduct amount extracted from forest
  ifelse (fr - resource-use >= min-fr)
  [
    set fr fr - resource-use
    set biomass fr / area-ha
    ask households [
      set firewood-stock  firewood-stock + act-extract
      set past-resource-ex act-extract
    ]
  ]
  [
    if fr > min-fr
    [
      foreach sort-on [rand-sort] households [ask ? [
          ifelse fr - act-extract >= min-fr
          [
            set firewood-stock firewood-stock + act-extract
            set fr fr - act-extract
            set past-resource-ex act-extract
            set biomass fr / area-ha
            ]
          [
            set firewood-stock firewood-stock + (fr - min-fr)
            set past-resource-ex (fr - min-fr)
            set fr min-fr
            set biomass fr / area-ha

            ]
          ]
      ]
    ]
  ]
  ; allow growth
  let growth 1.0025
  set past-growth (biomass * 0.0025 * area-ha)
  set biomass biomass * growth
  ;set fr area-ha * biomass
end

to update-attri ; update attributes of agents accordingly
  ask households [
    set prop-needs firewood-stock / hh-needs * 100
    set res-list []
    set norm-list []
  ]
end

; COLLECTING WATER
to collect-water
set rand-list []
  ; update availability
  set wr 270000 * n-bore
  w-calc-ex-level
  ask households
  [
    if fw-labour > 0 [
    set water-stock 0
    w-pick-extract ; select a level of resource extraction at random
    foreach w-norm-list [
      set w-resource-extract ?

      ; calculate consumption
      set w-consumption norm-hh-water-cons + f-water * (w-resource-extract - norm-hh-water-cons)


      ; calculate leisure
      ifelse w-labour = 0
      [ set w-leisure 1]
      [
        let w-gat-t w-t-min + ((wi / num-individuals) / (wr / num-individuals)) ; calculate collection time for a single trip
        let cmax 3 * norm-hh-water-cons; calculate maximum consumption level: 3 * hh-water-cons
        let p 20 ; average headload per trip is 20 litres
        let w-m-gat-t (w-resource-extract * cmax  / p * w-gat-t)
        ifelse (w-m-gat-t <= w-labour) [set w-col-time w-m-gat-t] [ set w-col-time w-labour]
        set w-leisure 1 - (w-col-time / w-labour)
      ]

      ; calculate adherence
      ifelse (w-resource-extract > w-norm-ex-level)
      [set w-rules 0]
      [set w-rules 1 - (w-norm-ex-level - w-resource-extract)]
      set w-norms 1 - sqrt((w-resource-extract - norm-neighbours)^ 2)
      set w-adherence (w-r * w-rules) + ((1 - w-r) * w-norms)
      ; calculate utility
      set w-utility (w-consumption ^ w-alpha-c * w-leisure ^ w-alpha-l * w-adherence ^ w-alpha-a)
      ; check utility against that for previous resource-extract
      if (w-utility > w-past-utility)
      [set w-past-utility w-utility
       set w-opt-extract w-resource-extract] ; update past utility with the new higher one and keep resource-extract the same
      ]
    if w-utility = 0 [set w-opt-extract min w-norm-list]
    set w-act-extract w-opt-extract * (w-max-res - w-min-res) + w-min-res ; convert normalised value back to actual value
  ]
  ]
   update-water
   w-update-attri
end

to w-calc-ex-level
   if (ticks = 1) or (ticks = 13) or ( ticks = 25) or (ticks = 37) or (ticks = 49)
  or (ticks = 61) or (ticks = 73) or (ticks = 85) or (ticks = 97) or (ticks = 109)
  or (ticks = 121) or (ticks = 133) or (ticks = 145) or (ticks = 157) or (ticks = 169)
  or (ticks = 181) or (ticks = 193) or (ticks = 205) or (ticks = 217) or (ticks = 229)
  or (ticks = 241) or (ticks = 253) or (ticks = 265) or (ticks = 277) or (ticks = 289)
  or (ticks = 301) or (ticks = 313) or (ticks = 325) or (ticks = 337) or (ticks = 349)
  or (ticks = 361) or (ticks = 373) or (ticks = 385) or (ticks = 397) or (ticks = 409)
  or (ticks = 421) or (ticks = 433) or (ticks = 445) or (ticks = 457) or (ticks = 469)
  [set capacity wr / num-individuals]
  ask households [set w-ex-level capacity * hh-size]
end

to w-pick-extract
    set hh-water-cons (hh-size * w-req-water )
    foreach n-values 10 [?] [ array:set w-resource-array ? ((normal w-past-resource-ex 0.02))]
    set w-res-list array:to-list w-resource-array
    let w-av-ex mean [w-past-resource-ex] of social-net
    let c-list w-res-list
    set c-list lput av-ex c-list
    set c-list lput w-ex-level c-list
    set c-list lput hh-water-cons c-list
    set w-max-res max c-list
    set w-min-res min c-list
    foreach w-res-list [
      let norm ((? - w-min-res)/(w-max-res - w-min-res))
      set w-norm-list lput norm w-norm-list]
    set norm-hh-water-cons (hh-water-cons - w-min-res)/(w-max-res - w-min-res)
    set w-norm-ex-level (w-ex-level - w-min-res)/(w-max-res - w-min-res)
    set w-norm-neighbours (w-av-ex - w-min-res)/(w-max-res - w-min-res)
end

to update-water
  let resource-use sum [w-act-extract] of households
  ; deduct amount extracted from forest
  ifelse (wr - resource-use >= min-water)
  [
    set wr wr - resource-use
    ask households [set water-stock  w-act-extract]
  ]
  [

      foreach sort-on [rand-sort] households [ask ? [
          ifelse wr - w-act-extract >= min-water
          [
            set water-stock w-act-extract
            set wr wr - w-act-extract
          ]
          [
            set water-stock wr - min-water
            set wr min-water
          ]
    ]
  ]
  ]
end

to w-update-attri ; update attributes of agents accordingly
  ask households [
    set w-prop-needs water-stock / hh-water-cons * 100
    set w-past-resource-ex water-stock
    set w-res-list []
    set w-norm-list []
    ;set per-cap (water-stock / hh-size) / 30
  ]
end

; ACQUIRE INPUTS
to subsidised-inputs
  ask households
  [
    set coupon-n 0             ; reset coupon-n to 0
    if month = coupon-month and hh-land-area > 0
  [
    if (hh-type = 1) and (random-float 100 <= p1-access)
    [
      let n-coupon random-float 100
      if n-coupon <= 18.2 [ set coupon-n 1]
      if (n-coupon > 18.2) and (n-coupon <= 59.7) [set coupon-n 2]
      if (n-coupon > 59.7) and (n-coupon <= 93.7) [set coupon-n 3]
      if (n-coupon > 93.7) and (n-coupon <= 99.7) [set coupon-n 4]
      if (n-coupon > 99.7) and (n-coupon <= 99.8) [set coupon-n 6]
      if (n-coupon > 99.8) and (n-coupon <= 100) [set coupon-n 7]
      let c-count 0
      while [coupon-n > 0 and c-count <= coupon-n]
      [
        let t-coupon random-float 100
        ifelse t-coupon <= 81.8 [ set coupon-type 1] [set coupon-type 2]
        if coupon-type = 1
        [
          let s-inorg-fert log-normal 51.0 106.1
          let cost-fert s-inorg-fert * value-s-inorg-fert
          if (hh-capital > cost-fert) and (random-float 1 <= p1-coupon-use)
          [
            set hh-inorg-fert hh-inorg-fert + s-inorg-fert
            set hh-capital hh-capital - cost-fert
            set hh-inputs hh-inputs + hh-inorg-fert
          ]
          ]
        if coupon-type = 2
        [
          let s-pesticide log-normal 4.8 10.1
          let cost-pesticide s-pesticide * value-s-pesticide
          if (hh-capital > cost-pesticide) and (random-float 1 <= p1-coupon-use)
          [
            set hh-pesticide hh-pesticide + s-pesticide
            set hh-capital hh-capital - cost-pesticide
            set hh-inputs hh-inputs + hh-pesticide
          ]
        ]
        set c-count c-count + 1
      ]
    ]
     if (hh-type = 2) and (random-float 100 <= p2-access)
    [
      let n-coupon random-float 100
      if n-coupon <= 25.3 [ set coupon-n 1]
      if (n-coupon > 25.3) and (n-coupon <= 68.7) [set coupon-n 2]
      if (n-coupon > 68.7) and (n-coupon <= 98.2) [set coupon-n 3]
      if (n-coupon > 98.2) and (n-coupon <= 100) [set coupon-n 4]
      let c-count 0
      while [coupon-n > 0 and c-count <= coupon-n]
      [
        let t-coupon random-float 100
        ifelse t-coupon <= 81.1 [ set coupon-type 1] [set coupon-type 2]
        if coupon-type = 1
        [
          let s-inorg-fert log-normal 65.3 213
          let cost-fert s-inorg-fert * value-s-inorg-fert
          if (hh-capital > cost-fert) and (random-float 1 <= p2-coupon-use)
          [
            set hh-inorg-fert hh-inorg-fert + s-inorg-fert
            set hh-capital hh-capital - cost-fert
            set hh-inputs hh-inputs + hh-inorg-fert

          ]
          ]
        if coupon-type = 2
        [
          let s-pesticide log-normal 4.2 2.6
          let cost-pesticide s-pesticide * value-s-pesticide
          if (hh-capital > cost-pesticide) and (random-float 1 <= p2-coupon-use)
          [
            set hh-pesticide hh-pesticide + s-pesticide
            set hh-capital hh-capital - cost-pesticide
            set hh-inputs hh-inputs + hh-pesticide
          ]
        ]
        set c-count c-count + 1
      ]
    ]
    if (hh-type = 3) and (random-float 100 <= p3-access)
    [
      let n-coupon random-float 100
      if n-coupon <= 17.1 [ set coupon-n 1]
      if (n-coupon > 17.1) and (n-coupon <= 62) [set coupon-n 2]
      if (n-coupon > 62) and (n-coupon <= 95.8) [set coupon-n 3]
      if (n-coupon > 95.8) and (n-coupon <= 99.3) [set coupon-n 4]
      if (n-coupon > 99.3) and (n-coupon <= 100) [set coupon-n 5]
      let c-count 0
      while [coupon-n > 0 and c-count <= coupon-n]
      [
        let t-coupon random-float 100
        ifelse t-coupon <= 80.9 [ set coupon-type 1] [set coupon-type 2]
        if coupon-type = 1
        [
          let s-inorg-fert log-normal 78.2 268.9
          let cost-fert s-inorg-fert * value-s-inorg-fert
          if (hh-capital > cost-fert) and (random-float 1 <= p3-coupon-use)
          [
            set hh-inorg-fert hh-inorg-fert + s-inorg-fert
            set hh-capital hh-capital - cost-fert
            set hh-inputs hh-inputs + hh-inorg-fert

          ]
          ]
        if coupon-type = 2
        [
          let s-pesticide log-normal 5.8 9.6
          let cost-pesticide s-pesticide * value-s-pesticide
          if (hh-capital > cost-pesticide) and (random-float 1 <= p3-coupon-use)
          [
            set hh-pesticide hh-pesticide + s-pesticide
            set hh-capital hh-capital - cost-pesticide
            set hh-inputs hh-inputs + hh-pesticide
          ]
        ]
        set c-count c-count + 1
      ]
  ]
  ]
  ]
end

; FARMING

to setcrop-priority ; create a list of crops in order of labour priority for each month - data based on IHS3
  ask households [
    if (month = "Jun") [set crop-priority  ["nutspulses" "permRoots" "cash" "fruits" "annualRoots" "grains" "veg"] ]
    if (month = "Jul") [set crop-priority  ["cash" "veg" "grains" "permRoots" "nutspulses" "fruits" "annualRoots"] ]
    if (month = "Aug") [set crop-priority  ["nutspulses" "veg" "annualRoots" "fruits""cash" "grains" "permRoots"] ]
    if (month = "Sep") [set crop-priority  ["nutspulses" "veg" "grains" "permRoots" "fruits" "annualRoots" "cash"] ]
    if (month = "Oct") [set crop-priority  ["annualRoots" "cash""permRoots" "fruits" "grains" "nutspulses" "veg"] ]
    if (month = "Nov") [set crop-priority  [ "cash" "permRoots" "grains" "nutspulses" "veg" "fruits" "annualRoots"] ]
    if (month = "Dec") [set crop-priority  ["cash" "fruits" "nutspulses" "grains" "permRoots" "veg" "annualRoots"] ]
    if (month = "Jan") [set crop-priority  ["nutspulses" "veg" "fruits""grains" "cash" "annualRoots" "permRoots"] ]
    if (month = "Feb") [set crop-priority  ["nutspulses" "cash" "fruits" "permRoots" "grains""annualRoots" "veg"] ]
    if (month = "Mar") [set crop-priority  ["veg" "cash" "permRoots" "grains" "fruits" "nutspulses" "annualRoots"] ]
    if (month = "Apr") [set crop-priority  ["nutspulses" "fruits" "annualRoots" "permRoots" "cash""grains" "veg"] ]
    if (month = "May") [set crop-priority  ["grains" "permRoots" "nutspulses""cash" "fruits" "annualRoots" "veg"] ]
  ]

end

to allocate-land
  if season-start = TRUE [                       ; at the start of the growing season need to allocate land to different crops
    ask households [
      foreach reverse sort-on [patch-area] my-farm [
         ask ? [
          allo-land self                         ; allocates land to each of the households patches in turn
         ]]
      if farming-lab > 0
      [
        set labour-pool labour-pool + farming-lab
        set farming-lab 0
        ]
  ]
  ]
end

to allo-land [a-patch]
  ask myself
  [
  if ([ patch-type ] of a-patch = 3)
  [
    calc-veg-req a-patch
    ifelse (hh-veg-labour = TRUE)
    [farm-vegetables a-patch]
    [
      calc-food-req a-patch
      ifelse hh-food-labour = TRUE
      [farm-foodcrops a-patch ]
      [fallow a-patch]
  ]
  ]
  calc-sub-req                            ; determine whether farming requirements have been met
  if ([ patch-type ] of a-patch = 2) and (hh-sub-req = TRUE) and ([fruit-stand] of a-patch = "FALSE")
    [
      calc-cash-req a-patch
      ifelse (hh-cash-land = TRUE) and (hh-cash-labour = TRUE)  and (hh-cash-know = TRUE)
      [farm-cashcrops a-patch]
        [
          calc-tree-req a-patch
          ifelse (hh-tree-land = TRUE) and (hh-tree-know = TRUE) and (hh-tree-labour = TRUE)
          [plant-fruittrees a-patch]
          [
            calc-food-req a-patch
            ifelse hh-food-labour = TRUE
            [farm-foodcrops a-patch]
            [fallow a-patch]]]
    ]
   if ([ patch-type ] of a-patch = 2) and (hh-sub-req = FALSE) and ([fruit-stand] of a-patch = "FALSE")
   [
     calc-food-req a-patch
     ifelse hh-food-labour = TRUE
     [farm-foodcrops a-patch ]
     [fallow a-patch]
      ]

    if ([patch-type] of a-patch = 2) and ([fruit-stand] of a-patch = "TRUE")  ; maintain fruit trees
    [ plant-fruittrees a-patch ]
    ]
end

to calc-sub-req
    if hh-type  = 1 [set sub-req 0.58]     ;subsistence requirements are dependent upon HH type
    if hh-type  = 2 [set sub-req 0.49]
    if hh-type  = 3 [set sub-req 0.57]

    let food-allo  (allo-grains + allo-nuts-pulses + allo-annual-roots + allo-perm-roots + allo-vegetables)
    ifelse food-allo >= sub-req
    [set hh-sub-req TRUE]
    [set hh-sub-req FALSE]
end


to calc-cash-req [a-patch]
    let cash-labourreq (cash-labour * [patch-area] of a-patch)
    ifelse farming-lab >= cash-labourreq       ; determine whether cash crop labour requirements are met
    [set hh-cash-labour TRUE]
    [
      ifelse hh-capital > 0
      [
        let labourdef (cash-labourreq - farming-lab)
        seek-labour labourdef self
        ifelse farming-lab >= cash-labourreq
        [set hh-cash-labour TRUE]
        [set hh-cash-labour FALSE]
      ]
      [set hh-cash-labour FALSE]
       ]

    ifelse hh-land-area >= cash-land          ; determine whether cash crop land requirements are met
    [set hh-cash-land TRUE]
    [set hh-cash-land FALSE]

    ifelse (hh-edu-level >= 2) or (past-cash-crops > 0) ; checks to see if HH has sufficient knowledge of cash crops
    [set hh-cash-know TRUE]
    [set hh-cash-know FALSE]
  end

 to calc-food-req [a-patch]
    let food-labourReq (food-labour * [patch-area] of a-patch)  ; checks HH has sufficient labour to plant food crops
    ifelse farming-lab >= food-labourReq
    [set hh-food-labour TRUE]
    [
      ifelse hh-capital > 0
      [
        let labourdef (food-labourReq - farming-lab)
        seek-labour labourdef self
        ifelse farming-lab >= food-labourReq
        [set hh-food-labour TRUE]
        [set hh-food-labour FALSE]
      ]
      [set hh-food-labour FALSE]
       ]
 end

   to calc-tree-req [a-patch]
    ifelse hh-land-area >= tree-land                            ; checks HH has sufficient land to plant trees
    [set hh-tree-land TRUE]
    [set hh-tree-land FALSE]

    let fruits-labourreq (fruits-labour * [patch-area] of a-patch) ; checks HH has sufficient labour to plant trees
    ifelse farming-lab >= fruits-labourreq
    [set hh-tree-labour TRUE]
    [
      ifelse hh-capital > 0
      [
        let labourdef (fruits-labourreq - farming-lab)
        seek-labour labourdef self
        ifelse farming-lab >= fruits-labourreq
        [set hh-tree-labour TRUE]
        [set hh-tree-labour FALSE]
      ]
      [set hh-tree-labour FALSE]
       ]

    ifelse (hh-edu-level >= 2) or (past-fruits > 0)           ; checks HH has sufficient knowledge of trees
    [set hh-tree-know TRUE]
    [set hh-tree-know FALSE]
     end

   to calc-veg-req [a-patch]
    let veg-labourreq (vegetables-labour * [patch-area] of a-patch) ; checks HH has sufficient labour to farm vegetables
    ifelse farming-lab >= veg-labourreq
    [set hh-veg-labour TRUE]
    [
        ifelse hh-capital > 0
      [
        let labourdef (veg-labourreq - farming-lab)
        seek-labour labourdef self
        ifelse farming-lab >= veg-labourreq
        [set hh-veg-labour TRUE]
        [set hh-veg-labour FALSE]
      ]
      [set hh-veg-labour FALSE]
       ]
end

to farm-vegetables [a-patch]
    set allo-vegetables (allo-vegetables + [patch-area] of a-patch)
    set farming-lab (farming-lab - (vegetables-labour * [patch-area] of a-patch)) ; reduce HH labour
    set farm-work (farm-work + (vegetables-labour * [patch-area] of a-patch)) ; increase farm work count
    ask a-patch [
     set land-fallow FALSE
     set patch-cover-type  7]
end




to farm-foodcrops [a-patch]                         ; type of food crops planted is dependent upon a weighted/heuristic decision tree. Data from IHS3

  let randFood random 100                     ; get a random number between 0 and 100
  if (hh-type  = 1) and (randFood <= 33)
  [
    set allo-grains (allo-grains + [patch-area] of a-patch)
    ask a-patch [
      set patch-cover-type  2
      set land-fallow FALSE]
    ]
  if (hh-type  = 1) and (randFood >= 34) and (randFood <= 37)
  [
    set allo-nuts-pulses (allo-nuts-pulses + [patch-area] of a-patch)
    ask a-patch [
      set patch-cover-type  4
      set land-fallow FALSE]
    ]
  if (hh-type  = 1) and (randFood >= 38) and (randFood <= 39)
  [
    set allo-annual-roots (allo-annual-roots + [patch-area] of a-patch)
    ask a-patch [
      set patch-cover-type  1
      set land-fallow FALSE]
    ]
  if (hh-type  = 1) and (randFood >= 40) and (randFood <= 54)
  [
    set allo-perm-roots (allo-perm-roots + [patch-area] of a-patch)
    ask a-patch [
      set patch-cover-type  5
      set land-fallow FALSE]
    ]
  if (hh-type  = 1) and (randFood >= 55) and (randFood <= 100)
  [
    set allo-nuts-pulses (allo-nuts-pulses + (0.5 * [patch-area] of a-patch))
    set allo-grains (allo-grains + ( 0.5 * [patch-area] of a-patch))
    ask a-patch [
      set patch-cover-type  3
      set land-fallow FALSE]
    ]


  if (hh-type  = 2) and (randFood <= 38)
  [
    set allo-grains (allo-grains + [patch-area] of a-patch)
    ask a-patch [
      set patch-cover-type  2
      set land-fallow FALSE
      ]
    ]
  if (hh-type  = 2) and (randFood >= 39) and (randFood <= 40)
  [
    set allo-nuts-pulses (allo-nuts-pulses + [patch-area] of a-patch)
    ask a-patch [
      set patch-cover-type  4
      set land-fallow FALSE
      ]
    ]
  if (hh-type  = 2) and (randFood >= 41) and (randFood <= 42)
  [
    set allo-annual-roots (allo-annual-roots + [patch-area] of a-patch)
    ask a-patch [
      set patch-cover-type  1
      set land-fallow FALSE]
    ]
  if (hh-type  = 2) and (randFood >= 43) and (randFood <= 53)
  [
    set allo-perm-roots (allo-perm-roots + [patch-area] of a-patch)
    ask a-patch [
      set patch-cover-type  5
      set land-fallow FALSE
      ]
    ]
  if (hh-type  = 2) and (randFood >= 54) and (randFood <= 100)
  [
    set allo-nuts-pulses (allo-nuts-pulses + ( 0.5 * [patch-area] of a-patch))
    set allo-grains (allo-grains + ( 0.5 * [patch-area] of a-patch))
    ask a-patch [
      set patch-cover-type  3
      set land-fallow FALSE
      ]
    ]

  if (hh-type  = 3) and (randFood <= 28)
  [
    set allo-grains (allo-grains + [patch-area] of a-patch)
    ask a-patch [
      set patch-cover-type  2
      set land-fallow FALSE
      ]
    ]
  if (hh-type  = 3) and (randFood >= 29) and (randFood <= 31)
  [
    set allo-nuts-pulses (allo-nuts-pulses + [patch-area] of a-patch)
    ask a-patch [
      set patch-cover-type  4
      set land-fallow FALSE
      ]
    ]
  if (hh-type  = 3) and (randFood = 32)
  [
    set allo-annual-roots (allo-annual-roots + [patch-area] of a-patch)
    ask a-patch [
      set patch-cover-type  1
      set land-fallow FALSE]
    ]
  if (hh-type  = 3) and (randFood >= 33) and (randFood <= 48)
  [
    set allo-perm-roots (allo-perm-roots + [patch-area] of a-patch)
    ask a-patch [
      set patch-cover-type  5
      set land-fallow FALSE]
    ]
  if (hh-type  = 3) and (randFood >= 49) and (randFood <= 100)
  [
    set allo-nuts-pulses (allo-nuts-pulses + (0.5 * [patch-area] of a-patch))
    set allo-grains (allo-grains + ( 0.5 * [patch-area] of a-patch))
    ask a-patch [
      set patch-cover-type  3
      set land-fallow FALSE]
    ]
  set farming-lab (farming-lab - (food-labour * [patch-area] of a-patch)) ; reduce labour availability
  set farm-work farm-work + (food-labour * [patch-area] of a-patch) ; increase farm labour count
end


to fallow [a-patch]
  ; first allocate the labour farmers do have to farm food-crops
  ; then allocate the remainder to fallow

  let lab-req [patch-fallow] of a-patch * food-labour
  ifelse farming-lab >= lab-req
  [
    farm-foodcrops a-patch
  ]
  [
  ifelse farming-lab > 0
  [
    let patch-split farming-lab / food-labour
    ask a-patch [ set prop-patch patch-split]
   ; allocate this proportion of land to food crops

    let randFood random 100                     ; get a random number between 0 and 100
  if (hh-type  = 1) and (randFood <= 33)
  [
    set allo-grains (allo-grains + [prop-patch] of a-patch)
    ask a-patch [set patch-cover-type  2]
    ]
  if (hh-type  = 1) and (randFood >= 34) and (randFood <= 37)
  [
    set allo-nuts-pulses (allo-nuts-pulses  + [prop-patch] of a-patch)
    ask a-patch [set patch-cover-type  4]
    ]
  if (hh-type  = 1) and (randFood >= 38) and (randFood <= 39)
  [
    set allo-annual-roots (allo-annual-roots + [prop-patch] of a-patch)
    ask a-patch [set patch-cover-type  1]
    ]
  if (hh-type  = 1) and (randFood >= 40) and (randFood <= 54)
  [
    set allo-perm-roots (allo-perm-roots + [prop-patch] of a-patch)
    ask a-patch [set patch-cover-type  5]
    ]
  if (hh-type  = 1) and (randFood >= 55) and (randFood <= 100)
  [
    set allo-nuts-pulses (allo-nuts-pulses + (0.5 * [prop-patch] of a-patch))
    set allo-grains (allo-grains + ( 0.5 * [prop-patch] of a-patch ))
    ask a-patch [set patch-cover-type  3]
    ]

  if (hh-type  = 2) and (randFood <= 38)
  [
    set allo-grains (allo-grains  + [prop-patch] of a-patch)
    ask a-patch [set patch-cover-type  2]
    ]
  if (hh-type  = 2) and (randFood >= 39) and (randFood <= 40)
  [
    set allo-nuts-pulses (allo-nuts-pulses  + [prop-patch] of a-patch)
    ask a-patch [set patch-cover-type  4]
    ]
  if (hh-type  = 2) and (randFood >= 41) and (randFood <= 42)
  [
   set allo-annual-roots (allo-annual-roots +  [prop-patch] of a-patch)
    ask a-patch [set patch-cover-type  1]
    ]
  if (hh-type  = 2) and (randFood >= 43) and (randFood <= 53)
  [
    set allo-perm-roots (allo-perm-roots +  [prop-patch] of a-patch)
    ask a-patch [set patch-cover-type  5]
    ]
  if (hh-type  = 2) and (randFood >= 54) and (randFood <= 100)
  [
    set allo-nuts-pulses (allo-nuts-pulses + ( 0.5 * [prop-patch] of a-patch ))
    set allo-grains (allo-grains + ( 0.5 *  [prop-patch] of a-patch ))
    ask a-patch [set patch-cover-type  3]
    ]

  if (hh-type  = 3) and (randFood <= 28)
  [
    set allo-grains (allo-grains +  [prop-patch] of a-patch)
    ask a-patch [set patch-cover-type  2]
    ]
  if (hh-type  = 3) and (randFood >= 29) and (randFood <= 31)
  [
    set allo-nuts-pulses (allo-nuts-pulses + [prop-patch] of a-patch)
    ask a-patch [set patch-cover-type  4]
    ]
  if (hh-type  = 3) and (randFood = 32)
  [
    set allo-annual-roots (allo-annual-roots + [prop-patch] of a-patch)
    ask a-patch [set patch-cover-type  1]
    ]
  if (hh-type  = 3) and (randFood >= 33) and (randFood <= 48)
  [
    set allo-perm-roots (allo-perm-roots + [prop-patch] of a-patch)
    ask a-patch [set patch-cover-type  5]
    ]
  if (hh-type  = 3) and (randFood >= 49) and (randFood <= 100)
  [
    set allo-nuts-pulses (allo-nuts-pulses + (0.5 * [prop-patch] of a-patch ))
    set allo-grains (allo-grains + ( 0.5 * [prop-patch] of a-patch ))
    ask a-patch [set patch-cover-type  3]
    ]
  set farm-work farm-work + farming-lab
  set farming-lab 0
  ; set remaining land to fallow
  ask a-patch [
    set land-fallow TRUE
    set patch-fallow patch-area - prop-patch
    ]
   set allo-fallow allo-fallow + [patch-fallow] of a-patch
  ]
  [
   set allo-fallow (allo-fallow + [patch-area] of a-patch)
   ask a-patch [
      set land-fallow TRUE
      set patch-cover-type 0
    ]
  ]
  ]
  end

to farm-cashcrops [a-patch]
    set allo-cash-crops (allo-cash-crops + [patch-area] of a-patch)
    set farming-lab (farming-lab - (cash-labour * [patch-area] of a-patch))
    set farm-work farm-work + (cash-labour * [patch-area] of a-patch)
    ask a-patch [
      set land-fallow FALSE
      set patch-cover-type 6
    ]

end


to plant-fruittrees [a-patch]

   let randFruit random 100        ; mix of fruit crops and food crops to planted is dependent upon a weighted/ heuristic decision tree. Data from IHS3
   ask a-patch [
     if fruit-stand = "TRUE" [set fruit-stand-age fruit-stand-age + 1 ]
    ]
  if (hh-type  = 1) and (randFruit <= 63)
  [
    set allo-fruits (allo-fruits + [patch-area] of a-patch)
    set farming-lab (farming-lab - (fruits-labour * [patch-area] of a-patch))
    ask a-patch [
      set patch-cover-type  8
      set land-fallow FALSE
      set fruit-stand "TRUE"
      ]
    ]
  if (hh-type  = 1) and (randFruit >= 64) and (randFruit <= 73)
  [
    set allo-fruits (allo-fruits +  (0.5 * [patch-area] of a-patch))
    set allo-grains (allo-grains + (0.5 * [patch-area] of a-patch))
    set farming-lab (farming-lab - (fruits-labour * [patch-area] of a-patch))
    ask a-patch [
      set patch-cover-type  9
      set land-fallow FALSE
      set fruit-stand "TRUE"
      ]
  ]
  if (hh-type  = 1) and (randFruit >= 74) and (randFruit <= 95)
  [
    set allo-fruits (allo-fruits + ( 1 / 3 * [patch-area] of a-patch))
    set allo-grains allo-grains + (( 1 / 3 * [patch-area] of a-patch))
    set allo-nuts-pulses (allo-nuts-pulses + ( 1 / 3 * [patch-area] of a-patch))
    set farming-lab (farming-lab - (fruits-labour * [patch-area] of a-patch))
    ask a-patch [
      set patch-cover-type  10
      set land-fallow FALSE
      set fruit-stand "TRUE"
      ]
  ]
  if (hh-type  = 1) and (randFruit >= 96) and (randFruit <= 100)
  [
    set allo-fruits(allo-fruits + 0.25 * [patch-area] of a-patch)
    set allo-grains (allo-grains + 0.25 * [patch-area] of a-patch)
    set allo-nuts-pulses (allo-nuts-pulses + (0.25 * [patch-area] of a-patch))
    set allo-perm-roots (allo-perm-roots + ( 0.25 * [patch-area] of a-patch))
    set farming-lab (farming-lab - (fruits-labour * [patch-area] of a-patch))
    ask a-patch [
      set patch-cover-type  11
      set land-fallow FALSE
      set fruit-stand "TRUE"
      ]
   ]

  if (hh-type  = 2) and (randFruit <= 65)
  [
    set allo-fruits(allo-fruits + [patch-area] of a-patch)
    set farming-lab (farming-lab - (fruits-labour * [patch-area] of a-patch))
    ask a-patch [
      set patch-cover-type  8
      set land-fallow FALSE
      set fruit-stand "TRUE"
      ]
    ]

    if (hh-type  = 2) and (randFruit >= 66) and (randFruit <= 80)
  [
    set allo-fruits (allo-fruits +  (0.5 * [patch-area] of a-patch))
    set allo-grains (allo-grains + (0.5 * [patch-area] of a-patch))
    set farming-lab (farming-lab - (fruits-labour * [patch-area] of a-patch))
    ask a-patch [
      set patch-cover-type  9
      set land-fallow FALSE
      set fruit-stand "TRUE"
      ]
  ]

  if (hh-type  = 2) and (randFruit >= 81) and (randFruit <= 100)
  [
    set allo-fruits(allo-fruits + ( 1 / 3 * [patch-area] of a-patch))
    set allo-grains (allo-grains + ( 1 / 3 * [patch-area] of a-patch))
    set allo-nuts-pulses (allo-nuts-pulses + ( 1 / 3 * [patch-area] of a-patch))
    set farming-lab (farming-lab - (fruits-labour * [patch-area] of a-patch))
    ask a-patch [
      set patch-cover-type 10
      set land-fallow FALSE
      set fruit-stand "TRUE"
      ]
  ]

  if (hh-type  = 3) and (randFruit <= 58)
  [
    set allo-fruits(allo-fruits + [patch-area] of a-patch)
    set farming-lab (farming-lab - (fruits-labour * [patch-area] of a-patch))
    ask a-patch [
      set patch-cover-type  8
      set land-fallow FALSE
      set fruit-stand "TRUE"
      ]
    ]
  if (hh-type  = 3) and (randFruit >= 59) and (randFruit <= 70)
  [
    set allo-fruits(allo-fruits + (0.5 * [patch-area] of a-patch))
    set allo-grains (allo-grains + (0.5 * [patch-area] of a-patch))
    set farming-lab (farming-lab - (fruits-labour * [patch-area] of a-patch))
    ask a-patch [
      set patch-cover-type 9
      set land-fallow FALSE
      set fruit-stand "TRUE"
      ]
  ]
  if (hh-type  = 3) and (randFruit >= 71) and (randFruit <= 96)
  [
    set allo-fruits(allo-fruits +  ( 1 / 3 * [patch-area] of a-patch))
    set allo-grains (allo-grains + ( 1 / 3 * [patch-area] of a-patch))
    set allo-nuts-pulses (allo-nuts-pulses + (0.1 * [patch-area] of a-patch))
    set farming-lab (farming-lab - (fruits-labour * [patch-area] of a-patch))
    ask a-patch [
      set patch-cover-type  10
      set land-fallow FALSE
      set fruit-stand "TRUE"
      ]
  ]
  if (hh-type  = 3) and (randFruit >= 97) and (randFruit <= 100)
  [
    set allo-fruits(allo-fruits + (0.25 * [patch-area] of a-patch))
    set allo-grains (allo-grains + (0.25 * [patch-area] of a-patch))
    set allo-nuts-pulses (allo-nuts-pulses + (0.25 * [patch-area] of a-patch))
    set allo-perm-roots (allo-perm-roots + (0.25 * [patch-area] of a-patch))
    set farming-lab (farming-lab - (fruits-labour * [patch-area] of a-patch))
    ask a-patch [
      set patch-cover-type  11
      set land-fallow FALSE
      set fruit-stand "TRUE"
      ]
   ]
end

to reallocate-land

  ask households [
  if season-start = FALSE
  [
    calcmonth-lab                          ;calculate monthly labour requirements
    ifelse farming-lab >= month-lab
    [
      set farm-work farm-work + month-lab
      calc-labour-dist self                ; increase crop labour quality index
      extend-crop-plan self                ; extend the area of land under crop\
      calc-labour-accum
      ]
    [
      if hh-capital > 0
      [
        set farm-work farm-work + farming-lab
        let labourDef month-lab - farming-lab
        seek-labour labourDef self
      ]
      calc-labour-dist self
      calc-labour-accum
      ]

    ]
  ]
end

to calcmonth-lab
    let month-grains (allo-grains * grain-labour)
    let month-nuts-pulses (allo-nuts-pulses * nuts-pulses-labour)
    let month-annual-roots (allo-annual-roots * annual-roots-labour)
    let month-perm-roots (allo-perm-roots * permroots-labour)
    let month-vegetables (allo-vegetables * vegetables-labour)
    let month-fruits (allo-fruits * fruits-labour)
    let month-cash-crops (allo-cash-crops * cash-labour)
    set month-lab ( month-grains + month-nuts-pulses + month-annual-roots + month-perm-roots + month-vegetables + month-fruits + month-cash-crops)
end

to calc-labour-dist [a-hh] ; distribute labour between crops based on crop priority

    foreach crop-priority [

      if (? = "grains") and (allo-grains > 0) and (farming-lab >= (allo-grains * grain-labour)) [
        set labour-grains (allo-grains * grain-labour)
        set farming-lab (farming-lab - (allo-grains * grain-labour))
      ]

      if (? = "nutspulses") and (allo-nuts-pulses > 0) and (farming-lab >= (allo-nuts-pulses * nuts-pulses-labour))  [
         set labour-nuts-pulses  (allo-nuts-pulses * nuts-pulses-labour)
         set farming-lab (farming-lab - (allo-nuts-pulses * nuts-pulses-labour))
      ]

      if (? = "permRoots") and (allo-perm-roots > 0) and (farming-lab >= (allo-perm-roots * permroots-labour)) [
         set labour-perm-roots  (allo-perm-roots * permroots-labour)
         set farming-lab (farming-lab - (allo-perm-roots * permroots-labour))
      ]

      if (? = "annualRoots") and (allo-annual-roots > 0) and (farming-lab >= (allo-annual-roots * annual-roots-labour)) [
         set labour-annual-roots  (allo-annual-roots * annual-roots-labour)
         set farming-lab (farming-lab - (allo-annual-roots * annual-roots-labour))
      ]

      if (? = "veg") and (allo-vegetables > 0) and (farming-lab >= (allo-vegetables * vegetables-labour))[
         set labour-vegetables (allo-vegetables * vegetables-labour)
         set farming-lab (farming-lab - (allo-vegetables * vegetables-labour))
      ]

      if (? = "fruits") and (allo-fruits > 0) and (farming-lab >= (allo-fruits * fruits-labour)) [
         set labour-fruits (allo-fruits * fruits-labour)
         set farming-lab (farming-lab - (allo-fruits * fruits-labour))
      ]

      if (? = "cash") and (allo-cash-crops > 0) and (farming-lab >= (allo-cash-crops * cash-labour))[
         set labour-cash-crops (allo-cash-crops * cash-labour)
         set farming-lab (farming-lab - (allo-cash-crops * cash-labour))
      ]
     ]
end

to calc-labour-accum   ; calculate culmulative labour for each of the patch-cover types
    if labour-annual-roots > 0 [
      set p1-lab  labour-annual-roots / allo-annual-roots
    ]
    if labour-grains > 0 [
      set p2-lab labour-grains / allo-grains
    ]
    if labour-grains > 0 and labour-nuts-pulses > 0 [
      set p3-lab 0.5 * ((labour-grains / allo-grains) + (labour-nuts-pulses / allo-nuts-pulses))
    ]
    if labour-grains > 0 and labour-nuts-pulses <= 0 [
      set p3-lab 0.5 * (labour-grains / allo-grains)
    ]
    if labour-grains <= 0 and labour-nuts-pulses > 0 [
      set p3-lab 0.5 * (labour-nuts-pulses / allo-nuts-pulses)
    ]
    if  labour-nuts-pulses > 0 [
      set p4-lab  labour-nuts-pulses / allo-nuts-pulses
     ]
    if  labour-perm-roots > 0 [
      set p5-lab  labour-perm-roots / allo-perm-roots
    ]
    if labour-cash-crops > 0 [
      set p6-lab labour-cash-crops / allo-cash-crops
    ]
    if labour-vegetables > 0 [
      set p7-lab labour-vegetables / allo-vegetables
    ]
    if labour-fruits > 0 [
      set p8-lab labour-fruits / allo-fruits
    ]
    if labour-fruits > 0 and labour-grains > 0 [
      set p9-lab 0.5 * ((labour-fruits / allo-fruits) + (labour-grains / allo-grains))
    ]
    if labour-fruits > 0 and labour-grains <= 0 [
      set p9-lab 0.5 * (labour-fruits / allo-fruits)
      ]
    if labour-fruits <= 0 and labour-grains > 0 [
      set p9-lab 0.5 * (labour-grains / allo-grains)
    ]
    if labour-fruits > 0 and labour-grains > 0 and labour-nuts-pulses > 0 [
      set p10-lab 1 / 3 * ((labour-fruits / allo-fruits) + (labour-grains / allo-grains) + (labour-nuts-pulses / allo-nuts-pulses))
    ]
    if labour-fruits > 0 and labour-grains > 0 and labour-nuts-pulses <= 0 [
      set p10-lab 1 / 3 * ((labour-fruits / allo-fruits) + (labour-grains / allo-grains))
    ]
    if labour-fruits > 0 and labour-grains <= 0 and labour-nuts-pulses > 0 [
      set p10-lab 1 / 3 * ((labour-fruits / allo-fruits) + (labour-nuts-pulses / allo-nuts-pulses))
    ]
    if labour-fruits <= 0 and labour-grains > 0 and labour-nuts-pulses > 0 [
      set p10-lab 1 / 3 * ((labour-grains / allo-grains) + (labour-nuts-pulses / allo-nuts-pulses))
    ]
    if labour-fruits > 0 and labour-grains <= 0 and labour-nuts-pulses <= 0 [
      set p10-lab 1 / 3 * (labour-fruits / allo-fruits)
    ]
    if labour-fruits <= 0 and labour-grains <= 0 and labour-nuts-pulses > 0 [
      set p10-lab 1 / 3 * (labour-nuts-pulses / allo-nuts-pulses)
    ]
    if labour-fruits <= 0 and labour-grains > 0 and labour-nuts-pulses <= 0 [
      set p10-lab 1 / 3 * (labour-grains / allo-grains)
    ]
    if labour-fruits > 0 and labour-grains > 0 and labour-nuts-pulses > 0 and labour-perm-roots > 0 [
      set p11-lab 0.25 * ((labour-fruits / allo-fruits) +  (labour-grains / allo-grains) + (labour-nuts-pulses / allo-nuts-pulses) + (labour-perm-roots / allo-perm-roots))
    ]
    if labour-fruits > 0 and labour-grains > 0 and labour-nuts-pulses > 0 and labour-perm-roots <= 0 [
      set p11-lab 0.25 * ((labour-fruits / allo-fruits) +  (labour-grains / allo-grains) + (labour-nuts-pulses / allo-nuts-pulses))
    ]
    if labour-fruits > 0 and labour-grains > 0 and labour-nuts-pulses <= 0 and labour-perm-roots > 0 [
      set p11-lab 0.25 * ((labour-fruits / allo-fruits) +  (labour-grains / allo-grains) + (labour-perm-roots / allo-perm-roots))
    ]
    if labour-fruits > 0 and labour-grains <= 0 and labour-nuts-pulses > 0 and labour-perm-roots > 0 [
      set p11-lab 0.25 * ((labour-fruits / allo-fruits) + (labour-nuts-pulses / allo-nuts-pulses) + (labour-perm-roots / allo-perm-roots))
    ]
    if labour-fruits <= 0 and labour-grains > 0 and labour-nuts-pulses > 0 and labour-perm-roots > 0 [
      set p11-lab 0.25 * ((labour-grains / allo-grains) + (labour-nuts-pulses / allo-nuts-pulses) + (labour-perm-roots / allo-perm-roots))
    ]
    if labour-fruits > 0 and labour-grains > 0 and labour-nuts-pulses <= 0 and labour-perm-roots <= 0 [
      set p11-lab 0.25 * ((labour-fruits / allo-fruits) +  (labour-grains / allo-grains))
    ]
    if labour-fruits > 0 and labour-grains <= 0 and labour-nuts-pulses <= 0 and labour-perm-roots > 0 [
      set p11-lab 0.25 * ((labour-fruits / allo-fruits) +  (labour-perm-roots / allo-perm-roots))
    ]
    if labour-fruits <= 0 and labour-grains <= 0 and labour-nuts-pulses > 0 and labour-perm-roots > 0 [
      set p11-lab 0.25 * ((labour-nuts-pulses / allo-nuts-pulses) + (labour-perm-roots / allo-perm-roots))
    ]
    if labour-fruits <= 0 and labour-grains > 0 and labour-nuts-pulses > 0 and labour-perm-roots <= 0 [
      set p11-lab 0.25 * ( (labour-grains / allo-grains) + (labour-nuts-pulses / allo-nuts-pulses))
    ]
    if labour-fruits > 0 and labour-grains <= 0 and labour-nuts-pulses <= 0 and labour-perm-roots <= 0 [
      set p11-lab 0.25 * (labour-fruits / allo-fruits)
    ]
    if labour-fruits <= 0 and labour-grains <= 0 and labour-nuts-pulses <= 0 and labour-perm-roots > 0 [
      set p11-lab 0.25 * (labour-perm-roots / allo-perm-roots)
    ]
    if labour-fruits <= 0 and labour-grains <= 0 and labour-nuts-pulses > 0 and labour-perm-roots <= 0 [
      set p11-lab 0.25 * (labour-nuts-pulses / allo-nuts-pulses)
    ]
    if labour-fruits <= 0 and labour-grains > 0 and labour-nuts-pulses <= 0 and labour-perm-roots <= 0 [
      set p11-lab 0.25 * (labour-grains / allo-grains)
    ]
    foreach sort my-farm [ ask ? [

        if patch-cover-type = 1 [
          set labour-accum  labour-accum + ( [p1-lab] of one-of households with [ hh-id = [owner-id] of ?]  * ([patch-area] of ?  - [patch-fallow] of ?))
          set l-a l-a + labour-accum
        ]
        if patch-cover-type = 2 [
          set labour-accum labour-accum +   ( [p2-lab] of one-of households with [ hh-id = [owner-id] of ?] * ([patch-area] of ?  - [patch-fallow] of ?))
          set l-a l-a + labour-accum
          ]
        if patch-cover-type = 3 [
          set labour-accum labour-accum +  ( [p3-lab] of one-of households with [ hh-id = [owner-id] of ?] * ([patch-area] of ?  - [patch-fallow] of ?))
          set l-a l-a + labour-accum
          ]
        if patch-cover-type = 4 [
          set labour-accum  labour-accum + ( [p4-lab] of one-of households with [ hh-id = [owner-id] of ?] * ([patch-area] of ?  - [patch-fallow] of ?))
          set l-a l-a + labour-accum
          ]
        if patch-cover-type = 5 [
          set labour-accum  labour-accum + ( [p5-lab] of one-of households with [ hh-id = [owner-id] of ?] * ([patch-area] of ?  - [patch-fallow] of ?))
          set l-a l-a + labour-accum
          ]
        if patch-cover-type = 6 [
          set labour-accum  labour-accum + ( [p6-lab] of one-of households with [ hh-id = [owner-id] of ?] * ([patch-area] of ?  - [patch-fallow] of ?))
          set l-a l-a + labour-accum
          ]
        if patch-cover-type = 7 [
          set labour-accum labour-accum + ( [p7-lab] of one-of households with [ hh-id = [owner-id] of ?] * ([patch-area] of ?  - [patch-fallow] of ?))
          set l-a l-a + labour-accum
          ]
        if patch-cover-type = 8 [
          set labour-accum labour-accum + ( [p8-lab] of one-of households with [ hh-id = [owner-id] of ?] * ([patch-area] of ?  - [patch-fallow] of ?))
          set l-a l-a + labour-accum
          ]
        if patch-cover-type = 9 [
          set labour-accum  labour-accum + ( [p9-lab] of one-of households with [ hh-id = [owner-id] of ?] * ([patch-area] of ?  - [patch-fallow] of ?))
          set l-a l-a + labour-accum
          ]
        if patch-cover-type = 10 [
          set labour-accum labour-accum + ( [p10-lab] of one-of households with [ hh-id = [owner-id] of ?] * ([patch-area] of ?  - [patch-fallow] of ?))
          set l-a l-a + labour-accum
          ]
        if patch-cover-type = 11 [
          set labour-accum labour-accum +  ( [p11-lab] of one-of households with [ hh-id = [owner-id] of ?] * ([patch-area] of ?  - [patch-fallow] of ?))
          set l-a l-a + labour-accum
          ]
        ]
    ]

    let farm-accum sum [l-a] of my-farm
    let crop-accum labour-grains + labour-nuts-pulses + labour-perm-roots + labour-fruits + labour-cash-crops + labour-annual-roots + labour-vegetables
    set l-a 0
    set p1-lab 0
    set p2-lab 0
    set p3-lab 0
    set p4-lab 0
    set p5-lab 0
    set p6-lab 0
    set p7-lab 0
    set p8-lab 0
    set p9-lab 0
    set p10-lab 0
    set p11-lab 0
end

to extend-crop-plan [a-hh]
  ask a-hh
  [
    ifelse (allo-fallow > 0)
    [
      cultfallow a-hh
         ]                        ; allocate crops to land - slight oversimplification because the season and patch might not allow for further planting ...
    [
      ifelse any? patches with [ patch-type  = 1]
      [clear-Forest self]
      [addlabour-pool self]
    ]
  ]
end

to cultfallow [a-hh]
  ask a-hh
  [
    foreach sort  my-farm [ ask ?
         [
           if land-fallow = TRUE
           [
             ifelse [prop-patch] of self > 0
             [
               reduce-patch-fallow a-hh self
               cult-rest a-hh self
               ]
             [
             reducefallow a-hh self
             allo-land self
             ]
             ]
           ]
         ]
    ]
end

to cult-rest [a-hh a-patch]
  ask a-hh
  [
    let lab-req [patch-fallow] of a-patch * food-labour
    ifelse farming-lab >= lab-req
    [
      ; upate labour
      set farming-lab farming-lab - lab-req
      ; cultivate the area of fallow with the crop currently on the rest of the plot
      if [patch-cover-type] of a-patch = 1 [set allo-annual-roots allo-annual-roots + ([patch-fallow] of a-patch) ]
      if [patch-cover-type] of a-patch = 2 [set allo-grains allo-grains + [patch-fallow] of a-patch]
      if [patch-cover-type] of a-patch = 3 [
        set allo-grains allo-grains + (0.5 * [patch-fallow] of a-patch)
        set allo-nuts-pulses allo-nuts-pulses + (0.5 * [patch-fallow] of a-patch)]
      if [patch-cover-type] of a-patch = 4 [set allo-nuts-pulses allo-nuts-pulses + [patch-fallow] of a-patch]
      if [patch-cover-type] of a-patch = 5 [set allo-perm-roots allo-perm-roots + [patch-fallow] of a-patch]
      ; decrease area of fallow
      ask a-patch [
        set patch-fallow 0
        set prop-patch 0
        set land-fallow FALSE
        ]
    ]
    [
      ; if there isn't enough labour...
      ifelse farming-lab > 0
       [
         let patch-split farming-lab / food-labour
         ; cultivate the area of patch with the crop currently on the rest of the plot
         if [patch-cover-type] of a-patch = 1 [set allo-annual-roots allo-annual-roots + patch-split ]
         if [patch-cover-type] of a-patch = 2 [set allo-grains allo-grains + patch-split]
         if [patch-cover-type] of a-patch = 3 [
           set allo-grains allo-grains + (0.5 * patch-split)
           set allo-nuts-pulses allo-nuts-pulses + (0.5 * patch-split)]
         if [patch-cover-type] of a-patch = 4 [set allo-nuts-pulses allo-nuts-pulses + patch-split]
         if [patch-cover-type] of a-patch = 5 [set allo-perm-roots allo-perm-roots + patch-split]

        ; update labour
         set farming-lab 0
         ; set remaining land to fallow

         ask a-patch [
           set prop-patch prop-patch + patch-split
           set patch-fallow patch-area - prop-patch
           ]
         set allo-fallow allo-fallow + [patch-fallow] of a-patch
    ]
       [
         if farming-lab = 0
         [ set allo-fallow allo-fallow + [patch-fallow] of a-patch]
       ]
  ]
  ]
  end

to reducefallow [a-hh a-patch]
  ask a-hh
  [
    set allo-fallow (allo-fallow - [patch-area] of a-patch)
  ]
end

to reduce-patch-fallow [a-hh a-patch]
  ask a-hh
  [
    set allo-fallow (allo-fallow - [patch-fallow] of a-patch)
  ]
end

to clear-forest [a-hh]
  ask a-hh
  [
    let forestpatch one-of patches with [ patch-type  = 1]
    ifelse farming-lab >= ([patch-area] of forestpatch * deforest-labour)
         [

           set hh-land-area (hh-land-area + [patch-area] of forestpatch)
           set allo-fallow (allo-fallow + [patch-area] of forestpatch)
           let id [hh-id] of a-hh
           ask forestpatch [set owner-id id]
           set  my-farm patches with [ owner-id  = [hh-id] of myself]
           set farming-lab farming-lab - (deforest-labour * [patch-area] of forestPatch)
           addlabour-pool self
           ask forestpatch
           [
             set patch-type  2
             set patch-cover-type 0
             set land-fallow TRUE
           ]
         ]
         [
           addlabour-pool self
         ]
  ]
end


to addlabour-pool [a-hh]
  ask a-hh [
    if farming-lab > 0
    [
    set labour-pool labour-pool + farming-lab
    set farming-lab 0
    ]
  ]
end


to seek-labour [labourDef a-hh]
  ask a-hh
  [
    set n-labour-request 0
    set get-labour FALSE
     while [(n-labour-request <= n-l-interact) and (labourdef > 0)]
    [

      let neighbour one-of social-net   ; identify a linked household at random
      let lab-avail [labour-pool] of neighbour    ; calculate available labour
      let lab-count lab-avail - labourdef
      ifelse lab-count > 0
      [
        set get-labour TRUE
        set hh-capital hh-capital - (ag-wage * labourdef)
        set farming-lab farming-lab + labourdef
        ask neighbour [
          set labour-pool labour-pool - labourdef
          set labour-inc (ag-wage * labourdef)
          set agri-work agri-work + labourdef
          ]
        set labourdef 0
      ]
      [
        set get-labour FALSE
        let lab-1 labourdef - lab-avail
        set hh-capital hh-capital - (ag-wage * lab-1)
        set farming-lab farming-lab + lab-1
        ask neighbour [
          set labour-inc (ag-wage * labour-pool)
          set agri-work agri-work + labour-pool
          set labour-pool 0

        ]
        set labourdef labourdef - lab-avail
      ]
      set n-labour-request n-food-request + 1
    ]
    ]
end

to apply-inputs
 ask households
 [
   if hh-inorg-fert > 0 and farming-lab > 0 and hh-land-area > 0
   [
     let patch-fert hh-inorg-fert / count my-farm  ; divide equally between patches
     foreach sort my-farm [ ask ? [set patch-inorg-fert patch-inorg-fert + patch-fert] ]
     set hh-inorg-fert  0
     ]
 ]
end

to apply-pesticides
  ask households
  [
    if count my-farm > 0
    [
    let patch-pest hh-pesticide / count my-farm
    foreach sort my-farm [ ask ? [set patch-pesticide patch-pesticide + patch-pest] ]
    set hh-pesticide 0
    ]
  ]
end

to compute-exp-yield
  harvest
  ask households [
    foreach sort  my-farm [ ask ?
         [
           calc-patch-yield self
         ]
    ]
    set output-p1 sum [patch-output] of patches with [ owner-id  = [hh-id] of myself and patch-cover-type = 1]
    set output-p2 sum [patch-output] of patches with [ owner-id  = [hh-id] of myself and patch-cover-type = 2]
    set output-p3 sum [patch-output] of patches with [ owner-id  = [hh-id] of myself and patch-cover-type = 3]
    set output-p4 sum [patch-output] of patches with [ owner-id  = [hh-id] of myself and patch-cover-type = 4]
    set output-p5 sum [patch-output] of patches with [ owner-id  = [hh-id] of myself and patch-cover-type = 5]
    set output-p6 sum [patch-output] of patches with [ owner-id  = [hh-id] of myself and patch-cover-type = 6]
    set output-p7 sum [patch-output] of patches with [ owner-id  = [hh-id] of myself and patch-cover-type = 7]
    set output-p8 sum [patch-output] of patches with [ owner-id  = [hh-id] of myself and patch-cover-type = 8]
    set output-p9 sum [patch-output] of patches with [ owner-id  = [hh-id] of myself and patch-cover-type = 9]
    set output-p10 sum [patch-output] of patches with [ owner-id  = [hh-id] of myself and patch-cover-type = 10]
    set output-p11 sum [patch-output] of patches with [ owner-id  = [hh-id] of myself and patch-cover-type = 11]

    ; update list of monthly output
    let total-output sum [patch-output] of patches with [owner-id = [hh-id] of myself]
    if month = "Jan" [set jan-out lput total-output jan-out]
    if month = "Feb" [set feb-out lput total-output feb-out]
    if month = "Mar" [set mar-out lput total-output mar-out]
    if month = "Apr" [set apr-out lput total-output apr-out]
    if month = "May" [set may-out lput total-output may-out]
    if month = "Jun" [set jun-out lput total-output jun-out]
    if month = "Jul" [set jul-out lput total-output jul-out]
    if month = "Aug" [set aug-out lput total-output aug-out]
    if month = "Sep" [set sep-out lput total-output sep-out]
    if month = "Oct" [set oct-out lput total-output oct-out]
    if month = "Nov" [set nov-out lput total-output nov-out]
    if month = "Dec" [set dec-out lput total-output dec-out]
  ]
end

to calc-patch-yield [a-patch]
    let lny-patch 0
    if [patch-cover-type] of a-patch = 1 and harvest-time = TRUE
     [
     ; convert everything into per ha
     set labour-ha [labour-accum] of a-patch  / ([patch-area] of a-patch  - [patch-fallow] of a-patch)
     set inorg-fert-ha ([patch-inorg-fert] of a-patch / ([patch-area] of a-patch  - [patch-fallow] of a-patch))
     set org-fert-ha ([patch-org-fert] of a-patch / ([patch-area] of a-patch  - [patch-fallow] of a-patch))
     set inorg inorg-fert-ha
     set lab labour-ha
     set org org-fert-ha
     ; apply regression equation
     set lny-patch 3.12 + (0.382 * ln(annual-rain + 1)) + (0.0000174 * org-fert-ha) + (0.103  * ln(inorg-fert-ha + 1)) + (0.000204 * labour-ha)
     set p-yield exp(lny-patch)
     ; calculate output for the whole plot
     ask a-patch[
       set patch-output p-yield * (patch-area - patch-fallow)
      set labour-accum 0
      set patch-inorg-fert 0
      set patch-org-fert 0
     ]
     ]

     if [patch-cover-type] of a-patch = 2 and harvest-time = TRUE
     [
     ; convert everything into per ha
     set labour-ha [labour-accum] of a-patch / [patch-area] of a-patch
     set inorg-fert-ha ([patch-inorg-fert] of a-patch /[patch-area] of a-patch)
     set org-fert-ha ([patch-org-fert] of a-patch / [patch-area] of a-patch)
     set inorg inorg-fert-ha
     set lab labour-ha
     set org org-fert-ha
     ; apply regression equation
     set lny-patch 2.89 + (0.382 * ln(annual-rain + 1)) + (0.0000174 * org-fert-ha) + (0.103  * ln(inorg-fert-ha + 1)) + (0.000204 * labour-ha)
     set p-yield exp(lny-patch)
     ; calculate output for the whole plot
     ask a-patch [
       set patch-output p-yield * (patch-area - patch-fallow)
       ; set variables of inputs to 0
       set labour-accum  0
       set patch-inorg-fert  0
       set patch-org-fert 0
     ]
     ]

     if [patch-cover-type] of a-patch = 3 and harvest-time = TRUE
     [
     ; convert everything into per ha
     set labour-ha [labour-accum] of a-patch / [patch-area] of a-patch
     set inorg-fert-ha ([patch-inorg-fert] of a-patch / [patch-area] of a-patch)
     set org-fert-ha ([patch-org-fert] of a-patch /[patch-area] of a-patch)
     set inorg inorg-fert-ha
     set lab labour-ha
     set org org-fert-ha
     ; apply regression equation
     set lny-patch  3.11 + (0.382 * ln(annual-rain + 1)) + (0.0000174 * org-fert-ha) + (0.103  * ln(inorg-fert-ha + 1)) + (0.000204 * labour-ha)
     set p-yield exp(lny-patch)
     ; calculate output for the whole plot
     ask a-patch [
       set patch-output p-yield * (patch-area - patch-fallow)
       ;set variables of inputs to 0
       set labour-accum  0
       set patch-inorg-fert  0
       set patch-org-fert 0
     ]
     ]

     if [patch-cover-type] of a-patch = 4 and harvest-time = TRUE
     [
     ; convert everything into per ha
     set labour-ha [labour-accum] of a-patch / [patch-area] of a-patch
     set inorg-fert-ha ([patch-inorg-fert] of a-patch /[patch-area] of a-patch)
     set org-fert-ha ([patch-org-fert] of a-patch / [patch-area] of a-patch)
     set inorg inorg-fert-ha
     set lab labour-ha
     set org org-fert-ha
     ; apply regression equation
     set lny-patch 2.63 + (0.382 * ln(annual-rain + 1)) + (0.0000174 * org-fert-ha) + (0.103  * ln(inorg-fert-ha + 1)) + (0.000204 * labour-ha)
     set p-yield exp(lny-patch)
     ; calculate output for the whole plot
     ask a-patch [
       set patch-output p-yield * (patch-area - patch-fallow)
       ;set variables of inputs to 0
       set labour-accum  0
       set patch-inorg-fert 0
       set patch-org-fert 0
     ]
     ]

     if [patch-cover-type] of a-patch = 5 and harvest-time = TRUE
     [
     ; convert everything into per ha
     set labour-ha [labour-accum] of a-patch / [patch-area] of a-patch
     set inorg-fert-ha ([patch-inorg-fert] of a-patch / [patch-area] of a-patch)
     set org-fert-ha ([patch-org-fert] of a-patch / [patch-area] of a-patch)
     set inorg inorg-fert-ha
     set lab labour-ha
     set org org-fert-ha
     ; apply regression equation
     set lny-patch 2.01 + (0.382 * ln(annual-rain + 1)) + (0.0000174 * org-fert-ha) + (0.103  * ln(inorg-fert-ha + 1)) + (0.000204 * labour-ha)
     set p-yield exp(lny-patch)
     ; calculate output for the whole plot
     ask a-patch [
       set patch-output p-yield * (patch-area - patch-fallow)
       ;set variables of inputs to 0
       set labour-accum 0
       set patch-inorg-fert  0
       set patch-org-fert 0
     ]
     ]

     if [patch-cover-type] of a-patch = 6 and harvest-time = TRUE
     [
     ; convert everything into per ha
     set labour-ha [labour-accum] of a-patch / [patch-area] of a-patch
     set inorg-fert-ha ([patch-inorg-fert] of a-patch / [patch-area] of a-patch)
     set org-fert-ha ([patch-org-fert] of a-patch / [patch-area] of a-patch)
     set inorg inorg-fert-ha
     set lab labour-ha
     set org org-fert-ha
     ; apply regression equation
     set lny-patch 3.33 + (0.382 * ln(annual-rain + 1)) + (0.0000174 * org-fert-ha) + (0.103  * ln(inorg-fert-ha + 1)) + (0.000204 * labour-ha)
     set p-yield exp(lny-patch)
     ; calculate output for the whole plot
     ask a-patch [
       set patch-output p-yield * (patch-area - patch-fallow)
       ;set variables of inputs to 0
       set labour-accum  0
       set patch-inorg-fert  0
       set patch-org-fert 0
     ]
     ]

     if [patch-cover-type] of a-patch = 7 and harvest-time = TRUE
     [
     ; convert everything into per ha
     set labour-ha [labour-accum] of a-patch / [patch-area] of a-patch
     set inorg-fert-ha ([patch-inorg-fert] of a-patch / [patch-area] of a-patch)
     set org-fert-ha ([patch-org-fert] of a-patch / [patch-area] of a-patch)
     set inorg inorg-fert-ha
     set lab labour-ha
     set org org-fert-ha
     ; apply regression equation
     set lny-patch 1.97  + (0.382 * ln(annual-rain + 1)) + (0.0000174 * org-fert-ha) + (0.103  * ln(inorg-fert-ha + 1)) + (0.000204 * labour-ha)
     set p-yield exp(lny-patch)
     ; calculate output for the whole plot
     ask a-patch [
       set patch-output p-yield * (patch-area - patch-fallow)
       ; set variables of inputs to 0
       set labour-accum  0
       set patch-inorg-fert  0
       set patch-org-fert 0
     ]
     ]

     if [patch-cover-type] of a-patch = 8 and harvest-time = TRUE
     [
     ; convert everything into per ha
     set labour-ha [labour-accum] of a-patch / [patch-area] of a-patch
     set inorg-fert-ha ([patch-inorg-fert] of a-patch / [patch-area] of a-patch)
     set org-fert-ha ([patch-org-fert] of a-patch / [patch-area] of a-patch)
     set inorg inorg-fert-ha
     set lab labour-ha
     set org org-fert-ha
     ; apply regression equation
     set lny-patch 1.96 + (0.382 * ln(annual-rain + 1)) + (0.0000174 * org-fert-ha) + (0.103  * ln(inorg-fert-ha + 1)) + (0.000204 * labour-ha)
     set p-yield exp(lny-patch)
     ; calculate output for the whole plot
     ask a-patch [
       set patch-output p-yield * (patch-area - patch-fallow)
       ; set variables of inputs to 0
       set labour-accum 0
       set patch-inorg-fert  0
       set patch-org-fert 0
     ]
     ]

     if [patch-cover-type] of a-patch = 9 and harvest-time = TRUE
     [
     ; convert everything into per ha
     set labour-ha [labour-accum] of a-patch / [patch-area] of a-patch
     set inorg-fert-ha ([patch-inorg-fert] of a-patch / [patch-area] of a-patch)
     set org-fert-ha ([patch-org-fert] of a-patch / [patch-area] of a-patch)
     set inorg inorg-fert-ha
     set lab labour-ha
     set org org-fert-ha
     ; apply regression equation
     set lny-patch 1.98 + (0.382 * ln(annual-rain + 1)) + (0.0000174 * org-fert-ha) + (0.103  * ln(inorg-fert-ha + 1)) + (0.000204 * labour-ha)
     set p-yield exp(lny-patch)
      ask a-patch
     [
       ; calculate output for the whole plot
       set patch-output p-yield * (patch-area - patch-fallow)
       ;set variables of inputs to 0
       set labour-accum  0
       set patch-inorg-fert  0
       set patch-org-fert 0
     ]
     ]

     if [patch-cover-type] of a-patch = 10 and harvest-time = TRUE
     [
     ; convert everything into per ha
     set labour-ha [labour-accum] of a-patch / [patch-area] of a-patch
     set inorg-fert-ha ([patch-inorg-fert] of a-patch / [patch-area] of a-patch)
     set org-fert-ha ([patch-org-fert] of a-patch / [patch-area] of a-patch)
     set inorg inorg-fert-ha
     set lab labour-ha
     set org org-fert-ha
     ; apply regression equation
     set lny-patch 2.24 + (0.382 * ln(annual-rain + 1)) + (0.0000174 * org-fert-ha) + (0.103  * ln(inorg-fert-ha + 1)) + (0.000204 * labour-ha)
     set p-yield exp(lny-patch)
     ; calculate output for the whole plot
     ask a-patch
     [
       set patch-output p-yield * (patch-area - patch-fallow)
       ;set variables of inputs to 0
       set labour-accum  0
       set patch-inorg-fert  0
       set patch-org-fert 0
     ]
     ]

     if [patch-cover-type] of a-patch = 11 and harvest-time = TRUE
     [
     ; convert everything into per ha
     set labour-ha [labour-accum] of a-patch / [patch-area] of a-patch
     set inorg-fert-ha ([patch-inorg-fert] of a-patch / [patch-area] of a-patch)
     set org-fert-ha ([patch-org-fert] of a-patch / [patch-area] of a-patch)
     set inorg inorg-fert-ha
     set lab labour-ha
     set org org-fert-ha
     ; apply regression equation
     set lny-patch 2.68 + (0.382 * ln(annual-rain + 1)) + (0.0000174 * org-fert-ha) + (0.103  * ln(inorg-fert-ha + 1)) + (0.000204 * labour-ha)
     set p-yield exp(lny-patch)
     ; calculate output for the whole plot
     ask a-patch
     [
       set patch-output p-yield * (patch-area - patch-fallow)
       ;set variables of inputs to 0
       set labour-accum  0
       set patch-inorg-fert  0
       set patch-org-fert 0
     ]
     ]
end

to harvest
  ask patches
  [
      if patch-cover-type = 1
      [ifelse month = "Jan" or month = "Apr" [ set harvest-time TRUE] [set harvest-time FALSE]]
      if patch-cover-type = 2
      [ifelse month = "Feb"or month = "Apr" [ set harvest-time TRUE] [set harvest-time FALSE]]
      if patch-cover-type = 3
      [ifelse month = "May" [ set harvest-time TRUE] [set harvest-time FALSE]]
      if patch-cover-type = 4
      [ifelse month = "May" [ set harvest-time TRUE] [set harvest-time FALSE]]
      if patch-cover-type = 5
      [ifelse month = "May" or month = "Aug" [ set harvest-time TRUE] [set harvest-time FALSE]]
      if patch-cover-type = 6
      [ifelse month = "May" [ set harvest-time TRUE] [set harvest-time FALSE]]
      if patch-cover-type = 7
      [ifelse month = "Sep" or month = "May" [ set harvest-time TRUE] [set harvest-time FALSE]]
      if patch-cover-type = 8
      [ifelse month = "Jan" or month = "Apr" or month = "Aug" [ set harvest-time TRUE] [set harvest-time FALSE]]
      if patch-cover-type = 9
      [ifelse month = "Apr" or month = "Sep" [ set harvest-time TRUE] [set harvest-time FALSE]]
      if patch-cover-type = 10
      [ifelse month = "Feb" or month = "May" or month = "Aug" [ set harvest-time TRUE] [set harvest-time FALSE]]
      if patch-cover-type = 11
      [ifelse month = "Jun" or month = "July" [ set harvest-time TRUE] [set harvest-time FALSE]]
      if patch-cover-type = 0
      [ set harvest-time FALSE ]
  ]
end

to process-yield
  ask households
  [
    set out-anroots output-p1
    set out-grains output-p2 + (0.9 * output-p3) + (0.5 * output-p9) + (0.4 * output-p10) + (0.25 * output-p11)
    set out-pulses output-p4 + (0.1 * output-p3) + (0.1 * output-p10) + (0.25 * output-p11)
    set out-peroots output-p5 + (0.25 * output-p11)
    set out-veg output-p7
    set out-fruit output-p8 + (0.5 * output-p9) + (0.5 * output-p10) + (0.25 * output-p11)
    set out-cash output-p6
    if hh-type = 1 and agri-type = "Wet"
    [
      set eat-anroots 0.87 * out-anroots * cf-anroots ; eaten annual roots (calories)
      set sell-anroots 0.13 * out-anroots * value-anroots * m-efficiency ; sold annual roots (dollars)
      set lost-anroots 0.0 * out-anroots ; lost annual roots (kg)

      set eat-grains 0.95 * out-grains * cf-grains ; eaten grains (calories)
      set sell-grains 0.4 * out-grains * value-grains * m-efficiency ; sold grains (dollars)
      set lost-grains 0.1 * out-grains ; lost grains (kg)

      set eat-pulses 0.67 * out-pulses * cf-pulses ; eaten pulses (calories)
      set sell-pulses 0.21 * out-pulses * value-pulses * m-efficiency  ; sold pulses (dollars)
      set lost-pulses 0.12 * out-pulses ; lost pulses (kg)

      set eat-peroots 0.88 * out-peroots * cf-peroots ; eaten perm roots  (calories)
      set sell-peroots 0.11 * out-peroots * value-peroots * m-efficiency  ; sold perm roots (dollars)
      set lost-peroots 0.01 * out-peroots ; lost perm roots (kg)

      set eat-veg 0.36 * out-veg * cf-veg ; eaten veg (calories)
      set sell-veg 0.64 * out-veg * value-veg * m-efficiency ; sold veg (dollars)
      set lost-veg 0.0 * out-veg ; lost veg (kg)

      set eat-fruit 0.86 * out-fruit * cf-fruit ; eaten fruit (calories)
      set sell-fruit 0.14 * out-fruit * value-fruit * m-efficiency ; sold fruit (dollars)
      set lost-fruit 0.0 * out-fruit ; lost fruit (kg)

      set eat-cash-crops 0.20 * out-cash * cf-cash ; eaten cash crop (calories)
      set sell-cash-crops 0.79 * out-cash * value-cash * m-efficiency ; sold cash crop (dollars)
      set lost-cash-crops 0.01 * out-cash ; lost acash crop (kg)
      ]

    if hh-type = 1 and agri-type = "Dry"
    [
      set eat-anroots 0.59 * out-anroots * cf-anroots ; eaten annual roots (calories)
      set sell-anroots 0.40 * out-anroots * value-anroots * m-efficiency ; sold annual roots (dollars)
      set lost-anroots 0.0 * out-anroots ; lost annual roots (kg)

      set eat-grains 0.86 * out-grains * cf-grains ; eaten grains (calories)
      set sell-grains 0.13 * out-grains * value-grains * m-efficiency ; sold grains (dollars)
      set lost-grains 0.01 * out-grains ; lost grains (kg)

      set eat-pulses 0.83 * out-pulses * cf-pulses ; eaten pulses (calories)
      set sell-pulses 0.17 * out-pulses * value-pulses * m-efficiency ; sold pulses (dollars)
      set lost-pulses 0.00 * out-pulses ; lost pulses (kg)

      set eat-peroots 0.88 * out-peroots * cf-peroots ; eaten perm roots  (calories)
      set sell-peroots 0.11 * out-peroots * value-peroots * m-efficiency ; sold perm roots (dollars)
      set lost-peroots 0.01 * out-peroots ; lost perm roots (kg)

      set eat-veg 0.26 * out-veg * cf-veg ; eaten veg (calories)
      set sell-veg 0.73 * out-veg * value-veg * m-efficiency ; sold veg (dollars)
      set lost-veg 0.01 * out-veg ; lost veg (kg)

      set eat-fruit 0.86 * out-fruit * cf-fruit ; eaten fruit (calories)
      set sell-fruit 0.14 * out-fruit * value-fruit ; sold fruit (dollars)
      set lost-fruit 0.0 * out-fruit ; lost fruit (kg)

      set eat-cash-crops 0.68 * out-cash * cf-cash ; eaten cash crop (calories)
      set sell-cash-crops 0.32 * out-cash * value-cash * m-efficiency ; sold cash crop (dollars)
      set lost-cash-crops 0.00 * out-cash ; lost acash crop (kg)
      ]

    if hh-type = 2 and agri-type = "Wet"
    [
      set eat-anroots 0.7 * out-anroots * cf-anroots ; eaten annual roots (calories)
      set sell-anroots 0.26 * out-anroots * value-anroots * m-efficiency ; sold annual roots (dollars)
      set lost-anroots 0.03 * out-anroots ; lost annual roots (kg)

      set eat-grains 0.98 * out-grains * cf-grains ; eaten grains (calories)
      set sell-grains 0.01 * out-grains * value-grains * m-efficiency ; sold grains (dollars)
      set lost-grains 0.01 * out-grains ; lost grains (kg)

      set eat-pulses 0.95 * out-pulses * cf-pulses ; eaten pulses (calories)
      set sell-pulses 0.05 * out-pulses * value-pulses * m-efficiency ; sold pulses (dollars)
      set lost-pulses 0.0 * out-pulses ; lost pulses (kg)

      set eat-peroots 0.95 * out-peroots * cf-peroots ; eaten perm roots  (calories)
      set sell-peroots 0.04 * out-peroots * value-peroots * m-efficiency ; sold perm roots (dollars)
      set lost-peroots 0.01 * out-peroots ; lost perm roots (kg)

      set eat-veg 0.69 * out-veg * cf-veg ; eaten veg (calories)
      set sell-veg 0.33 * out-veg * value-veg * m-efficiency ; sold veg (dollars)
      set lost-veg 0.00 * out-veg ; lost veg (kg)

      set eat-fruit 1 * out-fruit * cf-fruit ; eaten fruit (calories)
      set sell-fruit 0.0 * out-fruit * value-fruit * m-efficiency ; sold fruit (dollars)
      set lost-fruit 0.0 * out-fruit ; lost fruit (kg)

      set eat-cash-crops 0.29 * out-cash * cf-cash ; eaten cash crop (calories)
      set sell-cash-crops 0.70 * out-cash * value-cash * m-efficiency ; sold cash crop (dollars)
      set lost-cash-crops 0.01 * out-cash ; lost acash crop (kg)

    ]

    if hh-type = 2 and agri-type = "Dry"
    [
      set eat-anroots 0.61 * out-anroots * cf-anroots ; eaten annual roots (calories)
      set sell-anroots 0.34 * out-anroots * value-anroots * m-efficiency ; sold annual roots (dollars)
      set lost-anroots 0.05 * out-anroots ; lost annual roots (kg)

      set eat-grains 0.75 * out-grains * cf-grains ; eaten grains (calories)
      set sell-grains 0.22 * out-grains * value-grains * m-efficiency ; sold grains (dollars)
      set lost-grains 0.03 * out-grains ; lost grains (kg)

      set eat-pulses 1.0 * out-pulses * cf-pulses ; eaten pulses (calories)
      set sell-pulses 0.0 * out-pulses * value-pulses * m-efficiency ; sold pulses (dollars)
      set lost-pulses 0.0 * out-pulses ; lost pulses (kg)

      set eat-peroots 0.95 * out-peroots * cf-peroots ; eaten perm roots  (calories)
      set sell-peroots 0.04 * out-peroots * value-peroots * m-efficiency ; sold perm roots (dollars)
      set lost-peroots 0.01 * out-peroots ; lost perm roots (kg)

      set eat-veg 0.31 * out-veg * cf-veg ; eaten veg (calories)
      set sell-veg 0.69 * out-veg * value-veg * m-efficiency ; sold veg (dollars)
      set lost-veg 0.00 * out-veg ; lost veg (kg)

      set eat-fruit 1.0 * out-fruit * cf-fruit ; eaten fruit (calories)
      set sell-fruit 0.0 * out-fruit * value-fruit * m-efficiency ; sold fruit (dollars)
      set lost-fruit 0.0 * out-fruit ; lost fruit (kg)

      set eat-cash-crops 0.0 * out-cash * cf-cash ; eaten cash crop (calories)
      set sell-cash-crops 1.0 * out-cash * value-cash * m-efficiency ; sold cash crop (dollars)
      set lost-cash-crops 0.0 * out-cash ; lost acash crop (kg)
    ]
    if hh-type = 3 and agri-type = "Wet"
    [
      set eat-anroots 0.8 * out-anroots * cf-anroots ; eaten annual roots (calories)
      set sell-anroots 0.2 * out-anroots * value-anroots * m-efficiency ; sold annual roots (dollars)
      set lost-anroots 0.0 * out-anroots ; lost annual roots (kg)

      set eat-grains 0.96 * out-grains * cf-grains ; eaten grains (calories)
      set sell-grains 0.02 * out-grains * value-grains * m-efficiency ; sold grains (dollars)
      set lost-grains 0.02 * out-grains ; lost grains (kg)

      set eat-pulses 0.81 * out-pulses * cf-pulses ; eaten pulses (calories)
      set sell-pulses 0.18 * out-pulses * value-pulses * m-efficiency ; sold pulses (dollars)
      set lost-pulses 0.01 * out-pulses ; lost pulses (kg)

      set eat-peroots 0.95 * out-peroots * cf-peroots ; eaten perm roots  (calories)
      set sell-peroots 0.05 * out-peroots * value-peroots * m-efficiency ; sold perm roots (dollars)
      set lost-peroots 0.0 * out-peroots ; lost perm roots (kg)

      set eat-veg 0.26 * out-veg * cf-veg ; eaten veg (calories)
      set sell-veg 0.74 * out-veg * value-veg * m-efficiency ; sold veg (dollars)
      set lost-veg 0.0 * out-veg ; lost veg (kg)

      set eat-fruit 0.71 * out-fruit * cf-fruit ; eaten fruit (calories)
      set sell-fruit 0.29 * out-fruit * value-fruit * m-efficiency ; sold fruit (dollars)
      set lost-fruit 0.0 * out-fruit ; lost fruit (kg)

      set eat-cash-crops 0.21 * out-cash * cf-cash ; eaten cash crop (calories)
      set sell-cash-crops 0.79 * out-cash * value-cash * m-efficiency ; sold cash crop (dollars)
      set lost-cash-crops 0.0 * out-cash ; lost acash crop (kg)
    ]
    if hh-type = 3 and agri-type = "Dry"
    [
      set eat-anroots 0.74 * out-anroots * cf-anroots ; eaten annual roots (calories)
      set sell-anroots 0.25 * out-anroots * value-anroots * m-efficiency ; sold annual roots (dollars)
      set lost-anroots 0.01 * out-anroots ; lost annual roots (kg)

      set eat-grains 0.79 * out-grains * cf-grains ; eaten grains (calories)
      set sell-grains 0.21 * out-grains * value-grains * m-efficiency ; sold grains (dollars)
      set lost-grains 0.0 * out-grains ; lost grains (kg)

      set eat-pulses 0.93 * out-pulses * cf-pulses ; eaten pulses (calories)
      set sell-pulses 0.07 * out-pulses * value-pulses * m-efficiency ; sold pulses (dollars)
      set lost-pulses 0.0 * out-pulses ; lost pulses (kg)

      set eat-peroots 0.85 * out-peroots * cf-peroots ; eaten perm roots  (calories)
      set sell-peroots 0.05 * out-peroots * value-peroots * m-efficiency ; sold perm roots (dollars)
      set lost-peroots 0.0 * out-peroots ; lost perm roots (kg)

      set eat-veg 0.33 * out-veg * cf-veg ; eaten veg (calories)
      set sell-veg 0.67 * out-veg * value-veg * m-efficiency ; sold veg (dollars)
      set lost-veg 0.0 * out-veg ; lost veg (kg)

      set eat-fruit 0.71 * out-fruit * cf-fruit ; eaten fruit (calories)
      set sell-fruit 0.29 * out-fruit * value-fruit * m-efficiency ; sold fruit (dollars)
      set lost-fruit 0.0 * out-fruit ; lost fruit (kg)

      set eat-cash-crops 0.0 * out-cash * cf-cash ; eaten cash crop (calories)
      set sell-cash-crops 1.0 * out-cash * value-cash * m-efficiency ; sold cash crop (dollars)
      set lost-cash-crops 0.0 * out-cash ; lost acash crop (kg)
    ]
  ]
end


; TENDING TO LIVESTOCK       ; for now this is simply a function of labour and livestock unit
to tend-livestock
  ask households
  [
    if tlu = 0
    [
      set tlu (goats-owned * 0.1) + (cattle-owned * 0.5) + (chickens-owned * 0.01) ; update tlu to take into account any additions to hh livestock
    ]
    if tlu > 0 and hh-type = 1 ; calculate output for livestock units
    [
      set meat-output tlu * fh-labour * hh1-meat
      set egg-output  tlu * fh-labour * hh1-egg
      set milk-output tlu * fh-labour * hh1-milk
      set manure-output tlu * fh-labour * hh1-manure
      ]
    if tlu > 0 and hh-type = 2
    [
      set meat-output tlu * fh-labour * hh2-meat
      set egg-output tlu * fh-labour * hh2-egg
      set milk-output tlu * fh-labour * hh2-milk
      set manure-output tlu * fh-labour * hh2-manure
      ]
    if tlu > 0 and hh-type = 3
    [
      set meat-output tlu * fh-labour * hh3-meat
      set egg-output tlu * fh-labour * hh3-egg
      set milk-output tlu * fh-labour * hh3-milk
      set manure-output tlu * fh-labour * hh3-manure
      ]

    ]
end


to process-livestock
  ask households
  [
    set eat-milk 0.32 * milk-output  * cf-milk
    set sell-milk 0.14 * milk-output * value-milk * m-efficiency
    set lost-milk 0.54 * milk-output

    if hh-type = 1
    [
      set eat-meat 0.61 * meat-output * cf-meat
      set sell-meat 0.15 * meat-output * value-meat * m-efficiency
      set lost-meat 0.24 * meat-output

      set eat-egg 0.29 * egg-output * cf-egg
      set sell-egg 0.0 * egg-output * value-egg * m-efficiency
      set lost-egg 0.71 * egg-output
    ]

    if hh-type = 2
    [
      set eat-meat 0.69 * meat-output * cf-meat
      set sell-meat 0.0 * meat-output * value-meat * m-efficiency
      set lost-meat 0.31 * meat-output

      set eat-egg 0.30 * egg-output * cf-egg
      set sell-egg 0.0 * egg-output * value-egg * m-efficiency
      set lost-egg 0.70 * egg-output
    ]

   if hh-type = 3
   [
      set eat-meat 0.64 * meat-output * cf-meat
      set sell-meat 0.08 * meat-output * value-meat * m-efficiency
      set lost-meat 0.28 * meat-output

      set eat-egg 0.26 * egg-output * cf-egg
      set sell-egg 0.0 * egg-output * value-egg * m-efficiency
      set lost-egg 0.74 * egg-output
    ]
  ]
end

to manure
  ; for now assume manure is the result of a passive process (animal excretion left on patches)
  ask households
  [
  if manure-output > 0 and count my-farm > 0
  [
    let manure-patch manure-output / count my-farm  ; assume distribution of manure is equal amongst patches owned
    foreach sort my-farm [ask ? [ set patch-org-fert patch-org-fert + manure-patch ]] ; update organic fertiliser inputs on each patch
  ]
  ]

  end

to update-livestock
  ask households
  [

    if hh-type = 1 [set tlu-growth log-normal 0.1303434 0.2001746]
    if hh-type = 2 [set tlu-growth log-normal 0.1345572 0.1640915]
    if hh-type = 3 [set tlu-growth log-normal 0.1460708 0.2098184]

    if tlu > 0.01 [ set tlu tlu * tlu-growth ]

    if tlu < 0.01 and hh-type = 1 [
      ifelse random 101 <= tlu-prob-1 [set tlu 0.14] [set tlu 0]
      ]
    if tlu < 0.01 and hh-type = 2 [
      ifelse random 101 <= tlu-prob-2 [set tlu 0.14] [set tlu 0]
      ]
    if tlu < 0.01 and hh-type = 3 [
      ifelse random 101 <= tlu-prob-3 [set tlu 0.12] [set tlu 0]
      ]
    ]
  end

; FORAGING

to go-foraging
  ask households
  [
    if hh-type = 1 and fw-labour > 0
    [
      set eat-forage-veg log-normal 316.0 1163.2
      set eat-forage-fruit log-normal 96.0 879.6
    ]

    if hh-type = 2 and fw-labour > 0
     [
      set eat-forage-veg log-normal 246.2 887.0
      set eat-forage-fruit log-normal 166.3 1300.1
    ]

   if hh-type = 3 and fw-labour > 0
    [
      set eat-forage-veg log-normal 187.6 886.5
      set eat-forage-fruit log-normal 122.6 901.8
    ]
  ]
end

; OFF-FARM NON-AGRICULTURAL WORK
to off-farm-nonagwork
  ask households
[
  let nag na-labour * nag-avail
  set n-agri-work n-agri-work + nag
  set off-nonag-output nag * nag-wage
]
end

;SPENDING CAPACITY
to non-food-expense
  ask households
  [
    if hh-type = 1  [set m-nonf-expense log-normal 3.95 9.67]
    if hh-type = 2  [set m-nonf-expense log-normal 3.74 7.10]
    if hh-type = 3  [set m-nonf-expense log-normal 8.76 15.93]
  ]
end


to-report log-normal[a b]
  ; reports log-normal distribution

  ifelse (a > 0.0) and (b > 0.0)
  [let c  ln ( 1 + (b ^ 2 / a ^ 2))
  let M  ln (a) - (c / 2)
  let S  sqrt c
  report exp (random-normal M S)]
  [let p-act random-normal a b
   set p-act p-act ^ 2
   report sqrt p-act
  ]
end

to calc-income
  ask households
  [
    if hh-type = 1
    [
      set m-remitt log-normal 1.06 13.56
      set other-inc log-normal 0.79 11.67
      let ganyu-inc  labour-inc
      set crop-sales sell-anroots + sell-grains + sell-pulses + sell-peroots + sell-veg + sell-fruit + sell-cash-crops
      set hh-capital hh-capital + m-remitt + other-inc + ganyu-inc + off-nonag-output + crop-sales
      ]
      if hh-type = 2
    [
      set m-remitt log-normal 0.26 1.27
      set other-inc log-normal 0.40 5.11
      let ganyu-inc  labour-inc
      set crop-sales sell-anroots + sell-grains + sell-pulses + sell-peroots + sell-veg + sell-fruit + sell-cash-crops
      set hh-capital hh-capital + m-remitt + other-inc + ganyu-inc + off-nonag-output  + crop-sales
      ]

  if hh-type = 3
    [
      set m-remitt log-normal 0.47 5.08
      set other-inc log-normal 2.23 19.67
      let ganyu-inc  labour-inc
      set crop-sales sell-anroots + sell-grains + sell-pulses + sell-peroots + sell-veg + sell-fruit + sell-cash-crops
      set hh-capital hh-capital + m-remitt + other-inc + ganyu-inc + off-nonag-output +  crop-sales
      ]
  ]

end

to calc-spending-cap
  ask households
  [
    ;ifelse hh-capital > 0 [set m-nonf-expense hh-capital * expense-prop] [set m-nonf-expense 0]
    set spending-cap hh-capital - m-nonf-expense
    if spending-cap < 0 [set spending-cap 0]
    set spending-cal (spending-cap / value-grains) * cf-grains * m-efficiency
    set hh-capital hh-capital - m-nonf-expense
  ]
end


; FOOD AVAILABILITY ; potential amount of calories available from self-production, along with the potential amount of calories available from the market.

to calc-food-availability
  ask households [
    let food-output out-anroots + out-grains + out-pulses + out-peroots + out-veg + out-fruit + meat-output + egg-output + milk-output  + eat-forage-veg + eat-forage-fruit
    set food-availability food-output + spending-cal
    let actual eat-anroots + eat-grains + eat-pulses + eat-peroots + eat-veg + eat-fruit + eat-meat + eat-egg + eat-milk  + eat-forage-veg + eat-forage-fruit
    set surplus (actual + spending-cal) - (hh-food-needs * multiplier)
    if surplus >= 0
    [
      set calorie-pool surplus
      ifelse (hh-food-needs * multiplier) - actual > 0
      [ set actual-cal-pool 0
        set spend-cal-pool (spending-cal - ((hh-food-needs * multiplier) - actual))
      ]
      [
        set actual-cal-pool actual - hh-food-needs
        set spend-cal-pool spending-cal
      ]
    ]
    if surplus < 0 [
      set calorie-deficit -1 * surplus
      set calorie-pool 0
      set actual-cal-pool 0
      set spend-cal-pool 0
      ]
  ]
end


; COPING STRATEGIES ; amount of calories potentially available from coping strategies

to pot-cash-for-work
  ask households [
    if (hh-type = 1) and (random-float 1 <= pw1-access) and (labour-pool > 0); if access to public work programme is true
    [
      let pwp-inc log-normal 1.35 0.42           ; calculate value of work (in dollars)
      let pwp-maize (pwp-inc / value-grains) * m-efficiency   ; convert income into maize (in kg)
      set pwp-calories pwp-maize * cf-grains  ; convert maize into calories (Kcals)
      let cal-count calorie-deficit - pwp-calories
      ifelse cal-count > 0 [ set calorie-deficit cal-count ]
      [ set calorie-deficit 0
        set calorie-pool calorie-pool + (-1 * cal-count) ]
    ]
    if (hh-type = 2) and (random-float 1 <= pw2-access) and (labour-pool > 0)
    [
      let pwp-inc log-normal 1.75 1.45          ; calculate value of work (in dollars)
      let pwp-maize (pwp-inc / value-grains) * m-efficiency   ; convert income into maize (in kg)
      set pwp-calories pwp-maize * cf-grains  ; convert maize into calories (Kcals)
      let cal-count calorie-deficit - pwp-calories
      ifelse cal-count > 0 [ set calorie-deficit cal-count ]
      [ set calorie-deficit 0
        set calorie-pool calorie-pool + (-1 * cal-count) ]
    ]
    if (hh-type = 3) and (random-float 1 <= pw3-access) and (labour-pool > 0)
    [
      let pwp-inc log-normal 1.74 1.37           ; calculate value of work (in dollars)
      let pwp-maize (pwp-inc / value-grains) * m-efficiency   ; convert income into maize (in kg)
      set pwp-calories pwp-maize * cf-grains  ; convert maize into calories (Kcals)
      let cal-count calorie-deficit - pwp-calories
      ifelse cal-count > 0 [ set calorie-deficit cal-count ]
      [ set calorie-deficit 0
        set calorie-pool calorie-pool + (-1 * cal-count) ]
    ]
  ]
end

to pot-borrow-food
  ask households
  [
    set n-food-request 0
    while [(n-food-request <= n-f-interact) and (calorie-deficit > 0)]
    [

      let neighbour one-of social-net; identify a linked household at random
      let cal-avail [calorie-pool] of neighbour    ; calculate available labour
      let cal-count cal-avail - calorie-deficit
      ifelse cal-count > 0
      [
        set borrow-food borrow-food + calorie-deficit
        let caldef calorie-deficit
        ask neighbour [
          ifelse actual-cal-pool >= caldef
          [ set actual-cal-pool actual-cal-pool - caldef ]
          [
            set caldef caldef - actual-cal-pool
            set spend-cal-pool spend-cal-pool - caldef
            set hh-capital hh-capital - (caldef / cf-grains * value-grains)
            set actual-cal-pool 0
          ]
          set calorie-pool calorie-pool - caldef
          ]
        set calorie-deficit 0
      ]
      [
        set borrow-food borrow-food + cal-avail
        ask neighbour [
          set calorie-pool 0
          set hh-capital hh-capital - (spend-cal-pool / cf-grains * value-grains)
          set spend-cal-pool 0
          set actual-cal-pool 0
          ]
        set calorie-deficit calorie-deficit - cal-avail

      ]
      set n-food-request n-food-request + 1
    ]
    ]
end

to sell-livestock
  ask households
  [
    while [calorie-deficit > 0 and (tlu > 0.01)]
    [
      let cal-tlu ( value-tlu / value-grains) * 0.8 * cf-grains * m-efficiency
      set tlu tlu - 0.01
      let count-cal calorie-deficit - cal-tlu
      set sale-livestock sale-livestock + cal-tlu
      ifelse count-cal > 0
      [ set  calorie-deficit calorie-deficit - cal-tlu]
      [ set calorie-deficit 0 ]
    ]
  ]
  end

to calc-food-access
  ask households  ; total calories available from production, market & adaptive strategies
  [
    ifelse surplus > 0
    [ set food-access (hh-food-needs + calorie-pool)]
    [ set food-access  (eat-anroots + eat-grains + eat-pulses + eat-peroots + eat-veg + eat-fruit + eat-meat + eat-egg + eat-milk  + eat-forage-veg + eat-forage-fruit + spending-cal + pwp-calories + borrow-food + sale-livestock)]
    ]
end

to process-ability
  ask households
  [
    ; use the fuzzy logic inference system (FIS) to calculate process-ability
    nlfuzzy:use-fcl "proability.fcl"

    let wood-level firewood-stock / hh-needs * 100
    if wood-level > 100 [set wood-level 100]
    let water-level water-stock / hh-water-cons * 100
    ; print water-level
    if water-level > 100 [set water-level 100]
    let healthy hh-member with [illness  = "FALSE"]
    let prop-healthy ( count healthy) / hh-size * 100

    ; fuzzify input values
    nlfuzzy:set-value "wood_level" wood-level
    nlfuzzy:set-value "water_level" water-level
    nlfuzzy:set-value "prop_healthy" prop-healthy

    ; defuzzify output variable
    set hh-process-ability (nlfuzzy:eval "process_ability")
  ]
end


to calc-food-utilisation    ; given availability, access and process abilty constraints calculate actual calories consumed
  ask households
  [
    set food-utilisation food-access * (hh-process-ability / 100)
    ; apply a cap to limit the amount of calories a household is likely to eat (1.5 * needs)
    ; determine whether food needs are met or not
    if food-utilisation <=  multiplier * hh-food-needs
    [
      ifelse surplus > 0 [set bought-calories spend-cal-pool] [ set bought-calories spending-cal ]
    ]
    if food-utilisation > multiplier * hh-food-needs
    [
      set food-utilisation multiplier * hh-food-needs
      ifelse surplus > 0
      [
        set bought-calories food-utilisation - hh-food-needs
        ifelse bought-calories - actual-cal-pool <= 0
        [set bought-calories 0] [set bought-calories bought-calories - actual-cal-pool ]
      ]
      [
        set bought-calories food-utilisation - (eat-anroots + eat-grains + eat-pulses + eat-peroots + eat-veg + eat-fruit + eat-meat + eat-egg + eat-milk  + eat-forage-veg + eat-forage-fruit + pwp-calories + borrow-food + sale-livestock)
        ]
    ]
    set hh-capital hh-capital - (bought-calories / cf-grains * value-grains * m-efficiency)

    ifelse food-utilisation >= hh-food-needs
    [set met-food-needs 0]
    [set met-food-needs 1]

    ; update stocks of water and fuel
    set water-stock 0
    let firewood firewood-stock - hh-needs
    ifelse firewood >= 0 [set firewood-stock firewood ] [set firewood-stock 0]
  ]
end

to summarise-hh-diet
  ask households
  [
    ; determine proportion of diet from different food-types
    let grains eat-grains + bought-calories + pwp-calories + borrow-food + sale-livestock
    let anroots eat-anroots
    let peroots eat-peroots
    let pulse eat-pulses
    let veg eat-veg
    let fruit eat-fruit
    let meat eat-meat
    let egg eat-egg
    let milk eat-milk
    let forage eat-forage-veg + eat-forage-fruit

    let total grains + anroots + peroots + veg + fruit + meat + egg + milk + forage  + pulse
    if total > 0
    [
      let prop-grains grains / total * 100
      let prop-anroots anroots / total * 100
      let prop-peroots peroots / total * 100
      let prop-veg veg / total * 100
      let prop-fruit fruit / total * 100
      let prop-meat meat / total * 100
      let prop-egg egg / total * 100
      let prop-milk milk / total * 100
      let prop-forage forage / total * 100
      let prop-pulse pulse / total * 100

      ; calculate the percentage of food energy from staples (cereals, roots and tubers)
      let staples  grains + anroots + peroots
      set hh-prop-staples staples / total * 100

      ; calculate diet diversity as the number of unique food types eaten (of 8 possible types)
      ifelse prop-grains > 0 [set cereals 1] [set cereals 0]
      ifelse prop-fruit > 0 [set fruits 1] [set fruits 0]
      ifelse prop-meat > 0 or prop-egg > 0 [set meats 1] [ set meats 0]
      ifelse prop-milk > 0 [set milks 1] [set milks 0]
      ifelse prop-pulse > 0 [set nuts 1] [set nuts 0]
      ifelse prop-anroots > 0 or prop-peroots > 0 [set roots 1] [set roots 0]
      ifelse prop-veg > 0 [set vegs 1 ] [set vegs 0]
      ifelse prop-forage > 0 [set forages 1 ] [set forages 0]

      set diet-diversity cereals + fruits + meats + milks + nuts + roots + vegs + forages
    ]
      ; calculate daily food energy consumption per capita
      set daily-fecpc (food-utilisation / hh-size) / 30
  ]
end

to calc-prod-stability ; production stability is a measure of the variability of a households yield
   ask households
   [
     if month = "Jan" [ set hh-prod-stability cv jan-out ]
     if month = "Feb" [ set hh-prod-stability cv feb-out ]
     if month = "Mar" [ set hh-prod-stability cv mar-out ]
     if month = "Apr" [ set hh-prod-stability cv apr-out ]
     if month = "May" [ set hh-prod-stability cv may-out ]
     if month = "Jun" [ set hh-prod-stability cv jun-out ]
     if month = "Jul" [ set hh-prod-stability cv jul-out ]
     if month = "Aug" [ set hh-prod-stability cv aug-out ]
     if month = "Sep" [ set hh-prod-stability cv sep-out ]
     if month = "Oct" [ set hh-prod-stability cv oct-out ]
     if month = "Nov" [ set hh-prod-stability cv nov-out ]
     if month = "Dec" [ set hh-prod-stability cv dec-out ]
   ]
end

to-report cv [a-list] ; reports the coefficient of variation
  let cv-value 0
  ifelse length a-list > 1 and mean a-list > 0
  [set cv-value (standard-deviation a-list / mean a-list) * 100]
  [set cv-value 0]
  report cv-value
end

to calc-food-stability
  ; political stability is measured as the coefficient of variation of annual
  ; policy programmes for inputs and public work programmes
  set past-input-pol lput (p1-access + p2-access + p3-access / 3) past-input-pol
  set past-pw-pol lput (pw1-access + pw2-access + p3-access / 3) past-pw-pol
  set political-stability (cv past-input-pol + cv past-pw-pol / 2)
  ; market stability is measured as the coefficient of variation in annual maize price
  set market-stability cv grain-stability
  ; use the fuzzy logic inference system (FIS) to calculate process-ability
  ask households
  [
    nlfuzzy:use-fcl "stability.fcl"
    ; fuzzify input values
    nlfuzzy:set-value "market_stability" market-stability
    nlfuzzy:set-value "political_stability" political-stability
    nlfuzzy:set-value "prod_stability" hh-prod-stability
    ; defuzzify output variable
    set food-stability (nlfuzzy:eval "food_stability")
  ]
 end

to calc-food-security
  ask households
  [
    nlfuzzy:use-fcl "foodsecurity.fcl"

    set availability-status food-availability / hh-food-needs * 100
    if availability-status > 100 [set availability-status 100]
    set access-status food-access / hh-food-needs * 100
    if access-status > 100 [set access-status 100]
    set utilisation-status food-utilisation / hh-food-needs * 100
    if utilisation-status > 100 [set utilisation-status 100]


    ; fuzzify input values
    nlfuzzy:set-value "availability" availability-status
    nlfuzzy:set-value "access" access-status
    nlfuzzy:set-value "utilisation" utilisation-status
    nlfuzzy:set-value "stability" food-stability

    ; defuzzify output variable
    set food-security (nlfuzzy:eval "food_security")
  ]
end

to set-health-status
  ask individuals
  [
    let rand-health random-float 101
    ifelse ( [met-food-needs] of households with [hh-id = [family-id] of myself] = 1 ) and rand-health <= 30
    [set illness "TRUE"]
    [set illness "FALSE"]
    ifelse ( [met-food-needs] of households with [hh-id = [family-id] of myself] = 0 ) and rand-health <= 15
    [set illness "TRUE"]
    [set illness "FALSE"]
  ]
end

to model-outcomes
 ; COUNTS
 set count-h1 count households with [hh-type = 1]
 set count-h2 count households with [hh-type = 2]
 set count-h3 count households with [hh-type = 3]

  ; AVAILABILITY
  ; potential availability of calories from production and the market
  ifelse count households with [hh-type = 1] > 0 [set h1-avail mean [food-availability] of households with [hh-type = 1]] [set h1-avail 0]
  ifelse count households with [hh-type = 2] > 0 [set h2-avail mean [food-availability] of households with [hh-type = 2]] [set h1-avail 0]
  ifelse count households with [hh-type = 3] > 0 [set h3-avail mean [food-availability] of households with [hh-type = 3]] [set h1-avail 0]

   ; average yield of farm patches
  set av-yield mean [p-yield] of patches with [patch-type = 2 and owner-id > 0]
  set av-yield-dimba mean [p-yield] of patches with [patch-type = 3 and owner-id > 0]

  ; ACCESS
  ; average amount of accessable calories
  ifelse count households with [hh-type = 1] > 0 [set h1-access mean [food-access] of households with [hh-type = 1]] [set h1-access 0]
  ifelse count households with [hh-type = 2] > 0 [set h2-access mean [food-access] of households with [hh-type = 2]] [set h2-access 0]
  ifelse count households with [hh-type = 3] > 0 [set h3-access mean [food-access] of households with [hh-type = 3]] [set h3-access 0]

  ; average daily food energy consumption per capita
  ifelse count households with [hh-type = 1] > 0 [set h1-fecc mean [daily-fecpc] of households with [hh-type = 1]] [set h1-fecc 0]
  ifelse count households with [hh-type = 2] > 0 [set h2-fecc mean [daily-fecpc] of households with [hh-type = 2]] [set h2-fecc 0]
  ifelse count households with [hh-type = 3] > 0 [set h3-fecc mean [daily-fecpc] of households with [hh-type = 3]] [set h3-fecc 0]

  ; proportion of households that are food energy deficient
  ifelse count households with [hh-type = 1] > 0 [set prop-h1-defic (sum [met-food-needs] of households with [hh-type = 1] /  count households with [hh-type = 1]) * 100] [set prop-h1-defic 0]
  ifelse count households with [hh-type = 2] > 0  [set prop-h2-defic (sum [met-food-needs] of households with [hh-type = 2] /  count households with [hh-type = 2]) * 100] [set prop-h2-defic 0]
  ifelse count households with [hh-type = 3] > 0 [set prop-h3-defic (sum [met-food-needs] of households with [hh-type = 3] /  count households with [hh-type = 3]) * 100] [set prop-h3-defic 0]

  ; UTILISATION
  ; average diet diversity
  ifelse count households with [hh-type = 1] > 0 [set h1-diversity mean [diet-diversity] of households with [hh-type = 1]] [set h1-diversity 0]
  ifelse count households with [hh-type = 2] > 0 [set h2-diversity mean [diet-diversity] of households with [hh-type = 2]] [set h2-diversity 0]
  ifelse count households with [hh-type = 3] > 0 [set h3-diversity mean [diet-diversity] of households with [hh-type = 3]] [set h3-diversity 0]

  ; average percentage of food energy from staples
  ifelse count households with [hh-type = 1] > 0 [set h1-propstaples mean [hh-prop-staples] of households with [hh-type = 1]] [set h1-propstaples 0]
  ifelse count households with [hh-type = 2] > 0 [set h2-propstaples mean [hh-prop-staples] of households with [hh-type = 2]] [set h2-propstaples 0]
  ifelse count households with [hh-type = 3] > 0 [set h3-propstaples mean [hh-prop-staples] of households with [hh-type = 3]] [set h3-propstaples 0]

  ; %  process ability hh
  ifelse count households with [hh-type = 1] > 0 [set h1-pa mean [hh-process-ability] of households with [hh-type = 1]] [set h1-pa 0]
  ifelse count households with [hh-type = 2] > 0  [set h2-pa mean [hh-process-ability] of households with [hh-type = 2]] [set h2-pa 0]
  ifelse count households with [hh-type = 3] > 0 [set h3-pa mean [hh-process-ability] of households with [hh-type = 3]] [set h3-pa 0]

  ; STABILITY
  ifelse count households with [hh-type = 1] > 0 [set h1-stability mean [hh-prod-stability] of households with [hh-type = 1]] [set h1-stability 0]
  ifelse count households with [hh-type = 2] > 0 [set h2-stability mean [hh-prod-stability] of households with [hh-type = 2]] [set h2-stability 0]
  ifelse count households with [hh-type = 3] > 0 [set h3-stability mean [hh-prod-stability] of households with [hh-type = 3]] [set h3-stability 0]

  ;FOOD SECURITY
  ifelse count households with [hh-type = 1] > 0 [set h1-av mean [availability-status] of households with [hh-type = 1]] [set h1-av 0]
  ifelse count households with [hh-type = 2] > 0 [set h2-av mean [availability-status] of households with [hh-type = 2]] [set h2-av 0]
  ifelse count households with [hh-type = 3] > 0 [set h3-av mean [availability-status] of households with [hh-type = 3]] [set h3-av 0]

  ifelse count households with [hh-type = 1] > 0 [set h1-ac mean [access-status] of households with [hh-type = 1]] [set h1-ac 0]
  ifelse count households with [hh-type = 2] > 0 [set h2-ac mean [access-status] of households with [hh-type = 2]] [set h2-ac 0]
  ifelse count households with [hh-type = 3] > 0 [set h3-ac mean [access-status] of households with [hh-type = 3]] [set h3-ac 0]

  ifelse count households with [hh-type = 1] > 0 [set h1-u mean [utilisation-status] of households with [hh-type = 1]] [set h1-u 0]
  ifelse count households with [hh-type = 2] > 0 [set h2-u mean [utilisation-status] of households with [hh-type = 2]] [set h2-u 0]
  ifelse count households with [hh-type = 3] > 0 [set h3-u mean [utilisation-status] of households with [hh-type = 3]] [set h3-u 0]

  ifelse count households with [hh-type = 1] > 0 [set h1-s mean [food-stability] of households with [hh-type = 1]] [set h1-s 0]
  ifelse count households with [hh-type = 2] > 0 [set h2-s mean [food-stability] of households with [hh-type = 2]] [set h2-s 0]
  ifelse count households with [hh-type = 3] > 0 [set h3-s mean [food-stability] of households with [hh-type = 3]] [set h3-s 0]


  ; LANDUSE
  set h-land (count households with [hh-land-area > 0 ] / count households)
  ifelse count households with [hh-type = 1] > 0 [set h1-land (count households with [hh-type = 1 and hh-land-area > 0] / count households with [hh-type = 1])] [set h1-land 0]
  ifelse count households with [hh-type = 2] > 0 [set h2-land (count households with [hh-type = 2 and hh-land-area > 0] / count households with [hh-type = 2])] [set h2-land 0]
  ifelse count households with [hh-type = 3] > 0 [set h3-land (count households with [hh-type = 3 and hh-land-area > 0] / count households with [hh-type = 3])] [set h3-land 0]

  ask households
    [
      if hh-land-area > 0 [
        set lu-anro  allo-annual-roots / hh-land-area * 100
        set lu-grain allo-grains / hh-land-area * 100
        set lu-nut allo-nuts-pulses / hh-land-area * 100
        set lu-perm allo-perm-roots / hh-land-area * 100
        set lu-cash allo-cash-crops / hh-land-area * 100
        set lu-veg allo-vegetables / hh-land-area * 100
        set lu-fruit allo-fruits / hh-land-area * 100
        set lu-fal allo-fallow / hh-land-area * 100
      ]
    ]

  ifelse count households with [hh-land-area > 0] > 0 [set vil-anro mean [lu-anro] of households with [hh-land-area > 0]] [set vil-anro 0]
  ifelse count households with [hh-land-area > 0] > 0 [set vil-grain mean [lu-grain] of households with [hh-land-area > 0]] [set vil-grain 0]
  ifelse count households with [hh-land-area > 0] > 0 [set vil-nut mean [lu-nut] of households with [hh-land-area > 0]] [set vil-nut 0]
  ifelse count households with [hh-land-area > 0] > 0 [set vil-perm mean [lu-perm] of households with [hh-land-area > 0]] [set vil-perm 0]
  ifelse count households with [hh-land-area > 0] > 0 [set vil-cash mean [lu-cash] of households with [hh-land-area > 0]] [set vil-cash 0]
  ifelse count households with [hh-land-area > 0] > 0 [set vil-veg mean [lu-veg] of households with [hh-land-area > 0]] [set vil-veg 0]
  ifelse count households with [hh-land-area > 0] > 0 [set vil-fruit mean [lu-fruit] of households with [hh-land-area > 0]] [set vil-fruit 0]
  ifelse count households with [hh-land-area > 0] > 0 [set vil-fal mean [lu-fal] of households with [hh-land-area > 0]] [set vil-fal 0]


  ifelse count households with [hh-type = 1 and hh-land-area > 0] > 0 [set vil-anro-1 mean [lu-anro] of households with [hh-land-area > 0 and hh-type = 1]] [set vil-anro-1 0]
  ifelse count households with [hh-type = 2 and hh-land-area > 0] > 0 [set vil-anro-2 mean [lu-anro] of households with [hh-land-area > 0 and hh-type = 2]] [set vil-anro-2 0]
  ifelse count households with [hh-type = 3 and hh-land-area > 0] > 0 [set vil-anro-3 mean [lu-anro] of households with [hh-land-area > 0 and hh-type = 3]] [set vil-anro-3 0]
  ifelse count households with [hh-type = 1 and hh-land-area > 0] > 0 [set vil-grain-1 mean [lu-grain] of households with [hh-land-area > 0 and hh-type = 1]] [set vil-grain-1 0]
  ifelse count households with [hh-type = 2 and hh-land-area > 0] > 0 [set vil-grain-2 mean [lu-grain] of households with [hh-land-area > 0 and hh-type = 2]] [set vil-grain-2 0]
  ifelse count households with [hh-type = 3 and hh-land-area > 0] > 0 [set vil-grain-3 mean [lu-grain] of households with [hh-land-area > 0 and hh-type = 3]] [set vil-grain-3 0]
  ifelse count households with [hh-type = 1 and hh-land-area > 0] > 0 [set vil-nut-1 mean [lu-nut] of households with [hh-land-area > 0 and hh-type = 1]] [set vil-nut-1 0]
  ifelse count households with [hh-type = 2 and hh-land-area > 0] > 0 [set vil-nut-2 mean [lu-nut] of households with [hh-land-area > 0 and hh-type = 2]] [set vil-nut-2 0]
  ifelse count households with [hh-type = 3 and hh-land-area > 0] > 0 [set vil-nut-3 mean [lu-nut] of households with [hh-land-area > 0 and hh-type = 3]] [set vil-nut-3 0]
  ifelse count households with [hh-type = 1 and hh-land-area > 0] > 0 [set vil-perm-1 mean [lu-perm ] of households with [hh-land-area > 0 and hh-type = 1]] [set vil-perm-1 0]
  ifelse count households with [hh-type = 2 and hh-land-area > 0] > 0 [set vil-perm-2 mean [lu-perm ] of households with [hh-land-area > 0 and hh-type = 2]] [set vil-perm-2 0]
  ifelse count households with [hh-type = 3 and hh-land-area > 0] > 0 [set vil-perm-3 mean [lu-perm ] of households with [hh-land-area > 0 and hh-type = 3]] [set vil-perm-3 0]
  ifelse count households with [hh-type = 1 and hh-land-area > 0] > 0 [set vil-cash-1 mean [lu-cash] of households with [hh-land-area > 0 and hh-type = 1]] [set vil-cash-1 0]
  ifelse count households with [hh-type = 2 and hh-land-area > 0] > 0 [set vil-cash-2 mean [lu-cash ] of households with [hh-land-area > 0 and hh-type = 2]] [set vil-cash-2 0]
  ifelse count households with [hh-type = 3 and hh-land-area > 0] > 0 [set vil-cash-3 mean [lu-cash ] of households with [hh-land-area > 0 and hh-type = 3]] [set vil-cash-3 0]
  ifelse count households with [hh-type = 1 and hh-land-area > 0] > 0 [set vil-veg-1 mean [lu-veg] of households with [hh-land-area > 0 and hh-type = 1]] [set vil-veg-1 0]
  ifelse count households with [hh-type = 2 and hh-land-area > 0] > 0 [set vil-veg-2 mean [lu-veg] of households with [hh-land-area > 0 and hh-type = 2]] [set vil-veg-2 0]
  ifelse count households with [hh-type = 3 and hh-land-area > 0] > 0 [set vil-veg-3 mean [lu-veg ] of households with [hh-land-area > 0 and hh-type = 3]] [set vil-veg-3 0]
  ifelse count households with [hh-type = 1 and hh-land-area > 0] > 0 [set vil-fruit-1 mean [lu-fruit] of households with [hh-land-area > 0 and hh-type = 1]] [set vil-fruit-1 0]
  ifelse count households with [hh-type = 2 and hh-land-area > 0] > 0 [set vil-fruit-2 mean [lu-fruit] of households with [hh-land-area > 0 and hh-type = 2]] [set vil-fruit-2 0]
  ifelse count households with [hh-type = 3 and hh-land-area > 0] > 0 [set vil-fruit-3 mean [lu-fruit ] of households with [hh-land-area > 0 and hh-type = 3]] [set vil-fruit-3 0]
  ifelse count households with [hh-type = 1 and hh-land-area > 0] > 0 [set vil-fal-1 mean [lu-fal] of households with [hh-land-area > 0 and hh-type = 1]] [set vil-fal-1 0]
  ifelse count households with [hh-type = 2 and hh-land-area > 0] > 0 [set vil-fal-2 mean [lu-fal] of households with [hh-land-area > 0 and hh-type = 2]] [set vil-fal-2 0]
  ifelse count households with [hh-type = 3 and hh-land-area > 0] > 0 [set vil-fal-3 mean [lu-fal] of households with [hh-land-area > 0 and hh-type = 3]] [set vil-fal-3 0]


  ; YIELD
  ask households
  [
    set tot-anroots (tot-anroots + out-anroots)
    set tot-grains (tot-grains + out-grains)
    set tot-pulses (tot-pulses + out-pulses)
    set tot-peroots  (tot-peroots + out-peroots)
    set tot-fruit  (tot-fruit + out-fruit)
    set tot-cash (tot-cash + out-cash)
    set tot-veg (tot-veg + out-veg)
    set tot-output tot-anroots + tot-grains + tot-pulses + tot-peroots + tot-fruit + tot-cash + tot-veg
       ]
 ifelse count households with [ hh-land-area > 0] > 0 [set v-tot-anro mean [tot-anroots] of households with [hh-land-area > 0]] [set v-tot-anro 0]
 ifelse count households with [ hh-land-area > 0] > 0 [set v-tot-grains mean [tot-grains] of households with [hh-land-area > 0]] [set v-tot-grains 0]
 ifelse count households with [ hh-land-area > 0] > 0 [set v-tot-pulses mean [tot-pulses] of households with [hh-land-area > 0]] [set v-tot-pulses 0]
 ifelse count households with [ hh-land-area > 0] > 0 [set v-tot-peroots mean [tot-peroots] of households with [hh-land-area > 0]] [set v-tot-peroots 0]
 ifelse count households with [ hh-land-area > 0] > 0 [set v-tot-cash mean [tot-cash] of households with [hh-land-area > 0]] [set v-tot-cash 0]
 ifelse count households with [ hh-land-area > 0] > 0 [set v-tot-veg mean [tot-veg] of households with [hh-land-area > 0]] [set v-tot-veg 0]
 ifelse count households with [ hh-land-area > 0] > 0 [set v-tot-fruit mean [tot-fruit] of households with [hh-land-area > 0]] [set v-tot-fruit 0]

 ifelse count households with [hh-type = 1 and hh-land-area > 0] > 0 [set tot-anro-1 mean [tot-anroots] of households with [hh-type = 1 and hh-land-area > 0]] [set tot-anro-1 0]
 ifelse count households with [hh-type = 2 and hh-land-area > 0] > 0 [set tot-anro-2 mean [tot-anroots] of households with [hh-type = 2 and hh-land-area > 0]] [set tot-anro-2 0]
 ifelse count households with [hh-type = 3 and hh-land-area > 0] > 0 [set tot-anro-3 mean [tot-anroots] of households with [hh-type = 3 and hh-land-area > 0]] [set tot-anro-3 0]
 ifelse count households with [hh-type = 1 and hh-land-area > 0] > 0 [set tot-grain-1 mean [tot-grains] of households with [hh-type = 1 and hh-land-area > 0]] [set tot-grain-1 0]
 ifelse count households with [hh-type = 2 and hh-land-area > 0] > 0 [set tot-grain-2 mean [tot-grains] of households with [hh-type = 2 and hh-land-area > 0]] [set tot-grain-2 0]
 ifelse count households with [hh-type = 3 and hh-land-area > 0] > 0 [set tot-grain-3 mean [tot-grains] of households with [hh-type = 3 and hh-land-area > 0]] [set tot-grain-3 0]
 ifelse count households with [hh-type = 1 and hh-land-area > 0] > 0 [set tot-pulses-1 mean [tot-pulses] of households with [hh-type = 1 and hh-land-area > 0]] [set tot-pulses-1 0]
 ifelse count households with [hh-type = 2 and hh-land-area > 0] > 0 [set tot-pulses-2 mean [tot-pulses] of households with [hh-type = 2 and hh-land-area > 0]] [set tot-pulses-2 0]
 ifelse count households with [hh-type = 3 and hh-land-area > 0] > 0 [set tot-pulses-3 mean [tot-pulses] of households with [hh-type = 3 and hh-land-area > 0]] [set tot-pulses-3 0]
 ifelse count households with [hh-type = 1 and hh-land-area > 0] > 0 [set tot-peroots-1 mean [tot-peroots] of households with [hh-type = 1 and hh-land-area > 0]] [set tot-peroots-1 0]
 ifelse count households with [hh-type = 2 and hh-land-area > 0] > 0 [set tot-peroots-2 mean [tot-peroots] of households with [hh-type = 2 and hh-land-area > 0]] [set tot-peroots-2 0]
 ifelse count households with [hh-type = 3 and hh-land-area > 0] > 0 [set tot-peroots-3 mean [tot-peroots] of households with [hh-type = 3 and hh-land-area > 0]] [set tot-peroots-3 0]
 ifelse count households with [hh-type = 1 and hh-land-area > 0] > 0 [set tot-cash-1 mean [tot-cash] of households with [hh-type = 1 and hh-land-area > 0]] [set tot-cash-1 0]
 ifelse count households with [hh-type = 2 and hh-land-area > 0] > 0 [set tot-cash-2  mean [tot-cash] of households with [hh-type = 2 and hh-land-area > 0]] [set tot-cash-2 0]
 ifelse count households with [hh-type = 3 and hh-land-area > 0] > 0 [set tot-cash-3 mean [tot-cash] of households with [hh-type = 3 and hh-land-area > 0]] [set tot-cash-3 0]
 ifelse count households with [hh-type = 1 and hh-land-area > 0] > 0 [set tot-veg-1 mean [tot-veg] of households with [hh-type = 1 and hh-land-area > 0]] [set tot-veg-1 0]
 ifelse count households with [hh-type = 2 and hh-land-area > 0] > 0 [set tot-veg-2 mean [tot-veg] of households with [hh-type = 2 and hh-land-area > 0]] [set tot-veg-2 0]
 ifelse count households with [hh-type = 3 and hh-land-area > 0] > 0 [set tot-veg-3 mean [tot-veg] of households with [hh-type = 3 and hh-land-area > 0]] [set tot-veg-3 0]
 ifelse count households with [hh-type = 1 and hh-land-area > 0] > 0 [set tot-fruit-1 mean [tot-fruit] of households with [hh-type = 1 and hh-land-area > 0]] [set tot-fruit-1 0]
 ifelse count households with [hh-type = 2 and hh-land-area > 0] > 0 [set tot-fruit-2 mean [tot-fruit] of households with [hh-type = 2 and hh-land-area > 0]] [set tot-fruit-2 0]
 ifelse count households with [hh-type = 3 and hh-land-area > 0] > 0 [set tot-fruit-3 mean [tot-fruit] of households with [hh-type = 3 and hh-land-area > 0]] [set tot-fruit-3 0]
 end

to update-population
  if season-end = TRUE [
    grow-population
    update-social-net
    assign-patches
    update-agents
  ]
  end

to grow-population
  let future-pop round (item (year - 2) growth-rate)
  if population-scenario = "Growth"
  [
    set add-hh round (future-pop - count households)
    ask n-of 1 households [hatch-households add-hh [set sim-age 0] ]
    file-open "new-households.txt"
    foreach sort households with [sim-age = 0] [ask ?
      [
        set new-ind file-read
        set hh-id file-read
        set hh-type file-read
        set hh-capital file-read
        set chickens-owned file-read
        set goats-owned file-read
        set cattle-owned file-read
      ]
    ]
    let tot-ind sum [new-ind] of households with [sim-age = 0]
    ask n-of 1 individuals [ hatch-individuals tot-ind [set sim-age 0]]
    file-open "new-individuals.txt"
    foreach sort individuals with [sim-age = 0] [ask ?
      [
        set family-id file-read
        set status file-read
        set gender file-read
        set age file-read
        set edu-level file-read
        set illness file-read
      ]
    ]
    foreach sort households with [sim-age = 0] [ask ?
      [
        set hh-member individuals with [family-id = [hh-id] of myself]
        set hh-head individuals with [family-id = [hh-id] of myself and status = 1]
        set hh-size count hh-member
        let edu [edu-level] of hh-head
        set hh-edu-level item 0 edu
        let gend [gender] of hh-head
        set hh-gender item 0 gend
        set past-resource-ex normal (0.12 * hh-size) 0.02
      ]
    ]
  ]
  end

to update-social-net
  ; each new household needs to be incorporated into thesocial network
  ; for now just clear all existing links and build from scratch
  ; eventually will keep existing links, but add additional ones to connect
  ; new households
  if population-scenario = "Growth" and count households with [sim-age = 0] > 0
  [
    let new-hh households with [sim-age = 0]
    let new-indiv individuals with [sim-age = 0]
    ask new-hh [
      assign-family
      set hidden? true
      layout-circle (sort-by [[family] of ?1 < [family] of ?2] households) max-pxcor - 1
      facexy 0 0
      set size 0.5
      if who mod 2 = 0 [fd 4]
    ]

    let n (min [who] of households with [sim-age = 0])
    while [n < (max [who] of households with [sim-age = 0] + 1)]
   [
    ;; make link with one of the same family
    ;; this makes a lattice with average degree of ??
   ;repeat num-close-hh
   repeat count households / num-families
   [let b one-of households with [family = [family] of household n]
   if b != household n
   [make-link-between household n
              b ]]

   ;;this adds one link to a a friend hh that is not of the big family (similar to rewiring)
   ;let c one-of households with [family != [family] of turtle n]
   ;make-link-between turtle n
   ;           c
   ;; separate the clusters
    layout-spring households links 0.2 4 0.9
    display
    set n n + 1
   ]
   compute-metrics
   ; rewire-links
   define-social-net
  ]
   end

to assign-patches
  if population-scenario = "Growth"
  [
    ; the new household selects a member of their social network to share land
    ; this will go ahead if the selected household owns land above a certain threshold
    ask households with [sim-age = 0] [
      let a-hh self
      let neighbour one-of social-net ; identify linked house at random
      let neighbour-patches patches with [owner-id = [hh-id] of neighbour]
      ; identify patches left to fallow
      let fallow-patches neighbour-patches with [land-fallow = TRUE]
      ifelse count fallow-patches > 0
      [
        ; give the smallest fallow patch to the new household
        ask min-one-of fallow-patches [patch-area] [
          set owner-id [hh-id] of a-hh
        ]
      ]
      [
        ; consider splitting a patch if the area of land owned is
        ; greater than a certain threshold
        if count neighbour-patches > 1 [
          ask min-one-of neighbour-patches [patch-area] [
            set owner-id [hh-id] of a-hh
          ]
        ]
        if count neighbour-patches = 1 [
          let new-patch one-of neighbour-patches
          ask new-patch [
            if patch-area > mean [patch-area] of patches
            [
              split-patch new-patch a-hh
            ]
          ]
        ]
      ]
    ]
    ask households [
      set my-farm patches with [owner-id  = [hh-id] of myself]
      set hh-land-area sum [patch-area] of my-farm
      ; update household area of land given to fallow?
    ]
  ]
end

to split-patch [a-patch a-hh]
 ask a-patch [ set patch-area 0.5 * patch-area ]
 ask one-of patches with [patch-type = 5] [
   set patch-area [patch-area] of a-patch
   set patch-type [patch-type] of a-patch
   set owner-id [hh-id] of a-hh
 ]
end

to update-agents
  ask households [set sim-age sim-age + 1]
  ask individuals [set sim-age sim-age + 1]
end

to update-hh-type
  ask households
  [
    ;set av-prod av-prod +
    if season-end = TRUE [
      set past-type hh-type
      set hanging-in 0
      set stepping-up 0
      set stepping-out 0
      set falling-down 0
        let total-hrs farm-work + agri-work + n-agri-work
        if total-hrs > 0 [
          let prop-farm farm-work / total-hrs
          let prop-agri agri-work / total-hrs
          let prop-nag n-agri-work / total-hrs
          ifelse  prop-farm >= 0.64
          [set hh-type 1]
          [
            ifelse prop-agri >= 0.28
            [set hh-type 2]
            [
               ifelse n-agri-work < 0.4
               [set hh-type 1]
               [set hh-type 3]
            ]
          ]
        ]
        if hh-type = past-type
        [
          ifelse hh-capital > past-capital and tot-output > past-output
          [
            set stepping-up 1
            set hanging-in 0
          ]
          [
            set stepping-up 0
            set hanging-in 1
          ]
        ]
        if past-type = 2 [
          ifelse hh-type = 3 or hh-type = 1 [ set stepping-out 1] [set stepping-out 0]
          ]
        if past-type = 1 [
          ifelse hh-type = 3 [set stepping-out 1] [set stepping-out 0]
          ifelse hh-type = 2 [set falling-down 1] [set falling-down 0]
        ]
        if past-type = 3 [
          ifelse hh-type = 1 or hh-type = 2 [set falling-down 1] [set falling-down 0]
          ]
        set farm-work 0
        set agri-work 0
        set n-agri-work 0
        ]
    set past-capital hh-capital
    set past-output tot-output
    set tot-output 0
    ]
end

to set-trajectory
  ;TYPE
  set prop-hanging-in  sum [hanging-in] of households / count households * 100
  set prop-stepping-up sum [stepping-up] of households / count households * 100
  set prop-stepping-out sum [stepping-out] of households / count households * 100
  set prop-falling-down sum [falling-down] of households / count households * 100


  ifelse count households with [past-type = 1] > 0 [set prop-hanging-in-1  sum [hanging-in] of households with [past-type = 1] / count households with [past-type = 1] * 100] [set prop-hanging-in-1 0]
  ifelse count households with [past-type = 2] > 0 [set prop-hanging-in-2  sum [hanging-in] of households with [past-type = 2] / count households with [past-type = 2] * 100] [set prop-hanging-in-2 0]
  ifelse count households with [past-type = 3] > 0 [set prop-hanging-in-3  sum [hanging-in] of households with [past-type = 3] / count households with [past-type = 3]  * 100] [set prop-hanging-in-3 0]

  ifelse count households with [past-type = 1] > 0 [set prop-stepping-up-1 sum [stepping-up] of households with [past-type = 1] / count households with [past-type = 1] * 100] [set prop-stepping-up-1 0]
  ifelse count households with [past-type = 2] > 0 [set prop-stepping-up-2 sum [stepping-up] of households with [past-type = 2] / count households with [past-type = 2] * 100] [set prop-stepping-up-2 0]
  ifelse count households with [past-type = 3] > 0 [set prop-stepping-up-3 sum [stepping-up] of households with [past-type = 3] / count households with [past-type = 3] * 100] [set prop-stepping-up-3 0]

  ifelse count households with [past-type = 1] > 0 [ set prop-stepping-out-1 sum [stepping-out] of households with [past-type = 1]/ count households with [past-type = 1] * 100] [set prop-stepping-out-1 0]
  ifelse count households with [past-type = 2] > 0 [ set prop-stepping-out-2 sum [stepping-out] of households with [past-type = 2]/ count households with [past-type = 2] * 100] [set prop-stepping-out-2 0]
  ifelse count households with [past-type = 3] > 0 [ set prop-stepping-out-3 sum [stepping-out] of households with [past-type = 3]/ count households with [past-type = 3] * 100] [set prop-stepping-out-3 0]

  ifelse count households with [past-type = 1] > 0 [ set prop-falling-down-1 sum [falling-down] of households with [past-type = 1] / count households with [past-type = 1] * 100] [set prop-falling-down-1 0]
  ifelse count households with [past-type = 2] > 0 [ set prop-falling-down-2 sum [falling-down] of households with [past-type = 2] / count households with [past-type = 2] * 100] [set prop-falling-down-2 0]
  ifelse count households with [past-type = 3] > 0 [ set prop-falling-down-3 sum [falling-down] of households with [past-type = 3] / count households with [past-type = 3] * 100] [set prop-falling-down-3 0]
end

to update-hh
  ask households
  [
    ; update physical capital
    set t-labour 0
    set labour-pool 0

    ; reset firewood collection
    set past-resource-ex resource-extract
    set res-list []
    set norm-list []

    ; reset capability to be food secure
    set food-availability 0
    set food-access 0
    set food-utilisation 0
    set diet-diversity 0

    set availability-status 0
    set access-status 0
    set utilisation-status 0
    set food-stability 0

    ; reset labour allocation
    set fw-labour 0
    set w-labour 0
    set fh-labour 0
    set fo-labour 0
    set na-labour 0
    set farming-lab 0

    ; reset inputs
    set hh-inputs 0
    set coupon-n 0

    ; FARMING
    ; reset land and labour requirements
    set month-lab 0
    set hh-sub-req FALSE
    set hh-cash-labour FALSE
    set hh-cash-land FALSE
    set get-labour FALSE

    set labour-grains 0
    set labour-nuts-pulses 0
    set labour-annual-roots 0
    set labour-perm-roots 0
    set labour-vegetables 0
    set labour-fruits 0
    set labour-cash-crops 0


    ; update farming history
    if allo-grains > 0 [set past-grains (past-grains + 1)]
    if allo-nuts-pulses > 0 [ set past-nuts-pulses (past-nuts-pulses + 1)]
    if allo-annual-roots > 0 [set past-annual-roots (past-annual-roots + 1)]
    if allo-perm-roots > 0 [set past-perm-roots (past-perm-roots + 1)]
    if allo-vegetables > 0 [set past-vegetables (past-vegetables + 1)]
    if allo-fruits > 0 [set past-fruits (past-fruits + 1)]
    if allo-cash-crops > 0 [set past-cash-crops (past-cash-crops + 1)]

    ; clear calorie variables
    set spend-cal-pool 0
    set actual-cal-pool 0

    ; clear land and labour allocations at the end of the growing season
    if season-end = TRUE
    [
      set allo-grains 0
      set allo-nuts-pulses 0
      set allo-annual-roots 0
      set allo-perm-roots 0
      set allo-vegetables 0
      set allo-fruits 0
      set allo-cash-crops 0
      set allo-fallow 0

      set lg 0
      set lnp 0
      set lf 0
      set lpr 0

      set tot-anroots 0
      set tot-grains 0
      set tot-pulses 0
      set tot-peroots 0
      set tot-fruit 0
      set tot-cash 0
      set tot-veg 0

      set lu-anro 0
      set lu-grain 0
      set lu-nut 0
      set lu-perm 0
      set lu-cash 0
      set lu-veg 0
      set lu-fruit 0
      set lu-fal 0
    ]

    ; reset food processing parameters
    set out-anroots 0
    set out-grains 0
    set out-pulses 0
    set out-peroots 0
    set out-veg 0
    set out-fruit 0
    set out-cash 0
    set eat-anroots 0
    set sell-anroots 0
    set lost-anroots 0
    set eat-grains 0
    set sell-grains 0
    set lost-grains 0
    set eat-pulses 0
    set sell-pulses 0
    set lost-pulses 0
    set eat-peroots 0
    set sell-peroots 0
    set lost-peroots 0
    set eat-veg 0
    set sell-veg 0
    set lost-veg 0
    set eat-fruit 0
    set sell-fruit 0
    set lost-fruit 0
    set sell-cash-crops 0
    set meat-output 0
    set egg-output 0
    set milk-output 0
    set manure-output 0
    set eat-meat 0
    set sell-egg 0
    set lost-egg 0
    set eat-milk 0
    set sell-milk 0
    set lost-milk 0
    set eat-forage-veg 0
    set eat-forage-fruit 0

    ; reset livelihood outputs
    set off-nonag-output 0

    ; reset spending
    set m-nonf-expense 0
    set spending-cap 0
    set spending-cal 0

    ; reset food availability
    set calorie-pool 0
    set calorie-deficit 0
    set bought-calories 0

    ; reset adaptive strategies
    set pwp-calories 0
    set borrow-food 0
    set sale-livestock 0

    ; reset food security status
    set daily-fecpc 0
    set hh-prop-staples 0
  ]
end

; UPDATE PATCH
to update-patch
  ask patches
  [
    set p-yield 0
    set patch-output 0
    set inorg 0
    set lab 0
    set org 0
    if  fruit-stand = "TRUE" and fruit-stand-age >= max-tree-age
    [
      set fruit-stand "FALSE"
      set fruit-stand-age 0
    ]
  ]

end

to-report pick-random
  let random-number random 1001
  while [member? random-number rand-list = true]
  [set random-number random 1001]
  set rand-list lput random-number rand-list
  report random-number
end

to-report normal[a b]
  ; reports normal distribution
  let rn random-normal a b
  while [rn < 0]
  [set rn random-normal a b]
  report rn
end


; DIFFERENT ALTERNATIVES TO THE VIEW
to view-landuse
  ask links [hide-link]
  ask households [set hidden? true]
  ask patches with [patch-type = 1] [set pcolor 67]
  ask patches with [patch-type = 2] [set pcolor 33]
  ask patches with [patch-type = 3] [set pcolor 117]
  ask patches with [patch-type = 4] [set pcolor 95]
  ask patches with [patch-type = 5] [set pcolor 9]
end

to view-socialnet
  ask links [set hidden? false]
  ask households [set hidden? false]
  ask patches [set pcolor black]
end
@#$#@#$#@
GRAPHICS-WINDOW
19
17
354
399
12
13
13.0
1
10
1
1
1
0
1
1
1
-12
12
-13
13
0
0
1
ticks
30.0

BUTTON
370
16
444
49
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
372
169
443
247
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
592
246
685
291
Clustering Coeff.
clustering-coefficient
2
1
11

MONITOR
469
190
559
235
Av. Path Length
average-path-length
2
1
11

MONITOR
467
246
558
291
Av. Degree
average-degree
2
1
11

TEXTBOX
469
164
619
182
Social Network:
14
0.0
1

MONITOR
466
43
554
88
No. Households
count households
0
1
11

MONITOR
592
188
684
233
No. Families
num-families
0
1
11

TEXTBOX
470
305
620
323
Landcover:
14
0.0
1

BUTTON
372
130
445
163
one step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
468
102
554
147
Farmers
count households with [hh-type = 1]
1
1
11

MONITOR
591
41
678
86
Agri-labourers
count households with [hh-type = 2]
2
1
11

MONITOR
590
101
678
146
Non-ag workers
count households with [hh-type = 3]
2
1
11

MONITOR
577
329
684
374
Forest area (ha)
(sum [patch-area] of patches with [patch-type = 1])
1
1
11

MONITOR
466
331
571
376
Farm plot area (ha)
(sum [patch-area] of patches with [patch-type = 2])
1
1
11

MONITOR
465
386
685
431
Dimba area (ha)
(sum [patch-area] of patches with [patch-type = 3])
1
1
11

MONITOR
378
332
445
377
NIL
Month
17
1
11

MONITOR
377
385
446
430
Season
agri-type
17
1
11

MONITOR
20
537
94
582
Grains
sum [allo-grains] of households
1
1
11

MONITOR
104
481
177
526
Nuts-pulses
sum [allo-nuts-pulses] of households
1
1
11

MONITOR
188
481
261
526
Annual roots
sum [allo-annual-roots] of households
1
1
11

MONITOR
270
482
343
527
Perm roots
sum [allo-perm-roots] of households
1
1
11

MONITOR
272
537
343
582
Fallow
sum [allo-fallow] of households
1
1
11

MONITOR
18
482
93
527
Cash-crops
sum [allo-cash-crops] of households
1
1
11

MONITOR
106
536
180
581
Fruit trees
sum [allo-fruits] of households
1
1
11

MONITOR
189
536
262
581
Vegetables
sum [allo-vegetables] of households
1
1
11

TEXTBOX
378
255
445
273
Season:
14
0.0
1

TEXTBOX
467
18
617
36
Households:
14
0.0
1

TEXTBOX
20
431
347
472
Total area of land allocated to different crop types (ha):
14
0.0
1

MONITOR
21
657
348
702
Average yield of farm plots (Kg/ha)
av-yield
2
1
11

MONITOR
21
601
348
646
Average yield of dimba plots (Kg/ha)
av-yield-dimba
2
1
11

MONITOR
378
280
445
325
Year
Year + 2009
0
1
11

PLOT
711
56
1657
210
Average availability of calories
Month
Calories
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"farmer " 1.0 0 -16777216 true "" "plot h1-avail"
"agri-labourer" 1.0 0 -7500403 true "" "plot h2-avail"
"non-ag-worker" 1.0 0 -2674135 true "" "plot h3-avail"

TEXTBOX
712
32
862
55
Availability:
14
0.0
1

TEXTBOX
713
218
863
236
Access:
14
0.0
1

PLOT
708
241
1024
391
Average amount of accessible calories
Month
Calories
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"farmer" 1.0 0 -16777216 true "" "plot h1-access"
"agri-labourer" 1.0 0 -7500403 true "" "plot h2-access"
"non-ag-worker" 1.0 0 -2674135 true "" "plot h3-access"

PLOT
1031
240
1344
390
Average daily food energy consumption per capita
Month
FECC
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"farmer" 1.0 0 -16777216 true "" "plot h1-fecc"
"ag-labourer" 1.0 0 -7500403 true "" "plot h2-fecc"
"non-ag-worker" 1.0 0 -2674135 true "" "plot h3-fecc"

PLOT
1351
241
1659
391
Prop.  households food energy deficient
Month
Percentage
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"farmer" 1.0 0 -16777216 true "" "plot prop-h1-defic"
"ag-labourer" 1.0 0 -7500403 true "" "plot prop-h2-defic"
"non-ag-worker" 1.0 0 -2674135 true "" "plot prop-h3-defic"

TEXTBOX
714
408
864
426
Utilisation:
14
0.0
1

PLOT
716
435
1027
585
Average diet diversity
Month
Diversity Score
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"farmer" 1.0 0 -16777216 true "" "plot h1-diversity"
"ag-labourer" 1.0 0 -7500403 true "" "plot h2-diversity"
"non-ag-worker " 1.0 0 -2674135 true "" "plot h3-diversity"

PLOT
1034
435
1345
585
Average percentage of food energy from staples
Month
Percentage
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"farmer" 1.0 0 -16777216 true "" "plot h1-propstaples"
"ag-labourer" 1.0 0 -7500403 true "" "plot h2-propstaples"
"nonag-worker" 1.0 0 -2674135 true "" "plot h3-propstaples"

PLOT
1350
435
1661
585
Average process-ability
Month
Percentage
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"farmer" 1.0 0 -16777216 true "" "plot h1-pa"
"agri-labourer" 1.0 0 -7500403 true "" "plot h2-pa"
"non-agri-worker" 1.0 0 -2674135 true "" "plot h3-pa"

TEXTBOX
719
600
869
618
Stability:
14
0.0
1

PLOT
720
623
1666
773
Crop Production Stability
Month
Covariance Value
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"farmer " 1.0 0 -16777216 true "" "plot h1-stability"
"ag-labourer" 1.0 0 -7500403 true "" "plot h2-stability"
"non-ag-worker" 1.0 0 -2674135 true "" "plot h3-stability"

TEXTBOX
712
10
971
44
Food Security Outcomes:
14
0.0
1

BUTTON
371
55
444
88
NIL
view-landuse
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
372
92
445
125
NIL
view-socialnet
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
381
443
531
461
Markets:
14
0.0
1

SLIDER
380
470
687
503
m-efficiency
m-efficiency
0
1
0.8
0.1
1
NIL
HORIZONTAL

TEXTBOX
385
572
535
590
Scenarios:
14
0.0
1

CHOOSER
382
593
688
638
population-scenario
population-scenario
"Fixed" "Growth"
1

CHOOSER
384
655
690
700
climate-scenario
climate-scenario
"Fixed" "rcp_2.6"
1

PLOT
18
712
351
862
Average yield of land
Month
Kg/ha
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"dimba-plot" 1.0 0 -16777216 true "" "plot av-yield-dimba"
"farm-plot" 1.0 0 -955883 true "" "plot av-yield"

SLIDER
381
527
684
560
nag-avail
nag-avail
0
1
0.8
0.1
1
NIL
HORIZONTAL

MONITOR
384
745
525
790
hanging-in
prop-hanging-in
1
1
11

MONITOR
385
795
524
840
stepping-out
prop-stepping-out
1
1
11

MONITOR
548
795
691
840
falling-down
prop-falling-down
1
1
11

TEXTBOX
384
724
612
758
Household Trajectory:
14
0.0
1

SLIDER
19
891
121
924
n-f-interact
n-f-interact
1
20
2
1
1
NIL
HORIZONTAL

SLIDER
134
891
239
924
n-l-interact
n-l-interact
1
20
4
1
1
NIL
HORIZONTAL

SLIDER
384
883
692
916
random-seed-no
random-seed-no
0
100
398
1
1
NIL
HORIZONTAL

SLIDER
250
890
351
923
multiplier
multiplier
1
2
1.6
0.2
1
NIL
HORIZONTAL

TEXTBOX
21
870
171
888
Limits:
14
0.0
1

MONITOR
548
743
690
788
stepping-up
prop-stepping-up
1
1
11

TEXTBOX
384
861
534
879
Random Seed Value:
14
0.0
1

@#$#@#$#@
## WHAT IS IT?

A model exploring food security of rural households in Southern Malawi.

The purpose of this agent-based model is to simulate households behaviour at the village level and observe the emerging properties of the system in terms of food security. Households are the main entity and are distinguished into three types: i) on-farm workers, ii) off-farm agricultural workers and iii) off-farm non-agricultural workers.  The main attributes of households include human, physical, natural and financial capital. Households are connected through a social network, which is modeled as a small world. Individuals belong to households and are defined by their gender, education, age and body-weight. Four different environments are considered, including forest, farm plots, dimba plots and rivers. Key attributes the different environments include: area, slope, upslope area (As) and ownership. Households can own both dimba and farm plots, while forests and rivers remain communal. The ABM is a-spatial.

## HOW IT WORKS

The model works in monthly time steps.  It begins by defining the month of the year and the corresponding agricultural and fishing seasons. Basic needs in the form of food, water and fuel are then calculated for each of the households. Household labour is allocated between productive activities, including firewood collection, water collection, on-farm agricultural activities, off-farm agricultural activities and off-farm non-agricultural work. At the beginning of the agricultural season, households decide how to allocate their farm plots with different crops. Eleven different combinations of basic grains, annual roots, permanent roots, nuts & pulses, fruits, vegetables and cash crops are possible. Decisions are constrained by land, labour, subsistence, input and knowledge requirements.  In the months that follow, households are able to adjust land allocation decisions based on labour availability. In addition to farming, households may also tend to livestock, forage for wild and indigenous foods, go fishing, hunt game and carry out off-farm activities such as casual labour (ganyu) and non-agricultural employment. Towards the end of the time step, the food security status of a household is evaluated. Spending capacity is calculated as the difference between income from productive activities and expected non-food expenses. If the availability of calories from self-production and market access is insufficient at this point, households undertake adaptive strategies. These include: participation in government led ‘food for work’ programs, as well as borrowing food and money from the social network.  Utilisation of available calories is dependent upon a household’s ability to process food and the underlying stability of food security is evaluated as a function of process ability and production stability. At the end of the time step a household’s food security status is labeled ‘good’, ‘moderate’ or ‘poor’ depending upon availability, access, utilisation and stability of food.

## HOW TO USE IT

Hit 'setup' and then 'go'.

## THINGS TO NOTICE

Emergent phenomena include the level of food security and the state of natural resource stocks.

## THINGS TO TRY

Add extra plots and monitors to the interface.

## EXTENDING THE MODEL

Add additional procedures e.g. fish-farming etc.

## CREDITS AND REFERENCES

Model created by Samantha Dobbie and Stefano Balbi, April 2015.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="landuse" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="12"/>
    <metric>vil-anro</metric>
    <metric>vil-grain</metric>
    <metric>vil-nut</metric>
    <metric>vil-perm</metric>
    <metric>vil-cash</metric>
    <metric>vil-fruit</metric>
    <metric>vil-veg</metric>
    <metric>vil-fal</metric>
    <metric>vil-anro-1</metric>
    <metric>vil-anro-2</metric>
    <metric>vil-anro-3</metric>
    <metric>vil-grain-1</metric>
    <metric>vil-grain-2</metric>
    <metric>vil-grain-3</metric>
    <metric>vil-nut-1</metric>
    <metric>vil-nut-2</metric>
    <metric>vil-nut-3</metric>
    <metric>vil-perm-1</metric>
    <metric>vil-perm-2</metric>
    <metric>vil-perm-3</metric>
    <metric>vil-cash-1</metric>
    <metric>vil-cash-2</metric>
    <metric>vil-cash-3</metric>
    <metric>vil-veg-1</metric>
    <metric>vil-veg-2</metric>
    <metric>vil-veg-3</metric>
    <metric>vil-fruit-1</metric>
    <metric>vil-fruit-2</metric>
    <metric>vil-fruit-3</metric>
    <metric>vil-fal-1</metric>
    <metric>vil-fal-2</metric>
    <metric>vil-fal-3</metric>
    <enumeratedValueSet variable="population-scenario">
      <value value="&quot;Growth&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="m-efficiency">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nag-avail">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-f-interact">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="climate-scenario">
      <value value="&quot;rcp_2.6&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-l-interact">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="multiplier">
      <value value="1.6"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed-no" first="1" step="1" last="200"/>
  </experiment>
  <experiment name="cropoutput" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="12"/>
    <metric>month</metric>
    <metric>h-land</metric>
    <metric>h1-land</metric>
    <metric>h2-land</metric>
    <metric>h3-land</metric>
    <metric>v-tot-anro</metric>
    <metric>v-tot-grains</metric>
    <metric>v-tot-pulses</metric>
    <metric>v-tot-peroots</metric>
    <metric>v-tot-cash</metric>
    <metric>v-tot-veg</metric>
    <metric>v-tot-fruit</metric>
    <metric>tot-anro-1</metric>
    <metric>tot-anro-2</metric>
    <metric>tot-anro-3</metric>
    <metric>tot-grain-1</metric>
    <metric>tot-grain-2</metric>
    <metric>tot-grain-3</metric>
    <metric>tot-pulses-1</metric>
    <metric>tot-pulses-2</metric>
    <metric>tot-pulses-3</metric>
    <metric>tot-peroots-1</metric>
    <metric>tot-peroots-2</metric>
    <metric>tot-peroots-3</metric>
    <metric>tot-cash-1</metric>
    <metric>tot-cash-2</metric>
    <metric>tot-cash-3</metric>
    <metric>tot-veg-1</metric>
    <metric>tot-veg-2</metric>
    <metric>tot-veg-3</metric>
    <metric>tot-fruit-1</metric>
    <metric>tot-fruit-2</metric>
    <metric>tot-fruit-3</metric>
    <enumeratedValueSet variable="population-scenario">
      <value value="&quot;Growth&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="m-efficiency">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nag-avail">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-f-interact">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="climate-scenario">
      <value value="&quot;rcp_2.6&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-l-interact">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="multiplier">
      <value value="1.6"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed-no" first="1" step="1" last="200"/>
  </experiment>
  <experiment name="foodstatus" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="12"/>
    <metric>month</metric>
    <metric>h1-fecc</metric>
    <metric>h2-fecc</metric>
    <metric>h3-fecc</metric>
    <metric>prop-h1-defic</metric>
    <metric>prop-h2-defic</metric>
    <metric>prop-h3-defic</metric>
    <metric>h1-propstaples</metric>
    <metric>h2-propstaples</metric>
    <metric>h3-propstaples</metric>
    <steppedValueSet variable="n-f-interact" first="1" step="1" last="10"/>
    <enumeratedValueSet variable="m-efficiency">
      <value value="0.7"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <steppedValueSet variable="n-l-interact" first="1" step="1" last="10"/>
    <enumeratedValueSet variable="climate-scenario">
      <value value="&quot;rcp_2.6&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nag-avail">
      <value value="0.7"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="population-scenario">
      <value value="&quot;Growth&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="12"/>
    <metric>month</metric>
    <metric>prop-h1-defic</metric>
    <metric>prop-h2-defic</metric>
    <metric>prop-h3-defic</metric>
    <enumeratedValueSet variable="population-scenario">
      <value value="&quot;Growth&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="m-efficiency" first="0.7" step="0.1" last="0.9"/>
    <steppedValueSet variable="nag-avail" first="0.7" step="0.1" last="0.9"/>
    <steppedValueSet variable="n-f-interact" first="2" step="2" last="10"/>
    <enumeratedValueSet variable="climate-scenario">
      <value value="&quot;rcp_2.6&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="n-l-interact" first="2" step="2" last="10"/>
    <steppedValueSet variable="multiplier" first="1" step="0.2" last="2"/>
  </experiment>
  <experiment name="interactions" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="12"/>
    <metric>month</metric>
    <metric>prop-h1-defic</metric>
    <metric>prop-h2-defic</metric>
    <metric>prop-h3-defic</metric>
    <steppedValueSet variable="n-f-interact" first="0" step="5" last="20"/>
    <steppedValueSet variable="m-efficiency" first="0.4" step="0.1" last="1"/>
    <steppedValueSet variable="n-l-interact" first="0" step="5" last="20"/>
    <enumeratedValueSet variable="climate-scenario">
      <value value="&quot;rcp_2.6&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="nag-avail" first="0.4" step="0.1" last="1"/>
    <enumeratedValueSet variable="population-scenario">
      <value value="&quot;Growth&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="fourpillars" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>year</metric>
    <metric>month</metric>
    <metric>count-h1</metric>
    <metric>count-h2</metric>
    <metric>count-h3</metric>
    <metric>h1-av</metric>
    <metric>h2-av</metric>
    <metric>h3-av</metric>
    <metric>h1-ac</metric>
    <metric>h2-ac</metric>
    <metric>h3-ac</metric>
    <metric>h1-u</metric>
    <metric>h2-u</metric>
    <metric>h3-u</metric>
    <metric>h1-s</metric>
    <metric>h2-s</metric>
    <metric>h3-s</metric>
    <enumeratedValueSet variable="population-scenario">
      <value value="&quot;Growth&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed-no" first="201" step="1" last="400"/>
    <enumeratedValueSet variable="m-efficiency">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nag-avail">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-f-interact">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="climate-scenario">
      <value value="&quot;rcp_2.6&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="multiplier">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-l-interact">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="foodresults" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="12"/>
    <metric>month</metric>
    <metric>h1-fecc</metric>
    <metric>h2-fecc</metric>
    <metric>h3-fecc</metric>
    <metric>prop-h1-defic</metric>
    <metric>prop-h2-defic</metric>
    <metric>prop-h3-defic</metric>
    <metric>h1-propstaples</metric>
    <metric>h2-propstaples</metric>
    <metric>h3-propstaples</metric>
    <enumeratedValueSet variable="population-scenario">
      <value value="&quot;Growth&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="m-efficiency">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nag-avail">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-f-interact">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="climate-scenario">
      <value value="&quot;rcp_2.6&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-l-interact">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="multiplier">
      <value value="1.6"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed-no" first="1" step="1" last="200"/>
  </experiment>
  <experiment name="trajectory" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>year</metric>
    <metric>month</metric>
    <metric>prop-hanging-in-1</metric>
    <metric>prop-stepping-up-1</metric>
    <metric>prop-stepping-out-1</metric>
    <metric>prop-falling-down-1</metric>
    <metric>prop-hanging-in-2</metric>
    <metric>prop-stepping-up-2</metric>
    <metric>prop-stepping-out-2</metric>
    <metric>prop-falling-down-2</metric>
    <metric>prop-hanging-in-3</metric>
    <metric>prop-stepping-up-3</metric>
    <metric>prop-stepping-out-3</metric>
    <metric>prop-falling-down-3</metric>
    <enumeratedValueSet variable="population-scenario">
      <value value="&quot;Growth&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed-no" first="201" step="1" last="400"/>
    <enumeratedValueSet variable="m-efficiency">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nag-avail">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-f-interact">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="climate-scenario">
      <value value="&quot;rcp_2.6&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="multiplier">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-l-interact">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
